@@ -3,6 +3,7 @@ package org.basex.core;
 import static org.basex.core.Lang.*;
 
 import org.basex.core.parse.Commands.CmdAlter;
+import org.basex.core.parse.Commands.CmdBinary;
 import org.basex.core.parse.Commands.CmdCreate;
 import org.basex.core.parse.Commands.CmdDrop;
 import org.basex.core.parse.Commands.CmdIndex;
@@ -16,7 +17,7 @@ import org.basex.util.*;
  * This class contains internationalized text strings, which are used throughout the project.
  * If this class is called first, the Strings are initialized by the {@link Lang} class.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public interface Text {
@@ -52,7 +53,7 @@ public interface Text {
   /** Entity. */
   String ORGANIZATION = Prop.NAME + " Team";
   /** Copyright info. */
-  String COPYRIGHT = "\u00A9 2005-22 " + ORGANIZATION;
+  String COPYRIGHT = "\u00A9 2005-23 " + ORGANIZATION;
 
   /** New line. */
   String NL = Prop.NL;
@@ -86,7 +87,7 @@ public interface Text {
   String S_STANDALONE = "Standalone";
   /** Start information. */
   String  S_LOCALINFO =
-    " [-bcdiIoqrRstuvVwxz] [input]" + NL +
+    " [-bcdiIoqrRstuvVwWxz] [input]" + NL +
     "  [input]    XQuery or command file, or query string" + NL +
     "  -b<args>   Bind external query variables" + NL +
     "  -c<input>  Execute commands from file or string" + NL +
@@ -102,7 +103,8 @@ public interface Text {
     "  -u         Toggle updates in original files" + NL +
     "  -v         Toggle output of progress info" + NL +
     "  -V         Toggle detailed query output" + NL +
-    "  -w         Toggle whitespace chopping" + NL +
+    "  -w         Toggle whitespace stripping" + NL +
+    "  -W         Enable indentation with whitespaces" + NL +
     "  -x         Toggle output of query plan" + NL +
     "  -z         Toggle output of query result";
 
@@ -110,7 +112,7 @@ public interface Text {
   String S_CLIENT = "Client";
   /** Client start information. */
   String S_CLIENTINFO =
-    " [-bcdiInopPqrRsUvVwxz] [input]" + NL +
+    " [-bcdiInopPqrRsUvVwWxz] [input]" + NL +
     "  [input]    XQuery or command file, or query string" + NL +
     "  -b<args>   Bind external query variables" + NL +
     "  -c<input>  Execute commands from file or string" + NL +
@@ -125,10 +127,11 @@ public interface Text {
     "  -r<num>    Run query multiple times" + NL +
     "  -R         Toggle query execution" + NL +
     "  -s<args>   Set serialization parameters" + NL +
-    "  -U<name>   Specify user name" + NL +
+    "  -U<name>   Specify username" + NL +
     "  -v         Toggle output of progress info" + NL +
     "  -V         Toggle detailed query output" + NL +
-    "  -w         Toggle whitespace chopping" + NL +
+    "  -w         Toggle whitespace stripping" + NL +
+    "  -W         Enable indentation with whitespaces" + NL +
     "  -x         Toggle output of query plan" + NL +
     "  -z         Toggle output of query result";
 
@@ -168,7 +171,7 @@ public interface Text {
     "  -p<port>   Set port of database server" + NL +
     "  -s<port>   Specify port to stop HTTP server" + NL +
     "  -S         Start as service" + NL +
-    "  -U<name>   Specify user name" + NL +
+    "  -U<name>   Specify username" + NL +
     "  -z         Suppress logging";
 
   /** Bug info. */
@@ -192,12 +195,12 @@ public interface Text {
   /** Command keyword. */
   String S_NAME = "name";
   /** Command keyword. */
+  String S_COMMENT = "comment";
+  /** Command keyword. */
   String S_PW = "password";
   /** Command keyword. */
   String S_DIR = "dir";
   /** Command keyword. */
-  String S_LIST = "list";
-  /** Command keyword. */
   String S_STOP = "stop";
 
   /** Index info. */
@@ -289,7 +292,7 @@ public interface Text {
   String TIMEOUT_EXCEEDED = lang("timeout_exceeded");
   /** Access denied. */
   String ACCESS_DENIED_X = lang("access_denied_%");
-  /** User name. */
+  /** Username. */
   String USERNAME = lang("username");
   /** Password. */
   String PASSWORD = lang("password");
@@ -313,7 +316,7 @@ public interface Text {
     CmdCreate.INDEX + '|' + CmdCreate.USER + "] [...]",
     lang("c_create1"),
     lang("c_create2") + NL +
-    LI + CmdDrop.BACKUP + " [" + S_NAME + "]:" + NL +
+    LI + CmdDrop.BACKUP + " ([" + S_NAME + "] ([" + S_COMMENT + "])):" + NL +
     "  " + lang("c_create22", S_NAME) + NL +
     LI + CmdCreate.DATABASE + " [" + S_NAME + "] ([" + S_INPUT + "]):"  + NL +
     "  " + lang("c_create21", S_NAME, S_INPUT) + NL +
@@ -339,13 +342,17 @@ public interface Text {
     lang("c_add1"), lang("c_add2", S_INPUT, S_PATH)
   };
   /** Command help. */
-  String[] HELPSTORE = {
-    '(' + S_TO + " [" + S_PATH + "]) [" + S_INPUT + ']',
-    lang("c_store1"), lang("c_store2", S_PATH)
+  String[] HELPBINARY = {
+      "[" + CmdBinary.GET + '|' + CmdBinary.PUT + ']',
+    lang("c_binary1"),
+    lang("c_binary2") + NL +
+    LI + CmdBinary.GET + " [" + S_PATH + "]" + COLS + lang("c_binary21", S_PATH) + NL +
+    LI + CmdBinary.PUT + " (" + S_TO + " [" + S_PATH + "]) [" + S_INPUT + ']' + COLS +
+      lang("c_binary22", S_PATH)
   };
   /** Command help. */
-  String[] HELPRETRIEVE = {
-    '[' + S_PATH + ']', lang("c_retrieve1"), lang("c_retrieve2", S_PATH)
+  String[] HELPGET = {
+    '[' + S_PATH + ']', lang("c_get1"), lang("c_get2", S_PATH)
   };
   /** Command help. */
   String[] HELPDELETE = {
@@ -375,12 +382,16 @@ public interface Text {
     "([" + S_NAME + "] ([" + S_PATH + "]))", lang("c_list1"), lang("c_list2", S_NAME, S_PATH)
   };
   /** Command help. */
+  String[] HELPDIR = {
+    '[' + S_PATH  + ']', lang("c_dir1"), lang("c_dir2")
+  };
+  /** Command help. */
   String[] HELPDROP = {
     "[" + CmdDrop.BACKUP + '|' + CmdDrop.DATABASE + '|' +
       CmdDrop.INDEX + '|' + CmdDrop.USER + "] [...]",
     lang("c_drop1"),
     lang("c_drop2") + NL +
-    LI + CmdDrop.BACKUP + " [" + S_NAME + "]:" + NL +
+    LI + CmdDrop.BACKUP + " ([" + S_NAME + "]):" + NL +
     "  " + lang("c_drop24") + NL +
     LI + CmdDrop.DATABASE + " [" + S_NAME + "]:" + NL +
     "  " + lang("c_drop21") + NL +
@@ -424,10 +435,6 @@ public interface Text {
     '[' + S_INPUT + ']', lang("c_execute1"), lang("c_execute2", S_INPUT)
   };
   /** Command help. */
-  String[] HELPJOBS = {
-    '[' + S_LIST + '|' + S_STOP + ']', lang("c_jobs1"), lang("c_jobs2")
-  };
-  /** Command help. */
   String[] HELPKILL = {
     '[' + S_NAME + ']', lang("c_kill1"), lang("c_kill2")
   };
@@ -436,21 +443,22 @@ public interface Text {
     '[' + S_PATH  + "] [newpath]", lang("c_rename1"), lang("c_rename2")
   };
   /** Command help. */
-  String[] HELPREPLACE = {
+  String[] HELPPUT = {
     '[' + S_PATH  + "] [" + S_INPUT + ']',
-    lang("c_replace1"), lang("c_replace2")
+    lang("c_put1"), lang("c_put2")
   };
   /** Command help. */
   String[] HELPRESTORE = {
-    '[' + S_NAME + "-(date)]", lang("c_restore1"), lang("c_restore2")
+    "([" + S_NAME + "(-date)])", lang("c_restore1"), lang("c_restore2")
   };
   /** Command help. */
   String[] HELPSHOW = {
     "[" + CmdShow.BACKUPS + '|' + CmdShow.SESSIONS + '|' + CmdShow.USERS + ']',
     lang("c_show1"),
     lang("c_show21") + NL +
+    LI + CmdShow.OPTIONS + " ([name])" + COLS + lang("c_show22") + NL +
     LI + CmdShow.SESSIONS + COLS + lang("c_show23") + NL +
-    LI + CmdShow.USERS + " (" + ON + " [database]): " + lang("c_show24") + NL +
+    LI + CmdShow.USERS + " (" + ON + " [database])" + COLS + lang("c_show24") + NL +
     LI + CmdShow.BACKUPS + COLS + lang("c_show25")
   };
   /** Command help. */
@@ -463,15 +471,15 @@ public interface Text {
   };
   /** Command help. */
   String[] HELPALTER = {
-    "[" + CmdAlter.DATABASE + '|' + CmdAlter.PASSWORD + '|' + CmdAlter.USER + "] [...]",
+    "[" + CmdAlter.DATABASE + '|' + CmdAlter.USER + '|' + CmdAlter.PASSWORD + "] [...]",
     lang("c_alter1"),
     lang("c_alter2") + NL  +
     LI + CmdAlter.DATABASE + " [" + S_NAME + "] [newname]" + NL +
     "  " + lang("c_alterdb") + NL +
-    LI + CmdAlter.PASSWORD + " [" + S_NAME + "] [" + S_PW + ']' + NL +
-    "  " + lang("c_alterpw") + NL +
     LI + CmdAlter.USER  + " [" + S_NAME + "] ([newname]):" + NL +
-    "  " + lang("c_alteruser")
+    "  " + lang("c_alteruser") + NL +
+    LI + CmdAlter.PASSWORD + " [" + S_NAME + "] [" + S_PW + ']' + NL +
+    "  " + lang("c_alterpw")
   };
   /** Command help. */
   String[] HELPINSPECT = {
@@ -482,10 +490,6 @@ public interface Text {
     "[option] ([value])", lang("c_set1"), lang("c_set2")
   };
   /** Command help. */
-  String[] HELPGET = {
-    "[option]", lang("c_get1"), lang("c_get2")
-  };
-  /** Command help. */
   String[] HELPPASSWORD = {
     "([" + S_PW + "])", lang("c_password1"), lang("c_password2")
   };
@@ -507,7 +511,7 @@ public interface Text {
   };
   /** Command help. */
   String[] HELPEXIT = {
-    "", lang("c_exit1"), lang("c_exit2")
+    "", lang("c_exit1"), lang("c_exit2", Prop.NAME)
   };
 
   // COMMAND INFOS ================================================================================
@@ -525,8 +529,10 @@ public interface Text {
   String NO_MAINMEM = lang("no_mainmem");
   /** Out of memory error. */
   String OUT_OF_MEM = lang("out_of_mem");
-  /** Progress exception. */
-  String INTERRUPTED = lang("interrupted");
+  /** Interrupted command execution. */
+  String INTERRUPTED = lang("interrupted") + DOT;
+  /** Chopped result. */
+  String CHOPPED = lang("chopped");
 
   /** Expecting command. */
   String EXPECTING_CMD = lang("expecting_cmd");
@@ -650,7 +656,7 @@ public interface Text {
   String BACKUP_RENAMED_X = lang("backup_renamed_%");
   /** Database was not renamed. */
   String BACKUP_NOT_RENAMED_X = lang("backup_not_renamed_%");
- /** Database was dropped. */
+  /** Database was dropped. */
   String BACKUP_DROPPED_X = lang("backup_dropped_%");
   /** Backup was not found. */
   String BACKUP_NOT_FOUND_X = lang("backup_not_found_%");
@@ -682,8 +688,12 @@ public interface Text {
   String QUERY = lang("query");
   /** Query info: optimized query. */
   String OPTIMIZED_QUERY = lang("optimized_query");
+  /** Query info: parsing. */
+  String PARSING = lang("parsing");
   /** Query info: compiling. */
   String COMPILING = lang("compiling");
+  /** Query info: optimizing. */
+  String OPTIMIZING = lang("optimizing");
   /** Query info: evaluating. */
   String EVALUATING = lang("evaluating");
   /** Query info: querying. */
@@ -693,14 +703,14 @@ public interface Text {
   /** Query info: plan. */
   String QUERY_PLAN = lang("query_plan");
 
-  /** "Query: ". */
-  String QUERY_CC = lang("query") + COLS;
   /** "Parsing: ". */
-  String PARSING_CC = lang("parsing") + COLS;
+  String PARSING_CC = PARSING + COLS;
   /** "Compiling: ". */
-  String COMPILING_CC = lang("compiling") + COLS;
+  String COMPILING_CC = COMPILING + COLS;
+  /** "Optimizing: ". */
+  String OPTIMIZING_CC = OPTIMIZING + COLS;
   /** "Evaluating: ". */
-  String EVALUATING_CC = lang("evaluating") + COLS;
+  String EVALUATING_CC = EVALUATING + COLS;
   /** "Printing: ". */
   String PRINTING_CC = lang("printing") + COLS;
   /** "Total time: ". */
@@ -709,8 +719,8 @@ public interface Text {
   String READ_LOCKING_CC = lang("read_locking") + COLS;
   /** "Write locking: ". */
   String WRITE_LOCKING_CC = lang("write_locking") + COLS;
-  /** "Hit(s): ". */
-  String HITS_X_CC = lang("hit_s") + COLS;
+  /** "Number: ". */
+  String NUMBER_CC = lang("number") + COLS;
   /** "Updated: ". */
   String UPDATED_CC = lang("updated") + COLS;
   /** "Printed: ". */
@@ -733,10 +743,10 @@ public interface Text {
   String SESSIONS_X = lang("sessions_%");
   /** Show packages. */
   String PACKAGES_X = lang("packages_%");
-  /** Show jobs. */
-  String JOBS_X = lang("jobs_%");
-  /** Show packages. */
+  /** Show resources. */
   String RESOURCES_X = lang("resources_%");
+  /** Show entries. */
+  String ENTRIES_X = lang("entries_%");
   /** Permission required. */
   String PERM_REQUIRED_X = lang("perm_required_%");
   /** Invalid permissions. */
@@ -773,8 +783,6 @@ public interface Text {
   String PKG_INSTALLED_X_X = lang("pkg_installed_%_%");
   /** Package replaced. */
   String PKG_REPLACED_X_X = lang("pkg_replaced_%_%");
-  /** Jobs stopped. */
-  String JOBS_STOPPED_X = lang("jobs_stopped_%");
 
   // GENERAL COMMANDS =============================================================================
 
@@ -802,8 +810,6 @@ public interface Text {
   String TYPE = lang("type");
   /** "Input path". */
   String INPUT_PATH = lang("input_path");
-  /** "Timestamp". */
-  String TIMESTAMP = lang("timestamp");
   /** "Resources". */
   String RESOURCES = lang("resources");
   /** "Encoding". */
@@ -812,26 +818,10 @@ public interface Text {
   String PARAMETERS = lang("parameters");
   /** "Path". */
   String PATH = lang("path");
-  /** "Duration". */
-  String DURATION = lang("duration");
-  /** "State". */
-  String STATE = lang("state");
-  /** "Start". */
-  String START = lang("start");
-  /** "End". */
-  String END = lang("end");
-  /** "Interval". */
-  String INTERVAL = lang("interval");
-  /** "User". */
-  String USER = lang("user");
-  /** "Reads". */
-  String READS = lang("reads");
-  /** "Writes". */
-  String WRITES = lang("writes");
-  /** "Time". */
-  String TIME = lang("time");
   /** External Variables. */
   String EXTERNAL_VARIABLES = lang("external_variables");
+  /** Indent result. */
+  String INDENT_RESULT = lang("indent_result");
 
   /** Command info. */
   String RECENTLY_OPENED = lang("recently_opened");
@@ -893,10 +883,6 @@ public interface Text {
   /** "Local Options". */
   String LOCAL_OPTIONS = lang("local_options");
 
-  /** "(chopped)". */
-  String CHOPPED = '(' + lang("chopped") + ") ";
-  /** "(% entries)". */
-  String ENTRIES_X = '(' + lang("entries_%") + ')';
   /** "Error". */
   String ERROR = lang("error");
 
@@ -1053,8 +1039,6 @@ public interface Text {
   String COMMAND = lang("command");
   /** "Backup". */
   String BACKUP = lang("backup");
-  /** "XQuery". */
-  String XQUERY = "XQuery";
 
   /** Button text for deleting files. */
   String DROP = lang("drop");
@@ -1109,10 +1093,6 @@ public interface Text {
   String USE_CATALOG_FILE = lang("use_catalog_file");
   /** Use XInclude. */
   String USE_XINCLUDE = lang("use_xinclude");
-  /** Use Catalog file not found on CP. */
-  String HELP1_USE_CATALOG = lang("help1_use_catalog");
-  /** Use Catalog file not found on CP. */
-  String HELP2_USE_CATALOG = lang("help2_use_catalog");
 
   /** Database creation filter. */
   String FILE_PATTERNS = lang("file_patterns");
@@ -1125,8 +1105,8 @@ public interface Text {
 
   /** Dialog title for database options. */
   String CREATE_DATABASE = lang("create_database");
-  /** Chop whitespaces. */
-  String CHOP_WS = lang("chop_ws");
+  /** Strip whitespaces. */
+  String STRIP_WS = lang("strip_ws");
   /** Strip namespaces. */
   String STRIP_NS = lang("strip_ns");
   /** DTD information. */
@@ -1208,8 +1188,6 @@ public interface Text {
 
   /** General info. */
   String GENERAL = lang("general");
-  /** General info. */
-  String PARSING = lang("parsing");
   /** Name indexes. */
   String NAMES = lang("names");
   /** Paths. */
@@ -1407,8 +1385,8 @@ public interface Text {
   /** Out of memory error due to database creation. */
   String H_OUT_OF_MEM = NL + lang("h_out_of_mem");
 
-  /** Information on chopping whitespaces. */
-  String H_CHOP_WS = lang("h_chop_ws");
+  /** Information on stripping whitespaces. */
+  String H_STRIP_WS = lang("h_strip_ws");
   /** Internal parser information. */
   String H_INT_PARSER = lang("h_int_parser");
 
