@@ -1,13 +1,12 @@
 package org.basex.core.cmd;
 
 import org.basex.core.*;
-import org.basex.core.locks.*;
 import org.basex.core.users.*;
 
 /**
  * Abstract class for database backup.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 abstract class ABackup extends Command {
@@ -18,9 +17,4 @@ abstract class ABackup extends Command {
   ABackup(final String... args) {
     super(Perm.CREATE, false, args);
   }
-
-  @Override
-  public void addLocks() {
-    jc().locks.writes.add(Locking.BACKUP); // No parallel backup operations
-  }
 }
