@@ -11,13 +11,13 @@ import org.basex.core.users.*;
 /**
  * Evaluates the 'alter password' command and alters the password of a user.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class AlterPassword extends AUser {
   /**
    * Default constructor.
-   * @param name user name
+   * @param name username
    * @param pw password
    */
   public AlterPassword(final String name, final String pw) {
@@ -41,6 +41,6 @@ public final class AlterPassword extends AUser {
   @Override
   public void build(final CmdBuilder cb) {
     cb.init(Cmd.ALTER + " " + CmdAlter.PASSWORD).arg(0);
-    if(!cb.conf()) cb.arg(1);
+    if(!cb.password()) cb.arg(1);
   }
 }
