@@ -1,11 +1,11 @@
 package org.basex.core.cmd;
 
-import org.basex.query.value.*;
+import java.util.AbstractMap.*;
 
 /**
  * Evaluates the 'xquery' command and processes an XQuery request.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class XQuery extends AQuery {
@@ -14,23 +14,7 @@ public final class XQuery extends AQuery {
    * @param query query to evaluate
    */
   public XQuery(final String query) {
-    super(false, query);
-  }
-
-  @Override
-  protected boolean run() {
-    return query(args[0]);
-  }
-
-  /**
-   * Binds a variable.
-   * @param name name of variable (if {@code null}, value will be bound as context value)
-   * @param value XQuery value to be bound
-   * @return self reference
-   */
-  public XQuery bind(final String name, final Value value) {
-    vars.put(name, value);
-    return this;
+    super(false, query, query);
   }
 
   /**
@@ -39,7 +23,7 @@ public final class XQuery extends AQuery {
    * @param value value to be bound (XQuery value; any other value will be converted to a string)
    * @return self reference
    */
-  public XQuery bind(final String name, final String value) {
+  public XQuery bind(final String name, final Object value) {
     return bind(name, value, null);
   }
 
@@ -47,11 +31,11 @@ public final class XQuery extends AQuery {
    * Binds a variable.
    * @param name name of variable (if {@code null}, value will be bound as context value)
    * @param value value to be bound
-   * @param type type
+   * @param type type (can be {@code null})
    * @return self reference
    */
-  public XQuery bind(final String name, final String value, final String type) {
-    vars.put(name, new String[] { value, type });
+  public XQuery bind(final String name, final Object value, final String type) {
+    bindings.put(name, new SimpleEntry<>(value, type));
     return this;
   }
 }
