@@ -10,6 +10,7 @@ import org.basex.build.*;
 import org.basex.core.*;
 import org.basex.core.cmd.*;
 import org.basex.index.*;
+import org.basex.index.resource.*;
 import org.basex.io.*;
 import org.basex.io.in.DataInput;
 import org.basex.io.out.DataOutput;
@@ -20,13 +21,10 @@ import org.basex.util.list.*;
 /**
  * This class provides meta information on a database.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class MetaData {
-  /** Database directory. Set to {@code null} if database is in main memory. */
-  public final IOFile dir;
-
   /** Database name. */
   public String name;
 
@@ -101,6 +99,8 @@ public final class MetaData {
   /** Last (highest) id assigned to a node. Can be {@code -1} if database is empty. */
   public int lastid = -1;
 
+  /** Database directory. Set to {@code null} if database is in main memory. */
+  private final IOFile dir;
   /** Flag for out-of-date indexes. */
   private boolean oldindex;
 
@@ -193,7 +193,7 @@ public final class MetaData {
   private static boolean addToPath(final StringBuilder sb, final StringList list) {
     if(sb.length() != 0) {
       final String segment = sb.toString();
-      if(segment.endsWith(".")) {
+      if(Strings.endsWith(segment, '.')) {
         if(!segment.equals(".")) return false;
       } else if(segment.equals("..")) {
         if(list.isEmpty()) return false;
@@ -258,7 +258,7 @@ public final class MetaData {
   }
 
   /**
-   * Returns a file instance for the specified database file.
+   * Returns a database file for the specified filename.
    * Should only be called if database is disk-based.
    * @param filename filename
    * @return database filename
@@ -268,11 +268,26 @@ public final class MetaData {
   }
 
   /**
-   * Returns the binary directory.
-   * @return binary directory, or {@code null} if this is a main-memory database
+   * Returns a directory with file resources.
+   * @param type resource type
+   * @return directory, or {@code null} for XML type or if this is a main-memory database
    */
-  public IOFile binaryDir() {
-    return dir == null ? null : new IOFile(dir, IO.RAW);
+  public IOFile dir(final ResourceType type) {
+    return dir == null ? null : type.dir(dir);
+  }
+
+  /**
+   * Returns the resource with the specified path.
+   * @param path internal file path
+   * @param type resource type
+   * @return path, or {@code null} if this is a main-memory database
+   */
+  public IOFile file(final String path, final ResourceType type) {
+    if(dir != null) {
+      final IOFile bin = dir(type), file = new IOFile(bin, path);
+      return file.isDir() ? file : type.filePath(bin, path);
+    }
+    return null;
   }
 
   /**
@@ -283,20 +298,6 @@ public final class MetaData {
     return dbFile(DATAUPD);
   }
 
-  /**
-   * Returns a reference to the specified binary resource.
-   * @param path internal file path
-   * @return path, or {@code null} if this is a main-memory database or
-   *   if the resource path cannot be resolved (e.g. because it points to a parent directory).
-   */
-  public IOFile binary(final String path) {
-    if(dir != null) {
-      final IOFile bin = binaryDir(), file = new IOFile(bin, path);
-      if(file.path().startsWith(bin.path())) return file;
-    }
-    return null;
-  }
-
   /**
    * Drops the specified database files.
    * Should only be called if database is disk-based.
@@ -380,7 +381,7 @@ public final class MetaData {
   // CLASS METHODS ================================================================================
 
   /**
-   * Reads in meta data from the specified stream.
+   * Reads in metadata from the specified stream.
    * @param in input stream
    * @throws IOException I/O exception
    */
@@ -435,7 +436,7 @@ public final class MetaData {
   }
 
   /**
-   * Writes the meta data to the specified output stream.
+   * Writes the metadata to the specified output stream.
    * @param out output stream
    * @throws IOException I/O Exception
    */
