@@ -13,6 +13,7 @@ import javax.swing.border.*;
 
 import org.basex.core.*;
 import org.basex.core.cmd.*;
+import org.basex.core.jobs.*;
 import org.basex.core.parse.*;
 import org.basex.data.*;
 import org.basex.gui.dialog.*;
@@ -38,7 +39,7 @@ import org.basex.util.options.*;
 /**
  * This class is the main window of the GUI. It is the central instance for user interactions.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class GUI extends JFrame implements BaseXWindow {
@@ -54,10 +55,10 @@ public final class GUI extends JFrame implements BaseXWindow {
   public final GUIStatus status;
   /** Input field. */
   public final GUIInput input;
-  /** Filter button. */
-  public final AbstractButton filter;
   /** Search view. */
   public final EditorView editor;
+  /** Text view. */
+  public final TextView text;
   /** Info view. */
   public final InfoView info;
 
@@ -82,8 +83,6 @@ public final class GUI extends JFrame implements BaseXWindow {
   /** Current input Mode. */
   private final BaseXCombo mode;
 
-  /** Text view. */
-  private final TextView text;
   /** Top panel. */
   private final BaseXBack top;
   /** Control panel. */
@@ -117,8 +116,8 @@ public final class GUI extends JFrame implements BaseXWindow {
     this.context = context;
     this.gopts = gopts;
 
-    if(Prop.MAC) GUIMacOS.init(this);
-    setIconImage(BaseXImages.get("logo_64"));
+    if(Prop.MAC) BaseXLayout.initMac(this);
+    setIconImage(BaseXImages.get("logo_small"));
     setTitle();
 
     // set window size
@@ -147,7 +146,7 @@ public final class GUI extends JFrame implements BaseXWindow {
     toolbar = new GUIToolBar(TOOLBAR, this);
     buttons.add(toolbar, BorderLayout.WEST);
 
-    results = new BaseXLabel(" ").border(0, 0, 0, 4).resize(1.7f);
+    results = new BaseXLabel(" ").border(-2, 0, 0, 4).resize(1.7f);
     results.setHorizontalAlignment(SwingConstants.RIGHT);
 
     BaseXBack b = new BaseXBack();
@@ -156,7 +155,7 @@ public final class GUI extends JFrame implements BaseXWindow {
     buttons.add(b, BorderLayout.EAST);
     if(this.gopts.get(GUIOptions.SHOWBUTTONS)) control.add(buttons, BorderLayout.CENTER);
 
-    mode = new BaseXCombo(this, FIND, XQUERY, COMMAND);
+    mode = new BaseXCombo(this, FIND, "XQuery", COMMAND);
     mode.setSelectedIndex(2);
 
     input = new GUIInput(this);
@@ -177,6 +176,9 @@ public final class GUI extends JFrame implements BaseXWindow {
     nav.add(mode, BorderLayout.WEST);
     nav.add(b, BorderLayout.CENTER);
 
+    final AbstractButton go = BaseXButton.get("c_go", RUN_QUERY, false, this);
+    go.addActionListener(e -> execute());
+
     stop = BaseXButton.get("c_stop", STOP, false, this);
     stop.setEnabled(false);
     stop.addActionListener(e -> {
@@ -186,16 +188,10 @@ public final class GUI extends JFrame implements BaseXWindow {
       }
     });
 
-    final AbstractButton go = BaseXButton.get("c_go", RUN_QUERY, false, this);
-    go.addActionListener(e -> execute());
-
-    filter = BaseXButton.command(GUIMenuCmd.C_FILTER_NODES, this);
-
-    b = new BaseXBack(new ColumnLayout(1));
-    b.add(stop);
-    b.add(go);
-    b.add(filter);
-    nav.add(b, BorderLayout.EAST);
+    final BaseXToolBar tb = new BaseXToolBar();
+    tb.add(go);
+    tb.add(stop);
+    nav.add(tb, BorderLayout.EAST);
 
     if(this.gopts.get(GUIOptions.SHOWINPUT)) control.add(nav, BorderLayout.SOUTH);
     top.add(control, BorderLayout.NORTH);
@@ -235,12 +231,21 @@ public final class GUI extends JFrame implements BaseXWindow {
 
   @Override
   public void dispose() {
-    saveOptions();
-    // check if all modified texts are saved or closed
+    quit();
+  }
+
+  /**
+   * Closes the GUI.
+   * @return success flag
+   */
+  public boolean quit() {
     if(editor.confirm(null)) {
+      saveOptions();
       context.close();
       super.dispose();
+      return true;
     }
+    return false;
   }
 
   /**
@@ -287,7 +292,7 @@ public final class GUI extends JFrame implements BaseXWindow {
   }
 
   /**
-   * Sets a cursor, enforcing a new look if necessary.
+   * Sets a cursor.
    * @param cursor cursor to be set
    * @param enforce enforce new cursor
    */
@@ -321,7 +326,7 @@ public final class GUI extends JFrame implements BaseXWindow {
     } else if(gopts.get(GUIOptions.SEARCHMODE) == 1 || Strings.startsWith(in, '/')) {
       simpleQuery(in);
     } else {
-      execute(new Find(in, gopts.get(GUIOptions.FILTERRT)));
+      execute(new Find(in));
     }
   }
 
@@ -351,17 +356,17 @@ public final class GUI extends JFrame implements BaseXWindow {
   /**
    * Launches the specified commands in a separate thread.
    * Commands are ignored if an update operation takes place.
-   * @param edit call from editor view
+   * @param editing call from editor view
    * @param cmds commands to be executed
    */
-  public void execute(final boolean edit, final Command... cmds) {
+  public void execute(final boolean editing, final Command... cmds) {
     // ignore command if updates take place
     if(updating) return;
 
     new Thread(() -> {
       if(cmds.length == 0) info.setInfo("", null, true, true);
       for(final Command cmd : cmds) {
-        if(!exec(cmd, edit)) break;
+        if(!execute(cmd, editing)) break;
       }
     }).start();
   }
@@ -369,10 +374,10 @@ public final class GUI extends JFrame implements BaseXWindow {
   /**
    * Executes the specified command.
    * @param cmd command to be executed
-   * @param edit called from editor view
+   * @param editing called from editor view
    * @return success flag
    */
-  private boolean exec(final Command cmd, final boolean edit) {
+  private boolean execute(final Command cmd, final boolean editing) {
     // wait when command is still running
     final int id = commandID.incrementAndGet();
     while(true) {
@@ -387,10 +392,10 @@ public final class GUI extends JFrame implements BaseXWindow {
     cursor(CURSORWAIT);
     input.setCursor(CURSORWAIT);
     stop.setEnabled(true);
-    if(edit) editor.pleaseWait(id);
+    if(editing) editor.pleaseWait(id);
 
     final Data data = context.data();
-    // reset current context if realtime filter is activated
+    // reset current context if real-time filter is activated
     if(gopts.get(GUIOptions.FILTERRT) && data != null && !context.root()) context.invalidate();
 
     // remember current command and context nodes
@@ -428,29 +433,24 @@ public final class GUI extends JFrame implements BaseXWindow {
         running = false;
       }
 
-      // show query info, send feedback to query editor
-      final String time = info.setInfo(inf, cmd, perf.getTime(), ok, true);
-      final boolean stopped = inf.substring(inf.lastIndexOf('\n') + 1).equals(INTERRUPTED);
-      if(edit) editor.info(cause, stopped, true);
-
       // get query result and node references to currently opened database
-      final Value result = cmd.result();
-      DBNodes nodes = result instanceof DBNodes ? (DBNodes) result : null;
+      final Value value = cmd.result;
+      DBNodes nodes = value instanceof DBNodes ? (DBNodes) value : null;
+      final boolean updated = cmd.updated(context);
 
-      // show text view if a non-empty result does not reference the currently opened database
-      if(!text.visible() && output.size() != 0 && nodes == null) {
-        GUIMenuCmd.C_SHOW_RESULT.execute(this);
+      if(!text.visible()) {
+        // show text view if the result does not comprise nodes of the opened database
+        if(nodes == null && output.size() != 0) GUIMenuCmd.C_SHOW_RESULT.execute(this);
+        // open info view if error occurs
+        if(!ok && !editing && !info.visible()) GUIMenuCmd.C_SHOW_INFO.execute(this);
       }
 
-      // check if query feedback was evaluated in the query view
-      if(!ok && !stopped) {
-        // display error in info view
-        text.setText(output, 0);
-        if(!info.visible() && (!edit || inf.startsWith(S_BUGINFO))) {
-          GUIMenuCmd.C_SHOW_INFO.execute(this);
-        }
-      } else {
-        final boolean updated = cmd.updated(context);
+      // show query info, send feedback to query editor
+      final boolean stopped = cause instanceof JobException;
+      if(editing) editor.info(cause, stopped, true);
+
+      // update context and send notifications if command was successful
+      if(ok) {
         if(context.data() != data) {
           // database reference has changed - notify views
           notify.init();
@@ -458,46 +458,49 @@ public final class GUI extends JFrame implements BaseXWindow {
           // update visualizations
           notify.update();
           // adopt updated nodes as result set
-          if(nodes == null && result == Empty.VALUE) nodes = context.current();
-        } else if(result != null) {
+          if(nodes == null && value.isEmpty()) nodes = context.current();
+        } else if(value != null) {
           // check if result has changed
-          final boolean flt = gopts.get(GUIOptions.FILTERRT);
+          final boolean filterrt = gopts.get(GUIOptions.FILTERRT);
           final DBNodes curr = context.current();
-          if(flt || curr != null && !curr.equals(current)) {
+          if(filterrt || curr != null && !curr.equals(current)) {
             // refresh context if at least one node was found
-            if(nodes != null) notify.context(nodes, flt, null);
+            if(nodes != null) notify.context(nodes, filterrt, null);
           } else if(context.marked != null) {
             // refresh highlight
-            DBNodes m = context.marked;
+            DBNodes marked = context.marked;
             if(nodes != null) {
               // use query result
-              m = nodes;
-            } else if(!m.isEmpty()) {
+              marked = nodes;
+            } else if(!marked.isEmpty()) {
               // remove old highlighting
-              m = new DBNodes(data);
+              marked = new DBNodes(data);
             }
             // refresh views
-            if(context.marked != m) notify.mark(m, null);
+            if(context.marked != marked) notify.mark(marked, null);
           }
         }
-
-        if(id == commandID.get() && !stopped) {
-          // refresh editor info
-          editor.refreshContextLabel();
-          // show status info
-          status.setText(TIME_REQUIRED + COLS + time);
-          // show number of hits
-          if(result != null) results.setText(gopts.results(result.size(), 0));
-          // assign textual output if no node result was created
-          if(nodes == null) text.setText(output, result != null ? result.size() : 0);
-          // only cache output if data has not been updated (in which case notifyUpdate was called)
-          if(!updated) text.cache(output, cmd, result);
-        }
       }
+
+      if(id == commandID.get()) {
+        // refresh editor info
+        editor.refreshContextLabel();
+        // refresh info view and status bar
+        final String total = info.setInfo(inf, cmd, perf.getTime(), ok, true);
+        if(ok) status.setText(TIME_REQUIRED + COLS + total, true);
+        // show number of hits
+        results.setText(BaseXLayout.results(value != null ? value.size() : -1, -1, this));
+        // assign textual output if no node result was created
+        if(nodes == null) text.setText(output, value != null ? value.size() : -1, cause);
+        // only cache output if data has not been updated (in which case notifyUpdate was called)
+        if(!updated) text.cache(output, cmd, value);
+      }
+
     } catch(final Exception ex) {
       // unexpected error
-      BaseXDialog.error(this, Util.info(EXEC_ERROR_X_X, cmd, Util.bug(ex)));
       updating = false;
+      running = false;
+      BaseXDialog.error(this, Util.info(EXEC_ERROR_X_X, cmd, Util.bug(ex)));
     }
     stop();
     return ok;
@@ -602,13 +605,11 @@ public final class GUI extends JFrame implements BaseXWindow {
    * @param result update number of results
    */
   public void refreshControls(final boolean result) {
-    final DBNodes marked = context.marked;
+    final DBNodes marked = context.marked, current = context.current();
     if(result && marked != null) {
-      results.setText(gopts.results((marked.isEmpty() ? context.current() : marked).size(), 0));
+      results.setText(BaseXLayout.results((marked.isEmpty() ? current : marked).size(), -1, this));
     }
 
-    filter.setEnabled(marked != null && !marked.isEmpty());
-
     final boolean inf = gopts.get(GUIOptions.SHOWINFO);
     context.options.set(MainOptions.QUERYINFO, inf);
     context.options.set(MainOptions.XMLPLAN, inf);
@@ -699,7 +700,7 @@ public final class GUI extends JFrame implements BaseXWindow {
    * Checks for new versions.
    * @param ask ask for automatic update checks
    */
-  public void checkVersion(final boolean ask) {
+  void checkVersion(final boolean ask) {
     // retrieve latest version
     final Version version = new Version(gopts.get(GUIOptions.UPDATEVERSION));
     Version latest = version;
@@ -726,7 +727,7 @@ public final class GUI extends JFrame implements BaseXWindow {
       }
       saveOptions();
     } else if(ask) {
-      // version is up to date: ask for automatic check
+      // version is up-to-date: ask for automatic check
       chk = BaseXDialog.confirm(this, Util.info(H_VERSION_LATEST_X, Prop.NAME) + '\n' +
           H_VERSION_CHECK);
       gopts.set(GUIOptions.CHECKUPDATES, chk);
