@@ -13,17 +13,19 @@ import org.basex.gui.text.TextEditor.*;
 import org.basex.gui.view.*;
 import org.basex.gui.view.editor.*;
 import org.basex.io.*;
+import org.basex.io.serial.*;
 import org.basex.query.func.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
+import org.basex.util.options.Options.*;
 
 /**
  * This enumeration encapsulates all commands that are triggered by GUI operations.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public enum GUIMenuCmd implements GUICommand {
@@ -201,6 +203,22 @@ public enum GUIMenuCmd implements GUICommand {
     }
   },
 
+  /** Indent result. */
+  C_INDENT_RESULT(INDENT_RESULT, "% shift I", false, true) {
+    @Override
+    public void execute(final GUI gui) {
+      final SerializerOptions sopts = gui.context.options.get(MainOptions.SERIALIZER);
+      sopts.put(SerializerOptions.INDENT, selected(gui) ? YesNo.NO : YesNo.YES);
+      gui.editor.refreshLayout();
+    }
+
+    @Override
+    public boolean selected(final GUI gui) {
+      final SerializerOptions sopts = gui.context.options.get(MainOptions.SERIALIZER);
+      return sopts.get(SerializerOptions.INDENT) == YesNo.YES;
+    }
+  },
+
   /** Jumps to the next error. */
   C_NEXT_ERROR(NEXT_ERROR, "% PERIOD", false, false) {
     @Override
@@ -309,7 +327,7 @@ public enum GUIMenuCmd implements GUICommand {
   C_EXIT(EXIT, null, false, false) {
     @Override
     public void execute(final GUI gui) {
-      gui.dispose();
+      gui.quit();
     }
   },
 
@@ -721,7 +739,7 @@ public enum GUIMenuCmd implements GUICommand {
 
   /* OPTION MENU */
 
-  /** Realtime execution on/off. */
+  /** Real-time execution on/off. */
   C_RT_EXECUTION(RT_EXECUCTION, null, false, true) {
     @Override
     public void execute(final GUI gui) {
@@ -735,7 +753,7 @@ public enum GUIMenuCmd implements GUICommand {
     }
   },
 
-  /** Realtime filtering on/off. */
+  /** Real-time filtering on/off. */
   C_RT_FILTERING(RT_FILTERING, null, true, true) {
     @Override
     public void execute(final GUI gui) {
@@ -899,7 +917,7 @@ public enum GUIMenuCmd implements GUICommand {
     }
   },
 
-   /** Displays the root node in the text view. */
+  /** Displays the root node in the text view. */
   C_SHOW_HOME(GO_HOME, null, true, false) {
     @Override
     public void execute(final GUI gui) {
@@ -988,6 +1006,6 @@ public enum GUIMenuCmd implements GUICommand {
    * @return function string
    */
   private static String openPre(final DBNodes nodes, final int index) {
-    return Function._DB_OPEN_PRE.args(nodes.data().meta.name, nodes.pre(index)).trim();
+    return Function._DB_GET_PRE.args(nodes.data().meta.name, nodes.pre(index)).trim();
   }
 }
