@@ -10,6 +10,7 @@ import java.awt.dnd.*;
 import java.awt.event.*;
 import java.io.*;
 import java.nio.file.*;
+import java.text.*;
 import java.util.*;
 import java.util.List;
 import java.util.function.*;
@@ -17,7 +18,9 @@ import java.util.function.*;
 import javax.swing.*;
 import javax.swing.border.*;
 
+import org.basex.core.*;
 import org.basex.gui.*;
+import org.basex.gui.dialog.*;
 import org.basex.gui.listener.*;
 import org.basex.gui.text.*;
 import org.basex.io.*;
@@ -27,7 +30,7 @@ import org.basex.util.*;
  * This class provides static layout and paint helper methods which are used all over
  * the GUI.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class BaseXLayout {
@@ -37,8 +40,8 @@ public final class BaseXLayout {
   /** Flag for adding rendering hints. */
   private static boolean hints = true;
 
-  /** Shortcut string for meta key. */
-  // will raise a warning (Java function returns deprecated value that is deprecated in Java 9)
+  /** Shortcut string for meta key (deprecated since Java 9). */
+  @SuppressWarnings("deprecation")
   private static final String META = Toolkit.getDefaultToolkit().getMenuShortcutKeyMask() ==
       InputEvent.CTRL_MASK ? "ctrl" : "meta";
 
@@ -138,7 +141,7 @@ public final class BaseXLayout {
       @Override
       public synchronized void drop(final DropTargetDropEvent dtde) {
         dtde.acceptDrop(DnDConstants.ACTION_COPY_OR_MOVE);
-        for(final Object clip : fromClipboard(() -> dtde.getTransferable())) {
+        for(final Object clip : fromClipboard(dtde::getTransferable)) {
           dnd.drop(clip);
         }
         comp.requestFocusInWindow();
@@ -221,7 +224,7 @@ public final class BaseXLayout {
         break;
       } catch(final Exception ex) {
         Util.stack(ex);
-        Performance.sleep(i * 200);
+        Performance.sleep(i * 200L);
       }
     }
     return list;
@@ -245,7 +248,7 @@ public final class BaseXLayout {
           Util.stack(ex);
         } else {
           Util.debug(ex);
-          Performance.sleep(i * 200);
+          Performance.sleep(i * 200L);
         }
       }
     }
@@ -265,7 +268,7 @@ public final class BaseXLayout {
 
   /**
    * Drag and drop handler.
-   * @author BaseX Team 2005-22, BSD License
+   * @author BaseX Team 2005-23, BSD License
    * @author Christian Gruen
    */
   public interface DropHandler {
@@ -336,7 +339,9 @@ public final class BaseXLayout {
       // focus input bar
       if(FOCUSINPUT.is(e)) gui.input.requestFocusInWindow();
       // focus editor
-      if(FOCUSEDITOR.is(e)) gui.editor.focusEditor();
+      else if(FOCUSEDITOR.is(e)) gui.editor.focusEditor();
+      // focus text
+      else if(FOCUSTEXT.is(e)) gui.text.focusText();
 
       // change font size
       final int fs = gui.gopts.get(GUIOptions.FONTSIZE);
@@ -357,7 +362,7 @@ public final class BaseXLayout {
   }
 
   /**
-   * Adds human readable shortcuts to the specified string.
+   * Adds human-readable shortcuts to the specified string.
    * @param string tooltip string
    * @param sc shortcut (can be {@code null})
    * @return tooltip
@@ -420,7 +425,7 @@ public final class BaseXLayout {
    * @param x horizontal position
    * @param y vertical position
    * @param w width
-   * @param c color color depth
+   * @param c color depth
    */
   public static void drawTooltip(final Graphics g, final String tt, final int x, final int y,
       final int w, final int c) {
@@ -552,4 +557,53 @@ public final class BaseXLayout {
     }
     return sb.toString();
   }
+
+  /**
+   * Returns a string representation of the number of results.
+   * @param count number of results (ignored if {@code -1})
+   * @param bytes number of bytes (ignored if {@code -1})
+   * @param gui GUI reference
+   * @return result string
+   */
+  public static String results(final long count, final long bytes, final GUI gui) {
+    final GUIOptions gopts = gui.gopts;
+    final BiFunction<Long, Integer, String> more = (num, max) -> num >= max ? "\u2265" : "";
+    final StringBuilder sb = new StringBuilder();
+    if(count >= 0) {
+      final String num = new DecimalFormat("#,###,###").format(count);
+      final String text = more.apply(count, gopts.get(GUIOptions.MAXRESULTS)) + num;
+      sb.append(Util.info(count == 1 ? Text.RESULT_X : Text.RESULTS_X, text));
+      if(bytes >= 0) {
+        final int maxtext = gopts.get(GUIOptions.MAXTEXT);
+        sb.append(", ").append(more.apply(bytes, maxtext)).append(Performance.format(bytes));
+      }
+    }
+    return sb.length() > 0 ? sb.toString() : " ";
+  }
+
+  /**
+   * Assigns macOS-specific interface GUI properties.
+   * @param gui GUI reference
+   */
+  public static void initMac(final GUI gui) {
+    try {
+      // show menu in the screen menu instead of inside the application window
+      System.setProperty("apple.laf.useScreenMenuBar", "true");
+
+      final Desktop desktop = Desktop.getDesktop();
+      desktop.setAboutHandler(e -> DialogAbout.show(gui));
+      desktop.setPreferencesHandler(e -> DialogPrefs.show(gui));
+      desktop.setQuitHandler((e, r) -> {
+        if(gui.quit()) r.performQuit();
+        else r.cancelQuit();
+      });
+
+      final Taskbar taskbar = Taskbar.getTaskbar();
+      taskbar.setIconImage(BaseXImages.get("logo_large"));
+
+    } catch(final Exception ex) {
+      Util.errln("Failed to initialize native Mac OS X interface:");
+      Util.stack(ex);
+    }
+  }
 }
