@@ -1,16 +1,17 @@
 package org.basex.gui.layout;
 
-import org.basex.core.*;
+import org.basex.data.*;
+import org.basex.index.resource.*;
 
 /**
  * JTree node which represents a leaf.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Lukas Kircher
  */
 public final class ResourceLeaf extends ResourceNode {
-  /** Represents binary resource or document. */
-  public final boolean binary;
+  /** Resource type. */
+  public final ResourceType type;
   /** This leaf is a dummy node displaying that node listing is abbreviated. */
   public final boolean abbr;
 
@@ -18,15 +19,15 @@ public final class ResourceLeaf extends ResourceNode {
    * Constructor.
    * @param name name of content node
    * @param path node path
-   * @param binary represented node is binary
+   * @param type resource type
    * @param abbr abbreviated node listing
    * @param tree tree reference
-   * @param context database context
+   * @param data database reference
    */
-  public ResourceLeaf(final byte[] name, final byte[] path, final boolean binary,
-      final boolean abbr, final BaseXTree tree, final Context context) {
-    super(name, path, tree, context);
-    this.binary = binary;
+  public ResourceLeaf(final byte[] name, final byte[] path, final ResourceType type,
+      final boolean abbr, final BaseXTree tree, final Data data) {
+    super(name, path, tree, data);
+    this.type = type;
     this.abbr = abbr;
   }
 
