@@ -15,7 +15,7 @@ import org.basex.util.list.*;
 /**
  * Provides methods for editing a text that is visualized by the {@link TextPanel}.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class TextEditor {
@@ -102,7 +102,7 @@ public final class TextEditor {
         // search was interrupted
       } catch(final Exception ex) {
         final String info = Util.message(ex).replaceAll(Text.NL + ".*", "");
-        gui.status.setError(Text.REGULAR_EXPR + Text.COLS + info);
+        gui.status.setText(Text.REGULAR_EXPR + Text.COLS + info, false);
       }
     });
     t.setDaemon(true);
@@ -630,9 +630,7 @@ public final class TextEditor {
     // adopt current indentation
     final int ind = open();
     if(ind != 0) {
-      final StringBuilder spaces = new StringBuilder();
-      for(int i = 0; i < ind; i++) spaces.append(' ');
-      v = new TokenBuilder().addAll(v.split("\n"), "\n" + spaces).toString();
+      v = new TokenBuilder().addAll(v.split("\n"), "\n".concat(" ".repeat(ind))).toString();
     }
     // delete old string, add new one
     replace(p, pos, v);
@@ -711,7 +709,7 @@ public final class TextEditor {
     // stable sort: before custom sort, apply default sort
     if(!unicode || column > 0) tokens.sort(true, true);
 
-    // choose cheapest comparator
+    // choose the cheapest comparator
     final Comparator<byte[]> cc;
     if(!unicode) {
       final Collator coll = Collator.getInstance();
@@ -786,7 +784,7 @@ public final class TextEditor {
     int indent = open(), move = 0;
     if(opening) {
       if(closing) {
-        for(int p = 0; p < indent + ind; p++) sb.append(' ');
+        sb.append(" ".repeat(Math.max(0, indent + ind)));
         move = indent + ind + 1;
         sb.append('\n');
       } else {
@@ -796,7 +794,7 @@ public final class TextEditor {
       // unindent before closing bracket
       indent -= ind;
     }
-    for(int p = 0; p < indent; p++) sb.append(' ');
+    sb.append(" ".repeat(Math.max(0, indent)));
     add(sb, false);
     return move;
   }
