@@ -6,7 +6,6 @@ import static org.basex.util.Token.*;
 
 import java.awt.*;
 import java.awt.event.*;
-import java.io.*;
 import java.util.*;
 import java.util.AbstractMap.*;
 import java.util.Map.*;
@@ -22,15 +21,15 @@ import org.basex.gui.listener.*;
 import org.basex.gui.text.SearchBar.*;
 import org.basex.gui.text.TextEditor.*;
 import org.basex.io.*;
-import org.basex.io.in.*;
 import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.util.*;
+import org.basex.util.hash.*;
 
 /**
  * Renders and provides edit capabilities for text.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class TextPanel extends BaseXPanel {
@@ -66,6 +65,9 @@ public class TextPanel extends BaseXPanel {
   /** Link listener. */
   private LinkListener linkListener;
 
+  /** Last number of mouse clicks. */
+  private int clicks;
+
   /**
    * Default constructor.
    * @param win parent window
@@ -397,10 +399,10 @@ public class TextPanel extends BaseXPanel {
         editor.select(select[0], select[sel ? 1 : 0]);
         release(Action.CHECK);
       }
-      gui.status.setText(Text.STRINGS_REPLACED);
+      gui.status.setText(Text.STRINGS_REPLACED, true);
     } catch(final Exception ex) {
       final String msg = Util.message(ex).replaceAll(Prop.NL + ".*", "");
-      gui.status.setError(Text.REGULAR_EXPR + Text.COLS + msg);
+      gui.status.setText(Text.REGULAR_EXPR + Text.COLS + msg, false);
     }
   }
 
@@ -451,12 +453,11 @@ public class TextPanel extends BaseXPanel {
 
   @Override
   public final void mouseDragged(final MouseEvent e) {
-    if(!SwingUtilities.isLeftMouseButton(e)) return;
-
-    // selection mode
-    select(e.getPoint(), false);
-    final int y = Math.max(20, Math.min(e.getY(), getHeight() - 20));
-    if(y != e.getY()) scroll.pos(scroll.pos() + e.getY() - y);
+    if(SwingUtilities.isLeftMouseButton(e) && clicks == 1) {
+      select(e.getPoint(), false);
+      final int y = Math.max(20, Math.min(e.getY(), getHeight() - 20));
+      if(y != e.getY()) scroll.pos(scroll.pos() + e.getY() - y);
+    }
   }
 
   @Override
@@ -479,15 +480,14 @@ public class TextPanel extends BaseXPanel {
     requestFocusInWindow();
     caret(true);
 
-    final boolean shift = e.isShiftDown();
-    final boolean selected = editor.isSelected();
+    final boolean shift = e.isShiftDown(), selected = editor.isSelected();
     if(SwingUtilities.isLeftMouseButton(e)) {
-      final int c = e.getClickCount();
-      if(c == 1) {
+      clicks = e.getClickCount();
+      if(clicks == 1) {
         // selection mode
         if(shift) editor.startSelection(true);
         select(e.getPoint(), !shift);
-      } else if(c == 2) {
+      } else if(clicks == 2) {
         editor.selectWord();
       } else {
         editor.selectLine();
@@ -895,7 +895,7 @@ public class TextPanel extends BaseXPanel {
   /** Find next hit. */
   private class FindCmd extends GUIPopupCmd {
     /** Constructor. */
-    FindCmd() { super(Text.FIND + Text.DOTS, FIND); }
+    FindCmd() { super(Text.FIND + "\u2026", FIND); }
 
     @Override
     public void execute() { search.activate(searchString(), true, false); }
@@ -1044,20 +1044,20 @@ public class TextPanel extends BaseXPanel {
 
     // find insertion candidates
     final ArrayList<Entry<String, String>> pairs = new ArrayList<>();
-    final int il = LISTS.size();
-    for(int i = 0; i < il; i++) {
-      if(i > 0) pairs.add(null);
-      for(final Entry<String, String> pair : LISTS.get(i)) {
+    final int ll = LISTS.size();
+    for(int l = 0; l < ll; l++) {
+      if(l > 0) pairs.add(null);
+      for(final Entry<String, String> pair : LISTS.get(l)) {
         final String name = pair.getKey();
         if(name.startsWith(input) || name.replace(":", "").startsWith(input)) pairs.add(pair);
       }
     }
-    if(pairs.size() < il) {
+    if(pairs.size() < ll) {
       pairs.clear();
-      for(int i = 0; i < il; i++) {
+      for(int i = 0; i < ll; i++) {
         if(i > 0) pairs.add(null);
         for(final Entry<String, String> pair : LISTS.get(i)) {
-          if(SmartStrings.matches(pair.getKey(), input)) pairs.add(pair);
+          if(SmartStrings.charsOccurIn(pair.getKey(), input)) pairs.add(pair);
         }
       }
     }
@@ -1120,23 +1120,10 @@ public class TextPanel extends BaseXPanel {
 
   /* Reads in the property file. */
   static {
-    for(int i = 0; i < 5; i++) LISTS.add(new ArrayList<>());
-    final String file = "/completions.properties";
-    final InputStream is = TextPanel.class.getResourceAsStream(file);
-    if(is == null) {
-      Util.errln(file + " not found.");
-    } else {
-      // add custom completions
-      try(NewlineInput nli = new NewlineInput(is)) {
-        for(String line; (line = nli.readLine()) != null;) {
-          final int i = line.indexOf('=');
-          if(i == -1 || Strings.startsWith(line, '#')) continue;
-          LISTS.get(0).add(new SimpleEntry<>(line.substring(0, i),
-              line.substring(i + 1).replace("\\n", "\n")));
-        }
-      } catch(final IOException ex) {
-        Util.errln(ex);
-      }
+    for(int l = 0; l < 5; l++) LISTS.add(new ArrayList<>());
+    final TokenMap map = Util.properties("completions.properties");
+    for(final byte[] key : map) {
+      LISTS.get(0).add(new SimpleEntry<>(Token.string(key), Token.string(map.get(key))));
     }
     // add functions (default functions first)
     for(final FuncDefinition fd : Functions.DEFINITIONS) {
