@@ -12,7 +12,7 @@ import org.basex.util.list.*;
  * Text renderer, supporting syntax highlighting and highlighting of selected, erroneous
  * or linked text.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 final class TextRenderer extends BaseXBack {
@@ -158,15 +158,6 @@ final class TextRenderer extends BaseXBack {
     }
   }
 
-  /**
-   * Marks the current line as erroneous.
-   * @param g graphics reference
-   */
-  private void drawErrorLine(final Graphics g) {
-    g.setColor(GUIConstants.colormark2A);
-    g.fillRect(0, lineY, offset - OFFSET * 3 / 2, fontHeight);
-  }
-
   /**
    * Draws the line number separator.
    * @param g graphics reference
@@ -402,6 +393,15 @@ final class TextRenderer extends BaseXBack {
     }
   }
 
+  /**
+   * Marks the current line as erroneous.
+   * @param g graphics reference
+   */
+  private void markErrorLine(final Graphics g) {
+    g.setColor(GUIConstants.colormark2A);
+    g.fillRect(0, lineY, offset - OFFSET * 3 / 2, fontHeight);
+  }
+
   /**
    * Finishes the current token.
    * @param iter iterator
@@ -533,7 +533,7 @@ final class TextRenderer extends BaseXBack {
         parentheses.pop();
         final int cr = parentheses.pop(), yy = parentheses.pop(), xx = parentheses.pop();
         if(cpos == pos || cpos == cr) {
-         g.setColor(GUIConstants.color4);
+          g.setColor(GUIConstants.color4);
           g.drawRect(xx, yy - (fontHeight << 2) / 5, charWidth(open), fontHeight);
           g.drawRect(x, lineY, charWidth(cp), fontHeight);
         }
@@ -563,7 +563,7 @@ final class TextRenderer extends BaseXBack {
     final int s = Math.max(2, fontHeight / 6);
     g.setColor(GUIConstants.RED);
     for(int xp = x; xp < x + ww; xp += 2) g.drawLine(xp - 1, y + 2, xp, y + s + 1);
-    if(edit) drawErrorLine(g);
+    if(edit) markErrorLine(g);
   }
 
   /**
