@@ -43,23 +43,25 @@ import org.xml.sax.*;
 /**
  * This view allows the input and evaluation of queries and documents.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class EditorView extends View {
-  /** Delay for showing the please wait info. */
+  /** Delay for showing the "please wait" info. */
   private static final int WAIT_DELAY = 250;
   /** Delay for highlighting an error. */
   private static final int SEARCH_DELAY = 100;
   /** Link pattern. */
-  private static final Pattern LINK = Pattern.compile("(.*?), ([0-9]+)/([0-9]+)");
+  private static final Pattern LINK = Pattern.compile("(.*?), (\\d+)/(\\d+)");
 
   /** Project files. */
   final ProjectView project;
   /** Go button. */
-  final AbstractButton exec;
+  final AbstractButton go;
+  /** Indent button. */
+  final AbstractButton indent;
   /** Test button. */
-  final AbstractButton tests;
+  final AbstractButton test;
 
   /** History Button. */
   private final AbstractButton history;
@@ -123,32 +125,32 @@ public final class EditorView extends View {
 
     history = BaseXButton.get("c_history", BaseXLayout.addShortcut(RECENTLY_OPENED,
         BaseXKeys.HISTORY.toString()), false, gui);
+    go = BaseXButton.get("c_go", BaseXLayout.addShortcut(RUN_QUERY,
+        BaseXKeys.EXEC.toString()), false, gui);
     stop = BaseXButton.get("c_stop", STOP, false, gui);
     stop.setEnabled(false);
-    exec = BaseXButton.get("c_go", BaseXLayout.addShortcut(RUN_QUERY,
-        BaseXKeys.EXEC.toString()), false, gui);
-    tests = BaseXButton.get("c_test", BaseXLayout.addShortcut(RUN_TESTS,
+    indent = BaseXButton.command(GUIMenuCmd.C_INDENT_RESULT, gui);
+    test = BaseXButton.get("c_test", BaseXLayout.addShortcut(RUN_TESTS,
         BaseXKeys.TESTS.toString()), false, gui);
 
-    final BaseXBack buttons = new BaseXBack(false);
-    buttons.layout(new ColumnLayout());
+    final BaseXToolBar buttons = new BaseXToolBar();
     buttons.add(newB);
     buttons.add(openB);
     buttons.add(saveB);
     buttons.add(history);
-    buttons.add(Box.createHorizontalStrut(8));
-    buttons.add(find);
-    buttons.add(Box.createHorizontalStrut(8));
+    buttons.addSeparator();
+    buttons.add(go);
     buttons.add(stop);
-    buttons.add(exec);
     buttons.add(vars);
-    buttons.add(tests);
+    buttons.add(indent);
+    buttons.add(test);
+    buttons.addSeparator();
+    buttons.add(find);
 
-    context = new BaseXLabel("").resize(1.2f);
+    context = new BaseXLabel("").resize(1.25f);
     context.setForeground(dgray);
 
-    final BaseXBack north = new BaseXBack(false);
-    north.layout(new BorderLayout(10, 0));
+    final BaseXBack north = new BaseXBack(false).layout(new BorderLayout(10, 0)).border(0, 0, 4, 0);
     north.add(buttons, BorderLayout.WEST);
     north.add(context, BorderLayout.CENTER);
     north.add(new BaseXHeader(EDITOR), BorderLayout.EAST);
@@ -156,9 +158,8 @@ public final class EditorView extends View {
     // status and query pane
     search.editor(addTab(), false);
 
-    info = new BaseXLabel().setText(OK, Msg.SUCCESS).resize(1.2f);
-    pos = new BaseXLabel(" ").resize(1.2f);
-
+    info = new BaseXLabel().setText(OK, Msg.SUCCESS).resize(1.25f);
+    pos = new BaseXLabel(" ").resize(1.25f);
     posCode.invokeLater();
 
     final BaseXBack south = new BaseXBack(false).border(8, 0, 0, 0);
@@ -205,8 +206,8 @@ public final class EditorView extends View {
       stop.setEnabled(false);
       gui.stop();
     });
-    exec.addActionListener(e -> run(getEditor(), Action.EXECUTE));
-    tests.addActionListener(e -> run(getEditor(), Action.TEST));
+    go.addActionListener(e -> run(getEditor(), Action.EXECUTE));
+    test.addActionListener(e -> run(getEditor(), Action.TEST));
     tabs.addChangeListener(e -> {
       final EditorArea ea = getEditor();
       if(ea == null) return;
@@ -231,7 +232,7 @@ public final class EditorView extends View {
 
   @Override
   public void refreshMark() {
-    tests.setEnabled(getEditor().file().hasSuffix(IO.XQSUFFIXES));
+    test.setEnabled(getEditor().file().hasSuffix(IO.XQSUFFIXES));
   }
 
   @Override
@@ -242,6 +243,7 @@ public final class EditorView extends View {
     for(final EditorArea edit : editors()) edit.refreshLayout(mfont);
     project.refreshLayout();
     search.refreshLayout();
+    indent.setSelected(GUIMenuCmd.C_INDENT_RESULT.selected(gui));
   }
 
   @Override
@@ -302,8 +304,9 @@ public final class EditorView extends View {
    * Refreshes the context label.
    */
   public void refreshContextLabel() {
-    final String label = context();
-    context.setText(label.isEmpty() ? "" : CONTEXT + COLS + label);
+    String label = context();
+    label = label.isEmpty() ? "" : CONTEXT + COLS + label;
+    if(!context.getText().equals(label)) context.setText(label);
   }
 
   /**
@@ -339,7 +342,7 @@ public final class EditorView extends View {
     // check if database is opened
     if(value == null) {
       final Data data = gui.context.data();
-      if(data != null) value = Function._DB_OPEN.args(data.meta.name);
+      if(data != null) value = Function._DB_GET.args(data.meta.name);
     }
     // check if main-memory document exists
     if(value == null) {
@@ -572,7 +575,7 @@ public final class EditorView extends View {
       if(xquery) gui.execute(true, new Test(file.path()));
     } else if(action == Action.EXECUTE && script) {
       // execute script
-      gui.execute(true, new Execute(string(text)));
+      gui.execute(true, new Execute(string(text)).baseURI(file.path()));
     } else if(action == Action.EXECUTE || xquery) {
       // execute or parse query
       String input = string(text);
@@ -778,7 +781,7 @@ public final class EditorView extends View {
   /**
    * Processes the result from a command or query execution.
    * @param th exception or {@code null}
-   * @param stopped {@code true} if evaluation was interrupted
+   * @param stopped {@code true} if evaluation was stopped
    * @param refresh refresh buttons
    */
   public void info(final Throwable th, final boolean stopped, final boolean refresh) {
@@ -930,12 +933,12 @@ public final class EditorView extends View {
 
   /**
    * Updates the references to renamed files.
-   * @param old old file file reference
+   * @param old old file reference
    * @param renamed updated file reference
    */
   public void rename(final IOFile old, final IOFile renamed) {
     try {
-      // use canonical representation and add slash to names of directories
+      // use canonical representation and add slash to the directory names
       final boolean dir = renamed.isDir();
       final String oldPath = old.file().getCanonicalPath() + (dir ? File.separator : "");
       // iterate through all tabs
@@ -1039,7 +1042,7 @@ public final class EditorView extends View {
     final BaseXBack tab = new BaseXBack(false).layout(new BorderLayout(10, 0));
     tab.add(edit.label, BorderLayout.CENTER);
 
-    final AbstractButton close = tabButton("e_close", "e_close2");
+    final AbstractButton close = tabButton("e_close", "e_close_hover");
     close.addActionListener(e -> close(edit));
     tab.add(close, BorderLayout.EAST);
 
@@ -1069,7 +1072,7 @@ public final class EditorView extends View {
    */
   public boolean confirm(final EditorArea edit) {
     final boolean all = edit == null;
-     final EditorArea[] eas = all ? editors() : new EditorArea[] { edit };
+    final EditorArea[] eas = all ? editors() : new EditorArea[] { edit };
     final String[] buttons = all && eas.length > 1 ? new String[] { CLOSE_ALL } : new String[0];
 
     for(final EditorArea ea : eas) {
@@ -1110,6 +1113,6 @@ public final class EditorView extends View {
     for(final Component c : tabs.getComponents()) {
       if(c instanceof EditorArea) edits.add((EditorArea) c);
     }
-    return edits.toArray(new EditorArea[0]);
+    return edits.toArray(EditorArea[]::new);
   }
 }
