@@ -16,7 +16,7 @@ import org.basex.util.*;
 /**
  * This class stores the table on disk and reads it page-wise.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  * @author Tim Petrowsky
  */
@@ -228,6 +228,7 @@ public final class TableDiskAccess extends TableAccess {
 
   @Override
   protected void copy(final byte[] entries, final int first, final int last) {
+    dirty();
     for(int o = 0, i = first; i < last; ++i, o += IO.NODESIZE) {
       final int off = cursor(i);
       final Buffer buffer = buffers.current();
@@ -425,19 +426,6 @@ public final class TableDiskAccess extends TableAccess {
     nextPre = page + 1 < used && fPreIndex[page + 1] < meta.size ? fPreIndex[page + 1] : meta.size;
   }
 
-  @Override
-  protected void dirty() {
-    // initialize data structures required for performing updates
-    if(fPreIndex == null) {
-      fPreIndex = new int[pages];
-      for(int i = 0; i < pages; i++) fPreIndex[i] = i * IO.ENTRIES;
-      pageIndex = new int[pages];
-      for(int i = 0; i < pages; i++) pageIndex[i] = i;
-      usedPages = new BitArray(used, true);
-    }
-    dirty = true;
-  }
-
   @Override
   public String toString() {
     final StringBuilder sb = new StringBuilder();
@@ -452,6 +440,21 @@ public final class TableDiskAccess extends TableAccess {
 
   // PRIVATE METHODS ==============================================================================
 
+  /**
+   * Marks the data structures as dirty.
+   */
+  private void dirty() {
+    // initialize data structures required for performing updates
+    if(fPreIndex == null) {
+      fPreIndex = new int[pages];
+      for(int i = 0; i < pages; i++) fPreIndex[i] = i * IO.ENTRIES;
+      pageIndex = new int[pages];
+      for(int i = 0; i < pages; i++) pageIndex[i] = i;
+      usedPages = new BitArray(used, true);
+    }
+    dirty = true;
+  }
+
   /**
    * Searches for the page containing the entry for the specified pre value.
    * Reads the page and returns its offset inside the page.
@@ -597,7 +600,7 @@ public final class TableDiskAccess extends TableAccess {
   /**
    * Calculates the occupied space in a page.
    * @param index page index
-   * @return occupied space in number of records
+   * @return occupied space
    */
   private int occSpace(final int index) {
     return (index + 1 < used ? fPreIndex[index + 1] : meta.size) - fPreIndex[index];
