@@ -7,15 +7,15 @@ import static org.basex.util.Token.*;
 import java.io.*;
 import java.util.*;
 import java.util.Map.*;
-import java.util.function.*;
+import java.util.concurrent.atomic.*;
 
 import org.basex.build.json.*;
 import org.basex.build.json.JsonOptions.*;
 import org.basex.core.*;
 import org.basex.core.MainOptions.MainParser;
+import org.basex.core.cmd.*;
 import org.basex.core.jobs.*;
 import org.basex.core.locks.*;
-import org.basex.core.users.*;
 import org.basex.data.*;
 import org.basex.io.parse.json.*;
 import org.basex.io.serial.*;
@@ -26,7 +26,6 @@ import org.basex.query.func.java.*;
 import org.basex.query.iter.*;
 import org.basex.query.scope.*;
 import org.basex.query.up.*;
-import org.basex.query.util.*;
 import org.basex.query.util.collation.*;
 import org.basex.query.util.ft.*;
 import org.basex.query.util.hash.*;
@@ -46,7 +45,7 @@ import org.basex.util.list.*;
  * This class organizes both static and dynamic properties that are specific to a
  * single query.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class QueryContext extends Job implements Closeable {
@@ -55,28 +54,30 @@ public final class QueryContext extends Job implements Closeable {
   /** Static variables. */
   public final Variables vars = new Variables();
   /** Functions. */
-  public final StaticFuncs funcs = new StaticFuncs();
+  public final StaticFuncs functions = new StaticFuncs();
+  /** Query resources. */
+  public final QueryResources resources;
   /** Parent query context. */
   public final QueryContext parent;
-  /** Query info. */
-  public final QueryInfo info;
   /** Database context. */
   public final Context context;
-
-  /** Query resources. */
-  public QueryResources resources;
-  /** Update container; will be created if the first update is evaluated. */
-  public Updates updates;
+  /** Query info. */
+  public final QueryInfo info;
 
   /** Global database options (will be reassigned after query execution). */
   final QueryOptions options = new QueryOptions(this);
 
   /** Query threads. */
   public final QueryThreads threads = new QueryThreads();
+  /** User-defined locks. */
+  public final LockList locks = new LockList();
   /** Current query focus. */
   public QueryFocus focus = new QueryFocus();
   /** Date/time values. */
-  public QueryDateTime dateTime;
+  private QueryDateTime dateTime;
+
+  /** Update container; will be created if the first update is evaluated. */
+  public Updates updates;
 
   /** Full-text position data (needed for highlighting full-text results). */
   public FTPosData ftPosData = Prop.gui ? new FTPosData() : null;
@@ -92,9 +93,6 @@ public final class QueryContext extends Job implements Closeable {
   /** Available collations. */
   public TokenObjMap<Collation> collations;
 
-  /** User-defined locks. */
-  public final LockList locks = new LockList();
-
   /** Number of successive tail calls. */
   public int tailCalls;
   /** Maximum number of successive tail calls (will be set before compilation). */
@@ -114,23 +112,25 @@ public final class QueryContext extends Job implements Closeable {
   /** Stack of module files that are currently parsed. */
   final TokenList modStack = new TokenList();
 
-  /** Root expression of the query. */
-  public MainModule root;
-  /** Context value. */
-  public MainModule ctxValue;
-  /** Flag for binding the context item only once. */
-  public boolean ctxAssigned;
+  /** Main module (root expression). */
+  public MainModule main;
+  /** Context scope. */
+  public ContextScope contextScope;
+  /** Indicates if context scope exists and is final. */
+  public boolean finalContext;
 
-  /** Map with external variables to be bound at compile time. */
+  /** External variables and context to be bound at compile time. */
   private final QNmMap<Value> bindings = new QNmMap<>();
 
-  /** Serialization parameters. */
-  private SerializerOptions serParams;
+  /** Serialization options. */
+  private SerializerOptions sopts;
   /** Indicates if the default serialization parameters are used. */
   private boolean defaultOutput;
 
   /** Indicates if the query has been compiled. */
   private boolean compiled;
+  /** Indicates if the query has been optimized. */
+  private boolean optimized;
   /** Indicates if the query context has been closed. */
   private boolean closed;
 
@@ -139,9 +139,8 @@ public final class QueryContext extends Job implements Closeable {
    * @param parent parent context
    */
   public QueryContext(final QueryContext parent) {
-    this(parent.context, parent, parent.info);
+    this(parent.context, parent, parent.resources, parent.info);
     parent.pushJob(this);
-    resources = parent.resources;
     updates = parent.updates;
   }
 
@@ -150,8 +149,7 @@ public final class QueryContext extends Job implements Closeable {
    * @param context database context
    */
   public QueryContext(final Context context) {
-    this(context, null, null);
-    resources = new QueryResources(this);
+    this(context, null, null, null);
   }
 
   /**
@@ -159,17 +157,20 @@ public final class QueryContext extends Job implements Closeable {
    * @param context database context
    * @param parent parent context (can be {@code null})
    * @param info query info (can be {@code null})
+   * @param resources resources (can be {@code null})
    */
-  private QueryContext(final Context context, final QueryContext parent, final QueryInfo info) {
+  public QueryContext(final Context context, final QueryContext parent,
+      final QueryResources resources, final QueryInfo info) {
     this.context = context;
     this.parent = parent;
-    this.info = info != null ? info : new QueryInfo(this);
+    this.info = info != null ? info : new QueryInfo(context);
+    this.resources = resources != null ? resources : new QueryResources(this);
   }
 
   /**
    * Parses the specified query.
    * @param query query string
-   * @param uri base URI (may be {@code null})
+   * @param uri base URI (can be {@code null})
    * @return module
    * @throws QueryException query exception
    */
@@ -196,7 +197,7 @@ public final class QueryContext extends Job implements Closeable {
   /**
    * Parses the specified query.
    * @param query query string
-   * @param uri base URI (may be {@code null})
+   * @param uri base URI (can be {@code null})
    * @return main module
    * @throws QueryException query exception
    */
@@ -207,37 +208,33 @@ public final class QueryContext extends Job implements Closeable {
   /**
    * Parses the specified query and assigns the root expression.
    * @param query query string
-   * @param uri base URI (may be {@code null})
-   * @param sc static context (may be {@code null})
+   * @param uri base URI (can be {@code null})
+   * @param sc static context (can be {@code null})
    * @return main module
    * @throws QueryException query exception
    */
   public MainModule parseMain(final String query, final String uri, final StaticContext sc)
       throws QueryException {
 
-    info.query = query;
-    final QueryParser qp = new QueryParser(query, uri, this, sc);
-    root = qp.parseMain();
-    // updating expression: check if an updating expression is left in the expression tree
-    if(updating && !qp.sc.mixUpdates) updating = root.expr.has(Flag.UPD);
-    return root;
+    return run(info.parsing, () -> {
+      info.query = query;
+      main = new QueryParser(query, uri, this, sc).parseMain();
+      return main;
+    });
   }
 
   /**
    * Parses the specified module.
    * @param query query string
-   * @param uri base URI (may be {@code null})
+   * @param uri base URI (can be {@code null})
    * @return library module
    * @throws QueryException query exception
    */
   public LibraryModule parseLibrary(final String query, final String uri) throws QueryException {
-    info.query = query;
-    try {
+    return run(info.parsing, () -> {
+      info.query = query;
       return new QueryParser(query, uri, this, null).parseLibrary(true);
-    } finally {
-      // library module itself is not updating
-      updating = false;
-    }
+    });
   }
 
   /**
@@ -247,13 +244,13 @@ public final class QueryContext extends Job implements Closeable {
    * @throws QueryException query exception
    */
   public void assign(final StaticFunc func, final Expr... args) throws QueryException {
-    for(final StaticFunc sf : funcs.funcs()) {
+    for(final StaticFunc sf : functions.funcs()) {
       if(func.info.equals(sf.info)) {
         // inline arguments of called function
         sf.anns.addUnique(new Ann(sf.info, Annotation._BASEX_INLINE, Empty.VALUE));
         // create and assign function call
         final StaticFuncCall call = new StaticFuncCall(sf.name, args, sf.sc, sf.info).init(sf);
-        root = new MainModule(call, new VarScope(sf.sc));
+        main = new MainModule(call, new VarScope(sf.sc));
         updating = sf.updating();
         return;
       }
@@ -262,70 +259,89 @@ public final class QueryContext extends Job implements Closeable {
   }
 
   /**
-   * Compiles and optimizes the expression.
+   * Compiles the expression. Performs static optimizations.
    * @throws QueryException query exception
    */
   public void compile() throws QueryException {
-    checkStop();
     if(compiled) return;
-    info.runtime = false;
+    compiled = true;
 
-    final CompileContext cc = new CompileContext(this);
-    try {
-      // bind external variables and context (if not assigned yet by other APIs)
-      final MainOptions mopts = context.options;
-      if(root != null && parent == null) {
-        for(final Entry<String, String> entry : mopts.toMap(MainOptions.BINDINGS).entrySet()) {
-          final String key = entry.getKey();
-          final Atm atm = Atm.get(entry.getValue());
-          if(key.isEmpty()) {
-            context(atm, root.sc);
-          } else {
-            bind(qname(key, root.sc), atm);
-          }
-        }
-        final DBNodes nodes = context.current();
-        if(nodes != null && !ctxAssigned) {
-          final String name = nodes.data().meta.name;
-          if(!context.perm(Perm.READ, name)) throw BASEX_PERMISSION_X_X.get(null, Perm.READ, name);
-          context(resources.compile(nodes), root.sc);
-        }
-      }
-
-      // set database options
+    run(info.compiling, () -> {
+      // assign tail call option after compiling options
       options.compile();
-      // set tail call option after assigning database options
-      maxCalls = mopts.get(MainOptions.TAILCALLS);
+      maxCalls = context.options.get(MainOptions.TAILCALLS);
 
       // bind external variables
-      vars.bindExternal(this, bindings);
-
-      // compile context value
-      if(ctxValue != null) {
-        try {
-          ctxValue.comp(cc);
-          final Value v = ctxValue.value(this);
-          final SeqType st = root.sc.contextType;
-          focus.value = st == null ? v : st.promote(v, null, this, root.sc, null, true);
-        } catch(final QueryException ex) {
-          // only {@link ParseExpr} instances may lead to a missing context
-          throw ex.error() == NOCTX_X ? CIRCCTX.get(ctxValue.info) : ex;
+      if(parent == null) {
+        final Map<String, String> map = context.options.toMap(MainOptions.BINDINGS);
+        for(final Entry<String, String> entry : map.entrySet()) {
+          bind(entry.getKey(), Atm.get(entry.getValue()), null, main.sc);
         }
       }
+      vars.bindExternal(this, bindings);
 
-      try {
-        // compile the expression
-        if(root != null) QueryCompiler.compile(cc, root);
-        // compile static functions
-        else funcs.compile(cc);
-      } catch(final StackOverflowError ex) {
-        Util.debug(ex);
-        throw BASEX_OVERFLOW.get(null, ex);
+      return compile(false);
+    });
+  }
+
+  /**
+   * Optimizes the expression. Performs dynamic optimizations.
+   * @throws QueryException query exception
+   */
+  public void optimize() throws QueryException {
+    compile();
+    if(optimized) return;
+    optimized = true;
+
+    run(info.optimizing, () -> {
+      // bind context
+      final StaticContext sc = main.sc;
+      if(parent == null && !bindings.contains(QNm.EMPTY)) {
+        final DBNodes nodes = context.current();
+        if(nodes != null) bind(null, resources.compile(nodes), null, sc);
       }
+      final Value value = bindings.get(QNm.EMPTY);
+      if(value != null) contextScope = new ContextScope(value, sc.contextType, new VarScope(sc));
+      if(contextScope != null) finalContext = true;
+
+      return compile(true);
+    });
+  }
+
+  /**
+   * Compiles the expression.
+   * @param dynamic dynamic compilation
+   * @return {@code null}
+   * @throws QueryException query exception
+   */
+  private Void compile(final boolean dynamic) throws QueryException {
+    checkStop();
+
+    info.runtime = false;
+    try {
+      final CompileContext cc = new CompileContext(this, dynamic);
+      if(contextScope != null && dynamic) {
+        try {
+          contextScope.compile(cc);
+          focus.value = contextScope.value(this);
+        } catch(final QueryException ex) {
+          Util.debug(ex);
+          throw ex.error() == NOCTX_X ? CIRCCTX.get(ex.info()) : ex;
+        }
+      }
+      if(main != null) {
+        new QueryCompiler().compile(cc);
+      } else {
+        // required for XQueryParse
+        functions.compileAll(cc);
+      }
+    } catch(final StackOverflowError ex) {
+      Util.debug(ex);
+      throw BASEX_OVERFLOW.get(null, ex);
     } finally {
       info.runtime = true;
-      compiled = true;
     }
+    return null;
   }
 
   /**
@@ -334,8 +350,8 @@ public final class QueryContext extends Job implements Closeable {
    * @throws QueryException query exception
    */
   public Iter iter() throws QueryException {
-    compile();
-    return updating ? update().iter() : root.iter(this);
+    optimize();
+    return run(info.evaluating, () -> updating ? update().iter() : main.iter(this));
   }
 
   /**
@@ -344,8 +360,8 @@ public final class QueryContext extends Job implements Closeable {
    * @throws QueryException query exception
    */
   public Value value() throws QueryException {
-    compile();
-    return updating ? update() : root.value(this);
+    optimize();
+    return run(info.evaluating, () -> updating ? update() : main.value(this));
   }
 
   /**
@@ -360,7 +376,7 @@ public final class QueryContext extends Job implements Closeable {
   }
 
   /**
-   * Returns a reference to the updates container.
+   * Returns the updates container.
    * @return updates container
    */
   public synchronized Updates updates() {
@@ -374,81 +390,41 @@ public final class QueryContext extends Job implements Closeable {
     final Locks l = jc().locks;
     final LockList list = updating ? l.writes : l.reads;
 
-    if(root == null || !root.databases(l, this) ||
-        ctxValue != null && !ctxValue.databases(l, this)) {
-      // use global locking if referenced databases cannot be determined statically
-      list.addGlobal();
-    } else {
-      // add custom locks
+    // locks in main module (can be null if parsing failed)
+    boolean local = main == null || main.databases(new LockVisitor(list, contextScope == null));
+    // locks in context expression
+    if(local && contextScope != null) {
+      // check if scope may still be overwritten by dynamic context
+      if(!finalContext) list.add(Locking.CONTEXT);
+      local = contextScope.databases(new LockVisitor(list, true));
+    }
+    if(local) {
       list.add(locks);
+    } else {
+      // global locking, referenced databases cannot be determined statically
+      list.addGlobal();
     }
   }
 
   /**
-   * Binds the context value if no value has been assigned yet. The rules are the same
-   * as for {@link #bind(String, Object, String, StaticContext) binding variables}.
-   * @param value value to be bound
-   * @param type type (may be {@code null})
-   * @param sc static context
-   * @throws QueryException query exception
-   */
-  public void context(final Object value, final String type, final StaticContext sc)
-      throws QueryException {
-    context(cast(value, type), sc);
-  }
-
-  /**
-   * Binds the context value if no value has been assigned yet.
-   * @param value value to be bound
-   * @param sc static context
-   */
-  public void context(final Value value, final StaticContext sc) {
-    if(!ctxAssigned) {
-      ctxValue = new MainModule(value, new VarScope(sc));
-      ctxAssigned = true;
-    }
-  }
-
-  /**
-   * Binds a value to a global variable if no value has been assigned yet.
+   * Binds a value to a global variable or the context value.
+   * The arguments will be ignored if a value has already been assigned.
    * The specified type is interpreted as follows:
    * <ul>
    *   <li> If {@code "json"} is specified, the value is converted according to the rules
    *        specified in {@link JsonXQueryConverter}.</li>
    *   <li> Otherwise, the type is cast to the specified XDM type.</li>
    * </ul>
-   * If the value is an XQuery {@link Value}, it is directly assigned.
-   * Otherwise, it is cast to the XQuery data model, using a Java/XQuery mapping.
-   * @param name name of variable
-   * @param value value to be bound
+   * @param name name of variable; context value if empty string or {@code null}
+   * @param value value to be bound (object or XQuery {@link Value})
    * @param type type (may be {@code null})
    * @param sc static context
    * @throws QueryException query exception
    */
   public void bind(final String name, final Object value, final String type, final StaticContext sc)
       throws QueryException {
-    bind(name, cast(value, type), sc);
-  }
-
-  /**
-   * Binds a value to a global variable if no value has been assigned yet.
-   * @param name name of variable
-   * @param value value to be bound
-   * @param sc static context
-   * @throws QueryException query exception
-   */
-  public void bind(final String name, final Value value, final StaticContext sc)
-      throws QueryException {
-    bind(qname(name, sc), value);
-  }
-
-  /**
-   * Binds a value to a global variable if no value has been assigned yet.
-   * @param name name of variable
-   * @param value value to be bound
-   */
-  private void bind(final QNm name, final Value value) {
-    if(!bindings.contains(name)) bindings.put(name, value);
+    final QNm qnm = name == null || name.isEmpty() ? QNm.EMPTY : qname(name, sc);
+    if(!bindings.contains(qnm)) bindings.put(qnm, cast(value, type));
   }
 
   /**
@@ -461,24 +437,16 @@ public final class QueryContext extends Job implements Closeable {
     qc.info.evalInfo(string);
   }
 
-  /**
-   * Returns info on query compilation and evaluation.
-   * @return query info
-   */
-  public String info() {
-    return info.toString(this);
-  }
-
   /**
    * Returns query-specific or default serialization parameters.
    * @return serialization parameters
    */
-  public SerializerOptions serParams() {
-    if(serParams == null) {
-      serParams = new SerializerOptions(context.options.get(MainOptions.SERIALIZER));
-      defaultOutput = root != null;
+  public SerializerOptions parameters() {
+    if(sopts == null) {
+      sopts = new SerializerOptions(context.options.get(MainOptions.SERIALIZER));
+      defaultOutput = main != null;
     }
-    return serParams;
+    return sopts;
   }
 
   /**
@@ -506,11 +474,11 @@ public final class QueryContext extends Job implements Closeable {
   public FElem toXml(final boolean full) {
     // only show root node if functions or variables exist
     final QueryPlan plan = new QueryPlan(compiled, closed, full);
-    if(root != null) {
-      for(final StaticScope ss : QueryCompiler.usedDecls(root)) ss.toXml(plan);
-      root.toXml(plan);
+    if(main != null) {
+      for(final StaticScope ss : QueryCompiler.usedDecls(main)) ss.toXml(plan);
+      main.toXml(plan);
     } else {
-      funcs.toXml(plan);
+      functions.toXml(plan);
       vars.toXml(plan);
     }
     return plan.root();
@@ -526,6 +494,7 @@ public final class QueryContext extends Job implements Closeable {
   @Override
   public void close() {
     if(closed) return;
+
     closed = true;
     if(parent == null) {
       // topmost query: close resources (opened by compile step)
@@ -537,6 +506,9 @@ public final class QueryContext extends Job implements Closeable {
       parent.popJob();
     }
     options.close();
+
+    final Performance perf = jc().performance;
+    if(perf != null) info.serializing.addAndGet(perf.ns());
   }
 
   @Override
@@ -605,55 +577,58 @@ public final class QueryContext extends Job implements Closeable {
 
   @Override
   public String toString() {
-    return root != null ? QueryInfo.usedDecls(root) : info.query;
+    return main != null ? QueryInfo.usedDecls(main) : info.query;
   }
 
   // CLASS METHODS ================================================================================
 
   /**
    * This function is called by the GUI.
-   * Caches and returns the result of the specified query. If all nodes are of the same database
+   * Caches the result of the specified query. If all nodes are of the same database
    * instance, the returned value will be of type {@link DBNodes}.
+   * @param cmd query command
    * @param max maximum number of items to cache (negative: return full result)
-   * @return result of query
-   * @throws QueryException query exception
    */
-  Value cache(final int max) throws QueryException {
-    final int mx = max >= 0 ? max : Integer.MAX_VALUE;
-
-    // evaluates the query
-    final Iter iter = iter();
-    final ItemList items;
-    Item item;
-
-    // check if all results belong to the database of the input context
+  void cache(final AQuery cmd, final int max) {
+    final ItemList items = new ItemList();
+    final IntList pres = new IntList();
     final Data data = resources.globalData();
-    if(defaultOutput && data != null) {
-      final IntList pres = new IntList();
-      while((item = next(iter)) != null && item.data() == data && pres.size() < mx) {
-        pres.add(((DBNode) item).pre());
-      }
+    try {
+      optimize();
+      run(info.evaluating, () -> {
+        // evaluates the query
+        final int mx = max >= 0 ? max : Integer.MAX_VALUE;
+        final Iter iter = iter();
+        Item item;
 
-      // all results processed: return compact node sequence, attach full-text positions
-      final int ps = pres.size();
-      if(item == null || ps == mx) {
-        return ps == 0 ? Empty.VALUE : new DBNodes(data, pres.finish()).ftpos(ftPosData);
-      }
+        do {
+          // collect pre values if a database is opened globally
+          if(defaultOutput && data != null) {
+            while((item = next(iter)) != null && item.data() == data && pres.size() < mx) {
+              pres.add(((DBNode) item).pre());
+            }
+            // skip if all results have been collected
+            if(item == null || pres.size() == mx) break;
 
-      // otherwise, add nodes to standard iterator
-      items = new ItemList();
-      for(int p = 0; p < ps; p++) items.add(new DBNode(data, pres.get(p)));
-      items.add(item);
-    } else {
-      items = new ItemList();
+            // otherwise, add nodes to standard iterator
+            for(final int pre : pres.finish()) items.add(new DBNode(data, pre));
+            items.add(item);
+          }
+
+          // use standard iterator
+          while((item = next(iter)) != null && items.size() < mx) {
+            item.cache(false, null);
+            items.add(item);
+          }
+        } while(false);
+        return null;
+      });
+    } catch(final QueryException | JobException ex) {
+      cmd.exception = ex;
     }
-
-    // use standard iterator
-    while((item = next(iter)) != null && items.size() < mx) {
-      item.cache(false, null);
-      items.add(item);
-    }
-    return items.value();
+    // collect results
+    cmd.result = !items.isEmpty() ? items.value() :
+      !pres.isEmpty() ? new DBNodes(data, pres.finish()).ftpos(ftPosData) : Empty.VALUE;
   }
 
   // PRIVATE METHODS ==============================================================================
@@ -666,7 +641,7 @@ public final class QueryContext extends Job implements Closeable {
   private Value update() throws QueryException {
     try {
       // retrieve result
-      final Value value = root.value(this);
+      final Value value = main.value(this);
       // only perform updates if no parent context exists
       if(updates == null || parent != null) return value;
 
@@ -675,12 +650,8 @@ public final class QueryContext extends Job implements Closeable {
       final StringList dbs = updates.databases();
 
       final ValueBuilder vb = new ValueBuilder(this);
-      final QueryConsumer<Value> materialize = val -> {
-        final Predicate<Data> test = d -> {
-          return d != null && (datas.contains(d) || !d.inMemory() && dbs.contains(d.meta.name));
-        };
-        vb.add(val.materialize(test, null, this));
-      };
+      final QueryConsumer<Value> materialize = val -> vb.add(val.materialize(d -> d != null &&
+          (datas.contains(d) || !d.inMemory() && dbs.contains(d.meta.name)), null, this));
       materialize.accept(value);
       materialize.accept(updates.output(true));
 
@@ -698,7 +669,6 @@ public final class QueryContext extends Job implements Closeable {
 
   /**
    * Casts a value to the specified type.
-   * See {@link #bind(String, Object, String, StaticContext)} for more infos.
    * @param value value to be cast
    * @param type type (may be {@code null})
    * @return cast value
@@ -717,7 +687,7 @@ public final class QueryContext extends Job implements Closeable {
         object = strings.add(string.split("\1")).toArray();
       }
 
-      // sub types overriding the global value (value \2 type)
+      // subtypes overriding the global value (value \2 type)
       if(string.indexOf('\2') != -1) {
         final ValueBuilder vb = new ValueBuilder(this);
         for(final String str : strings) {
@@ -747,19 +717,19 @@ public final class QueryContext extends Job implements Closeable {
     }
 
     // parse target type
-    final StaticContext sc = root != null ? root.sc : new StaticContext(this);
+    final StaticContext sc = main != null ? main.sc : new StaticContext(this);
     final SeqType st = new QueryParser(type, null, this, sc).parseSeqType();
     if(st.eq(SeqType.EMPTY_SEQUENCE_Z)) return Empty.VALUE;
     final Type tp = st.type;
 
     // cast XDM values
     if(object instanceof Value) {
-      final Value vl = (Value) object;
+      final Value val = (Value) object;
       // cast single item
-      if(vl.isItem()) return tp.cast((Item) vl, this, sc, null);
+      if(val.isItem()) return tp.cast((Item) val, this, sc, null);
       // cast sequence
       final ValueBuilder vb = new ValueBuilder(this);
-      for(final Item item : vl) vb.add(tp.cast(item, this, sc, null));
+      for(final Item item : val) vb.add(tp.cast(item, this, sc, null));
       return vb.value(tp);
     }
 
@@ -774,6 +744,28 @@ public final class QueryContext extends Job implements Closeable {
     return tp.cast(object, this, null);
   }
 
+  /**
+   * Runs code and measures its runtime.
+   * @param code code to run
+   * @param runtime value storing the runtime
+   * @param <T> type of result value
+   * @return result
+   * @throws QueryException query exception
+   */
+  private <T> T run(final AtomicLong runtime, final QuerySupplier<T> code) throws QueryException {
+    Performance perf = jc().performance;
+    if(perf == null) {
+      perf = new Performance();
+    } else {
+      perf.ns();
+    }
+    try {
+      return code.get();
+    } finally {
+      runtime.addAndGet(perf.ns());
+    }
+  }
+
   /**
    * Converts the specified variable name to a QName.
    * @param name name of variable
