@@ -12,7 +12,7 @@ import org.basex.util.*;
 /**
  * This class contains all query error messages.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public enum QueryError {
@@ -32,7 +32,7 @@ public enum QueryError {
   /** Error code. */
   BASEX_DBPATH2_X(BASEX, "doc", "Database path '%' yields more than one document."),
   /** Error code. */
-  BASEX_CACHE_X(BASEX, "cache", "Value cannot be cached: %."),
+  BASEX_STORE_X(BASEX, "store", "Value cannot be stored: %."),
   /** Error code. */
   BASEX_WHICH_X(BASEX, "function", "Function not found: %."),
   /** Error code. */
@@ -119,15 +119,6 @@ public enum QueryError {
   /** Error code. */
   BIN_USO_X(BIN, "unknown-significance-order", "Unknown octet-order value: '%'."),
 
-  // Caching Module
-
-  /** Error code. */
-  CACHE_IO_X(CACHE, "io", "%"),
-  /** Error code. */
-  CACHE_NAME_X(CACHE, "name", "Invalid name: %."),
-  /** Error code. */
-  CACHE_NOTFOUND_X(CACHE, "not-found", "Cache '%' not found."),
-
   // Client Module
 
   /** Error code. */
@@ -321,6 +312,8 @@ public enum QueryError {
 
   // HTTP Module
 
+  /** Invalid URI. */
+  HC_URI_X(HC, 1, "Invalid URI: %"),
   /** Error code. */
   HC_ERROR_X(HC, 1, "%"),
   /** Error code. */
@@ -344,23 +337,23 @@ public enum QueryError {
   // Jobs Module
 
   /** Error code. */
-  JOBS_ID_EXISTS_X(JOBS, "id", "Job id already exists: %."),
+  JOBS_ID_EXISTS_X(JOB, "id", "Job id already exists: %."),
   /** Error code. */
-  JOBS_ID_INVALID_X(JOBS, "id", "Invalid job name: %."),
+  JOBS_ID_INVALID_X(JOB, "id", "Invalid job name: %."),
   /** Error code. */
-  JOBS_OPTIONS(JOBS, "options", "Either 'cache' or 'interval' option is allowed."),
+  JOBS_OPTIONS(JOB, "options", "Either 'cache' or 'interval' option is allowed."),
   /** Error code. */
-  JOBS_OVERFLOW(JOBS, "overflow", "Too many queries cached."),
+  JOBS_OVERFLOW(JOB, "overflow", "Too many queries cached."),
   /** Error code. */
-  JOBS_RANGE_X(JOBS, "range", "Value out of range: %."),
+  JOBS_RANGE_X(JOB, "range", "Value out of range: %."),
   /** Error code. */
-  JOBS_RUNNING_X(JOBS, "running", "Result is not available yet: %."),
+  JOBS_RUNNING_X(JOB, "running", "Result is not available yet: %."),
   /** Error code. */
-  JOBS_SELF_X(JOBS, "self", "Cannot wait for own job: %"),
+  JOBS_SELF_X(JOB, "self", "Cannot wait for own job: %"),
   /** Error code. */
-  JOBS_SERVICE(JOBS, "service", "No variables allowed."),
+  JOBS_SERVICE(JOB, "service", "No variables allowed."),
   /** Error code. */
-  JOBS_SERVICE_X_X(JOBS, "service", "Could not write service: %."),
+  JOBS_SERVICE_X_X(JOB, "service", "Could not write service: %."),
 
   // JSON Module
 
@@ -375,11 +368,6 @@ public enum QueryError {
   /** Error code. */
   JSON_OPTIONS_X(JSON, "options", "'%':'%' is not supported by the target format."),
 
-  // Output Module
-
-  /** Error code. */
-  OUTPUT_FORMAT_X_X(OUTPUT, "format", "%: %."),
-
   // Process Module
 
   /** Error code. */
@@ -452,6 +440,20 @@ public enum QueryError {
   /** Error code. */
   SQL_TYPE_X_X(SQL, "type", "Invalid type (%): %."),
 
+  // Store Module
+
+  /** Error code. */
+  STORE_IO_X(STORE, "io", "%"),
+  /** Error code. */
+  STORE_NAME_X(STORE, "name", "Invalid name: %."),
+  /** Error code. */
+  STORE_NOTFOUND_X(STORE, "not-found", "Cache '%' not found."),
+
+  // String Module
+
+  /** Error code. */
+  STRING_FORMAT_X_X(STRING, "format", "%: %."),
+
   // Unit Module
 
   /** Error code. */
@@ -480,7 +482,7 @@ public enum QueryError {
   /** Error code. */
   USER_LOGGEDIN_X(USER, "logged-in", "User '%' is currently logged in."),
   /** Error code. */
-  USER_NAME_X(USER, "name", "Invalid user name: '%'."),
+  USER_NAME_X(USER, "name", "Invalid username: '%'."),
   /** Error code. */
   USER_PASSWORD_X(USER, "password", "Wrong password supplied for user '%'."),
   /** Error code. */
@@ -562,7 +564,7 @@ public enum QueryError {
   /** Error code. */
   DIVZERO_X(FOAR, 1, "% cannot be divided by zero."),
   /** Error code. */
-  DIVFLOW_X(FOAR, 2, "Invalid division result: %."),
+  INVIDIV(FOAR, 2, "Invalid integer division: %."),
   /** Error code. */
   RANGE_X(FOAR, 2, "Value out of range: %."),
 
@@ -588,6 +590,8 @@ public enum QueryError {
   NORMUNI_X(FOCH, 3, "Unsupported normalization form ('%')."),
   /** Error code. */
   CHARCOLL(FOCH, 4, "Collation does not operate on character-by-character basis."),
+  /** Error code. */
+  CHARINV_X(FOCH, 5, "Invalid name or glyph: %."),
 
   /** Error code. */
   IDDOC(FODC, 1, "Specified node has no document node as root."),
@@ -676,7 +680,7 @@ public enum QueryError {
   ESCAPE_JSON_X(FOJS, 7, "Invalid escape sequence: %."),
 
   /** Error code. */
-  NSDECL_X(FONS, 4, "No namespace declared for prefix '%'."),
+  NSDECL_X(FONS, 4, "Namespace prefix not declared: %."),
 
   /** Error code. */
   INVALIDZONE_X(FORG, 1, "Invalid timezone: %."),
@@ -714,22 +718,22 @@ public enum QueryError {
   IETF_INV_X(FORG, 10, "Invalid input: '%'."),
 
   /** Error code. */
-  REGMOD_X(FORX, 1, "Invalid regular flag: '%'."),
+  REGFLAG_X(FORX, 1, "Invalid regular flag: '%'."),
   /** Error code. */
-  REGPAT_X(FORX, 2, "Invalid regular expression: %."),
+  REGINVALID_X(FORX, 2, "Invalid regular expression: %."),
   /** Error code. */
-  REGROUP_X(FORX, 3, "Pattern matches empty string: '%'."),
+  REGEMPTY_X(FORX, 3, "Pattern matches empty string: '%'."),
   /** Error code. */
-  FUNREPBS_X(FORX, 4, "Invalid backslash in replacement string: %."),
+  REGBACKSLASH_X(FORX, 4, "Invalid backslash in replacement string: %."),
   /** Error code. */
-  FUNREPDOL_X(FORX, 4, "Invalid dollar sign in replacement string: %."),
+  REGDOLLAR_X(FORX, 4, "Invalid dollar sign in replacement string: %."),
 
   /** Error code. */
-  FIATOM_X_X(FOTY, 13, "Items of type % cannot be atomized: %."),
+  FIATOMIZE_X(FOTY, 13, "Atomic value required, function item found: %."),
   /** Error code. */
-  FISTRING_X_X(FOTY, 14, "Items of type % have no string representation: %."),
+  FISTRING_X(FOTY, 14, "Function item has no string value: %."),
   /** Error code. */
-  FICMP_X_X(FOTY, 15, "Items of type % cannot be compared: %."),
+  FICOMPARE_X(FOTY, 15, "Function item cannot be compared: %."),
 
   /** Error code. */
   UPFOTYPE_X(FOUP, 1, "Document or element expected, % found."),
@@ -751,12 +755,10 @@ public enum QueryError {
   /** Error code. */
   RESNF_X(FOUT, 1170, "Resource '%' cannot be retrieved."),
   /** Error code. */
-  FRAGID_X(FOUT, 1170, "URI contains a fragment identifier: %"),
+  FRAGID_X(FOUT, 1170, "URI contains a fragment identifier: %."),
   /** Error code. */
   INVURL_X(FOUT, 1170, "URI is invalid: %"),
   /** Error code. */
-  STBASEURI(FOUT, 1170, "Static Base URI is undefined."),
-  /** Error code. */
   ENCODING_X(FOUT, 1190, "Unknown encoding '%'."),
   /** Error code. */
   INVCHARS_X(FOUT, 1190, "%."),
@@ -938,7 +940,7 @@ public enum QueryError {
   /** Error code. */
   NOTERNARY(XPST, 3, "Incomplete ternary if expression."),
   /** Error code. */
-  NOELVIS(XPST, 3, "Expecting default expression."),
+  NODEFAULT(XPST, 3, "Expecting default expression."),
   /** Error code. */
   NOIF(XPST, 3, "Incomplete 'if' expression."),
   /** Error code. */
@@ -993,10 +995,8 @@ public enum QueryError {
   ARROWSPEC(XPST, 3, "No specifier after arrow operator: '%'."),
   /** Error code. */
   CASTTYPE_X(XPST, 3, "%"),
-
   /** Error code. */
   STATIC_X(XPST, 5, "No XML Schema support: %."),
-
   /** Error code. */
   VARUNDEF_X(XPST, 8, "Undeclared variable: %."),
   /** Error code. */
@@ -1007,7 +1007,6 @@ public enum QueryError {
   TYPEUNDEF_X(XPST, 8, "Undefined type annotation: %."),
   /** Error code. */
   SCHEMAINV_X(XPST, 8, "Undefined schema name: %."),
-
   /** Error code. */
   FUNCPRIVATE_X(XPST, 17, "Function not visible: %."),
   /** Error code. */
@@ -1020,22 +1019,30 @@ public enum QueryError {
   ABSTRACTFUNC_X(XPST, 17, "No function exists for abstract type: %."),
   /** Error code. */
   FUNCNOIMPL_X(XPST, 17, "External function not implemented: %."),
-
   /** Error code. */
   JAVAINIT_X_X(XPST, 17, "%: %."),
   /** Error code. */
   JAVACLASS_X(XPST, 17, "Unknown class: %."),
   /** Error code. */
   JAVAMEMBER_X(XPST, 17, "Unknown method or field: %."),
-
   /** Error code. */
   TYPEUNKNOWN_X(XPST, 51, "Unknown type: %."),
   /** Error code. */
   INVALIDCAST_X(XPST, 80, "Invalid cast type: %."),
   /** Error code. */
-  NOURI_X(XPST, 81, "No namespace declared for QName '%'."),
+  NOURI_X(XPST, 81, "Namespace prefix not declared: %."),
   /** Error code. */
   NSMISS_X(XPST, 81, "QName '%' has no namespace."),
+  /** Error code. */
+  KEYWORDTWICE_X(XPST, 141, "Keyword supplied twice: %."),
+  /** Error code. */
+  ARGMISSING_X_X(XPST, 141, "%: No argument supplied for: %."),
+  /** Error code. */
+  ARGTWICE_X_X(XPST, 141, "%: Argument supplied twice for: %."),
+  /** Error code. */
+  KEYWORDUNKNOWN_X_X(XPST, 142, "%: Unknown keyword: %."),
+  /** Error code. */
+  KEYWORDSUPPORT_X(XPST, 142, "%: Keyword arguments not supported."),
 
   /** Error code. */
   JAVANOINSTANCE_X_X(XPTY, 4, "% instance expected as first argument, % found."),
@@ -1105,6 +1112,8 @@ public enum QueryError {
   /** Error code. */
   BINARY_X(XPTY, 4, "Binary expected, % found."),
   /** Error code. */
+  STRBIN_X_X(XPTY, 4, "String or binary expected, % found: %."),
+  /** Error code. */
   STRNOD_X_X(XPTY, 4, "String or node expected, % found: %."),
   /** Error code. */
   MAP_X_X(XPTY, 4, "Map expected, % found: %."),
@@ -1115,13 +1124,13 @@ public enum QueryError {
   /** Error code. */
   ELM_X_X(XPTY, 4, "element(%) expected: %."),
   /** Error code. */
-  STRBIN_X_X(XPTY, 4, "String or binary expected, % found: %."),
-  /** Error code. */
   INVALIDOPTION_X(XPTY, 4, "Unknown option '%'."),
   /** Error code. */
   FUNCUP_X(XPTY, 4, "Function is updating: %."),
   /** Error code. */
   FUNCNOTUP_X(XPTY, 4, "Function is not updating: %."),
+  /** Error code. */
+  UNKNOWNOP_X(XPTY, 4, "Unknown operator: %."),
 
   /** Error code. */
   MIXEDRESULTS(XPTY, 18, "Path returns both nodes and non-nodes."),
@@ -1155,7 +1164,7 @@ public enum QueryError {
   /** Error code. */
   INVQNAME_X(XQDY, 74, "Invalid QName: %."),
   /** Error code. */
-  NOQNNAMENS_X(XQDY, 74, "No namespace declared for QName '%'."),
+  NOQNNAMENS_X(XQDY, 74, "Namespace prefix not declared: %."),
   /** Error code. */
   CEXML(XQDY, 96, "XML prefix or namespace cannot be rebound: %/%."),
   /** Error code. */
@@ -1282,7 +1291,7 @@ public enum QueryError {
   /** Error code. */
   DUPLFUNVIS(XQST, 106, "More than one visibility annotation declared."),
   /** Error code. */
-  OPTDECL_X(XQST, 108, "Output declaration not allowed library module: %."),
+  OPTDECL_X(XQST, 108, "Output declaration not allowed in library module: %."),
   /** Error code. */
   OUTINVALID_X(XQST, 109, "%"),
   /** Error code. */
@@ -1421,11 +1430,8 @@ public enum QueryError {
    * @param message message
    */
   QueryError(final ErrType type, final int number, final String message) {
-    final StringBuilder sb = new StringBuilder(8).append(type);
     final String n = Integer.toString(number);
-    final int s = 4 - n.length();
-    for(int i = 0; i < s; i++) sb.append('0');
-    code = sb.append(n).toString();
+    code = type + "0".repeat(4 - n.length()) + n;
     uri = type.uri;
     prefix = type.prefix;
     this.message = message;
@@ -1462,7 +1468,7 @@ public enum QueryError {
 
   /**
    * Error types.
-   * @author BaseX Team 2005-22, BSD License
+   * @author BaseX Team 2005-23, BSD License
    * @author Leo Woerteler
    */
   public enum ErrType {
@@ -1471,7 +1477,6 @@ public enum QueryError {
     /** Error type. */ ADMIN(ADMIN_PREFIX,       ADMIN_URI),
     /** Error type. */ BASEX(BASEX_PREFIX,       BASEX_URI),
     /** Error type. */ ARCHIVE(ADMIN_PREFIX,     ARCHIVE_URI),
-    /** Error type. */ CACHE(CACHE_PREFIX,       CACHE_URI),
     /** Error type. */ CLIENT(CLIENT_PREFIX,     CLIENT_URI),
     /** Error type. */ CONVERT(CONVERT_PREFIX,   CONVERT_URI),
     /** Error type. */ CSV(CSV_PREFIX,           CSV_URI),
@@ -1482,22 +1487,22 @@ public enum QueryError {
     /** Error type. */ HTML(HTML_PREFIX,         HTML_URI),
     /** Error type. */ HASH(HASH_PREFIX,         HASH_URI),
     /** Error type. */ INSPECT(INSPECT_PREFIX,   INSPECT_URI),
-    /** Error type. */ JOBS(JOBS_PREFIX,         JOBS_URI),
+    /** Error type. */ JOB(JOB_PREFIX,           JOB_URI),
     /** Error type. */ JSON(JSON_PREFIX,         JSON_URI),
-    /** Error type. */ OUTPUT(OUTPUT_PREFIX,     OUTPUT_URI),
     /** Error type. */ PROC(PROC_PREFIX,         PROC_URI),
     /** Error type. */ PROF(PROF_PREFIX,         PROF_URI),
     /** Error type. */ RANDOM(RANDOM_PREFIX,     RANDOM_URI),
     /** Error type. */ REPO(REPO_PREFIX,         REPO_URI),
     /** Error type. */ REQUEST(REQUEST_PREFIX,   REQUEST_URI),
-    /** Error type. */ SESSION(SESSION_PREFIX,   SESSION_URI),
     /** Error type. */ SESSIONS(SESSIONS_PREFIX, SESSIONS_URI),
-    /** Error type. */ WS(WS_PREFIX,             WS_URI),
     /** Error type. */ SQL(SQL_PREFIX,           SQL_URI),
+    /** Error type. */ STORE(STORE_PREFIX,       STORE_URI),
+    /** Error type. */ STRING(STRING_PREFIX,     STRING_URI),
     /** Error type. */ UNIT(UNIT_PREFIX,         UNIT_URI),
     /** Error type. */ USER(USER_PREFIX,         USER_URI),
     /** Error type. */ VALIDATE(VALIDATE_PREFIX, VALIDATE_URI),
     /** Error type. */ WEB(WEB_PREFIX,           WEB_URI),
+    /** Error type. */ WS(WS_PREFIX,             WS_URI),
     /** Error type. */ XQUERY(XQUERY_PREFIX,     XQUERY_URI),
     /** Error type. */ XSLT(XSLT_PREFIX,         XSLT_URI),
 
@@ -1599,7 +1604,7 @@ public enum QueryError {
    */
   public static QueryException diffError(final Item item1, final Item item2, final InputInfo ii) {
     final Type type1 = item1.type, type2 = item2.type;
-    return type1 == type2 ? CMPTYPE_X_X_X.get(ii, type1, item1, item2) :
+    return type1.eq(type2) ? CMPTYPE_X_X_X.get(ii, type1, item1, item2) :
       CMPTYPES_X_X_X_X.get(ii, type1, type2, item1, item2);
   }
 
@@ -1607,14 +1612,14 @@ public enum QueryError {
    * Throws a type exception.
    * @param ii input info
    * @param expr expression
-   * @param type target type
+   * @param st target type
    * @param name name (can be {@code null})
    * @param promote promote or treat as
    * @return query exception
    */
-  public static QueryException typeError(final Expr expr, final SeqType type, final QNm name,
+  public static QueryException typeError(final Expr expr, final SeqType st, final QNm name,
       final InputInfo ii, final boolean promote) {
-    return typeError(expr, type, name, ii, promote ? INVPROMOTE_X_X_X : INVTREAT_X_X_X);
+    return typeError(expr, st, name, ii, promote ? INVPROMOTE_X_X_X : INVTREAT_X_X_X);
   }
 
   /**
