@@ -1,18 +1,25 @@
 package org.basex.query.expr;
 
 import static org.basex.query.QueryError.*;
-import static org.basex.query.QueryText.*;
+import static org.basex.query.func.Function.*;
 
+import java.util.*;
+
+import org.basex.data.*;
 import org.basex.index.*;
 import org.basex.query.*;
 import org.basex.query.CompileContext.*;
 import org.basex.query.expr.CmpV.*;
+import org.basex.query.expr.path.*;
 import org.basex.query.func.*;
 import org.basex.query.func.fn.*;
 import org.basex.query.iter.*;
 import org.basex.query.util.collation.*;
 import org.basex.query.util.index.*;
+import org.basex.query.util.list.*;
+import org.basex.query.value.*;
 import org.basex.query.value.item.*;
+import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
 import org.basex.query.var.*;
 import org.basex.util.*;
@@ -21,7 +28,7 @@ import org.basex.util.hash.*;
 /**
  * General comparison.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class CmpG extends Cmp {
@@ -123,6 +130,18 @@ public class CmpG extends Cmp {
       return name;
     }
 
+    /**
+     * Checks if this is one of the specified types.
+     * @param ops types
+     * @return result of check
+     */
+    public final boolean oneOf(final OpG... ops) {
+      for(final OpG op : ops) {
+        if(this == op) return true;
+      }
+      return false;
+    }
+
     /**
      * Returns the comparator for the specified value comparison operator.
      * @param opV operator to be found
@@ -143,15 +162,15 @@ public class CmpG extends Cmp {
 
   /**
    * Constructor.
+   * @param info input info
    * @param expr1 first expression
    * @param expr2 second expression
    * @param op operator
    * @param coll collation (can be {@code null})
    * @param sc static context
-   * @param info input info
    */
-  public CmpG(final Expr expr1, final Expr expr2, final OpG op, final Collation coll,
-      final StaticContext sc, final InputInfo info) {
+  public CmpG(final InputInfo info, final Expr expr1, final Expr expr2, final OpG op,
+      final Collation coll, final StaticContext sc) {
     super(info, expr1, expr2, coll, SeqType.BOOLEAN_O, sc);
     this.op = op;
   }
@@ -168,23 +187,21 @@ public class CmpG extends Cmp {
     final Type t1 = exprs[0].seqType().type.atomic(), t2 = exprs[1].seqType().type.atomic();
     if(t1 != null && t2 != null) {
       if(t1.isStringOrUntyped() && t2.isStringOrUntyped()) {
-        simplifyAll(Simplify.STRING, cc);
+        exprs = simplifyAll(Simplify.STRING, cc);
       } else if(t1.isNumber() && t2.isNumber()) {
-        simplifyAll(Simplify.NUMBER, cc);
+        exprs = simplifyAll(Simplify.NUMBER, cc);
       }
     }
 
+    // simplify operands
+    exprs = simplifyAll(Simplify.DISTINCT, cc);
+
     // swap operands
     if(swap()) {
-      cc.info(OPTSWAP_X, this);
+      cc.info(QueryText.OPTSWAP_X, this);
       op = op.swap();
     }
 
-    // simplify operands
-    for(int e = 0; e < 2; e++) {
-      exprs[e] = exprs[e].simplifyFor(Simplify.DISTINCT, cc);
-    }
-
     // optimize expression
     expr = opt(cc);
 
@@ -199,9 +216,9 @@ public class CmpG extends Cmp {
       final Expr expr1 = exprs[0], expr2 = exprs[1];
       final SeqType st1 = expr1.seqType(), st2 = expr2.seqType();
       final Type type1 = st1.type, type2 = st2.type;
-      // skip type check if types are identical (and a child instance of of any atomic type)
+      // skip type check if types are identical (and a child instance of any atomic type)
       check = !(type1 == type2 && !AtomType.ANY_ATOMIC_TYPE.instanceOf(type1) &&
-          (type1.isSortable() || op != OpG.EQ && op != OpG.NE) || comparable(type1, type2));
+          (type1.isSortable() || !op.oneOf(OpG.EQ, OpG.NE)) || comparable(type1, type2));
 
       CmpHashG hash = null;
       if(st1.zeroOrOne() && !st1.mayBeArray() && st2.zeroOrOne() && !st2.mayBeArray()) {
@@ -213,7 +230,7 @@ public class CmpG extends Cmp {
           type1.isStringOrUntyped() && type2.isStringOrUntyped()) && !st2.zeroOrOne()) {
         // hash-based comparisons
         hash = this instanceof CmpHashG ? (CmpHashG) this :
-          new CmpHashG(expr1, expr2, op, null, sc, info);
+          new CmpHashG(expr1, expr2, op, sc, info);
         expr = hash;
       }
       // pre-evaluate expression; discard hashed results
@@ -236,23 +253,34 @@ public class CmpG extends Cmp {
    */
   private Expr optArith(final CompileContext cc) throws QueryException {
     final Expr expr1 = exprs[0], expr2 = exprs[1];
-    if(expr1 instanceof Arith) {
-      final Arith arith = (Arith) expr1;
-      final Expr op1 = arith.arg(0), op2 = arith.arg(1);
-      final Calc calc = arith.calc;
-      if(calc == Calc.MINUS && op2.seqType().instanceOf(SeqType.NUMERIC_O) && expr2 == Int.ZERO) {
-        // sum(A) - sum(B) = 0  ->  sum(A) = sum(B)
-        return new CmpG(op1, op2, op, coll, sc, info).optimize(cc);
-      }
-      if(calc != Calc.MOD && calc != Calc.IDIV && op2 instanceof ANum &&
-        (expr2 instanceof ANum || expr2 instanceof Arith && expr2.arg(1) instanceof ANum)) {
-        // count(E) div 2 = 1  ->  count(E) = 1 * 2
-        // $a - 1 = $b + 1  ->  $a = $b + 2
-        final Expr arg2 = new Arith(info, expr2, op2, calc.invert()).optimize(cc);
-        return new CmpG(op1, arg2, op, coll, sc, info).optimize(cc);
+    Expr ex = null;
+
+    if(expr1 instanceof Arith && expr2.seqType().instanceOf(SeqType.NUMERIC_O)) {
+      final Expr op11 = expr1.arg(0), op12 = expr1.arg(1), op22 = expr2.arg(1);
+      final double num12 = op12 instanceof ANum ? ((ANum) op12).dbl() : Double.NaN;
+      if(op12.seqType().instanceOf(SeqType.NUMERIC_O)) {
+        final Calc calc1 = ((Arith) expr1).calc;
+        if(calc1 == Calc.MINUS && expr2 == Int.ZERO) {
+          // E - NUMERIC = 0  ->  E = NUMERIC
+          ex = new CmpG(info, op11, op12, op, coll, sc);
+        } else if((
+          Function.POSITION.is(op11) ||
+          !Double.isNaN(num12) &&
+          (expr2 instanceof ANum || expr2 instanceof Arith && op22 instanceof ANum)
+        ) && (
+          calc1.oneOf(Calc.PLUS, Calc.MINUS) ||
+          calc1.oneOf(Calc.MULT, Calc.DIV) && num12 != 0 && (op.oneOf(OpG.EQ, OpG.NE) || num12 > 0)
+        )) {
+          // position() + 1 < last()  ->  position() < last() - 1
+          // count(E) div 2 = 1  ->  count(E) = 1 * 2
+          // $a - 1 = $b + 1  ->  $a = $b + 2
+          // $x * -1 = 1  ->  $x = 1 div -1  (no rewrite if RHS if */div (<,<=,>=,>) is negative)
+          final Expr arg2 = new Arith(info, expr2, op12, calc1.invert()).optimize(cc);
+          ex = new CmpG(info, op11, arg2, op, coll, sc);
+        }
       }
     }
-    return this;
+    return ex != null ? ex.optimize(cc) : this;
   }
 
   @Override
@@ -375,7 +403,7 @@ public class CmpG extends Cmp {
     final Expr expr1 = exprs[0], expr2 = exprs[1];
     final SeqType st1 = expr1.seqType(), st2 = expr2.seqType();
     return st1.one() && !st1.mayBeArray() && st2.one() && !st2.mayBeArray() ?
-      new CmpG(expr1, expr2, op.invert(), coll, sc, info) : null;
+      new CmpG(info, expr1, expr2, op.invert(), coll, sc) : null;
   }
 
   @Override
@@ -413,7 +441,7 @@ public class CmpG extends Cmp {
     final Expr exprL = exprs[0], exprR1 = exprs[1], exprR2 = cmp2.exprs[1];
     final QueryFunction<OpG, Expr> newList = newOp -> {
       final Expr exprR = List.get(cc, info, exprR1, exprR2);
-      return new CmpG(exprL, exprR, newOp, coll, sc, info).optimize(cc);
+      return new CmpG(info, exprL, exprR, newOp, coll, sc).optimize(cc);
     };
 
     // check if comparisons can be merged
@@ -446,6 +474,84 @@ public class CmpG extends Cmp {
     return expr2;
   }
 
+  @Override
+  public Expr simplifyFor(final Simplify mode, final CompileContext cc) throws QueryException {
+    // E[local-name() = 'a']  ->  E[self::*:a]
+    return cc.simplify(this, mode.oneOf(Simplify.EBV, Simplify.PREDICATE) ? optPred(cc) : this,
+      mode);
+  }
+
+  /**
+   * Optimizes this expression as predicate.
+   * @param cc compilation context
+   * @return resulting expression
+   * @throws QueryException query exception
+   */
+  private Expr optPred(final CompileContext cc) throws QueryException {
+    final Value val = cc.qc.focus.value;
+    if(val == null) return this;
+
+    final Type type = val.seqType().type;
+    final Expr expr1 = exprs[0], expr2 = exprs[1];
+    final OpV opV = opV();
+    if(type instanceof NodeType && type != NodeType.NODE && expr1 instanceof ContextFn &&
+        expr2 instanceof Value && opV == OpV.EQ) {
+      // skip functions that do not refer to the current context item
+      final ContextFn func = (ContextFn) expr1;
+      final Value value = (Value) expr2;
+      if(func.exprs.length > 0 && !(func.exprs[0] instanceof ContextValue)) return this;
+
+      final ArrayList<QNm> qnames = new ArrayList<>();
+      NamePart part = null;
+      if(expr2.seqType().type.isStringOrUntyped()) {
+        // local-name() eq 'a'  ->  self::*:a
+        if(LOCAL_NAME.is(func)) {
+          part = NamePart.LOCAL;
+          for(final Item item : value) {
+            final byte[] name = item.string(info);
+            if(XMLToken.isNCName(name)) qnames.add(new QNm(name));
+          }
+        } else if(NAMESPACE_URI.is(func)) {
+          // namespace-uri() = ('URI1', 'URI2')  ->  self::Q{URI1}* | self::Q{URI2}*
+          for(final Item item : value) {
+            final byte[] uri = item.string(info);
+            if(Token.eq(Token.normalize(uri), uri)) qnames.add(new QNm(Token.COLON, uri));
+          }
+          if(qnames.size() == value.size()) part = NamePart.URI;
+        } else if(NAME.is(func)) {
+          // (db-without-ns)[name() = 'city']  ->  (db-without-ns)[self::city]
+          final Data data = cc.qc.focus.value.data();
+          final byte[] dataNs = data != null ? data.defaultNs() : null;
+          if(dataNs != null && dataNs.length == 0) {
+            part = NamePart.LOCAL;
+            for(final Item item : value) {
+              final byte[] name = item.string(info);
+              if(XMLToken.isNCName(name)) qnames.add(new QNm(name));
+            }
+          }
+        }
+      } else if(NODE_NAME.is(func) && expr2.seqType().type == AtomType.QNAME) {
+        // node-name() = xs:QName('pref:local')  ->  self::pref:local
+        part = NamePart.FULL;
+        for(final Item item : value) {
+          qnames.add((QNm) item);
+        }
+      }
+
+      if(part != null) {
+        final ExprList paths = new ExprList(2);
+        for(final QNm qname : qnames) {
+          final Test test = new NameTest(qname, part, (NodeType) type, cc.sc().elemNS);
+          final Expr step = Step.get(cc, null, info, test);
+          if(step != Empty.VALUE) paths.add(Path.get(cc, info, null, step));
+        }
+        return paths.isEmpty() ? Bln.FALSE : paths.size() == 1 ? paths.get(0) :
+          new Union(info, paths.finish()).optimize(cc);
+      }
+    }
+    return this;
+  }
+
   @Override
   public final boolean indexAccessible(final IndexInfo ii) throws QueryException {
     // only equality expressions on default collation can be rewritten
@@ -463,7 +569,7 @@ public class CmpG extends Cmp {
 
   @Override
   public CmpG copy(final CompileContext cc, final IntObjMap<Var> vm) {
-    final CmpG cmp = new CmpG(exprs[0].copy(cc, vm), exprs[1].copy(cc, vm), op, coll, sc, info);
+    final CmpG cmp = new CmpG(info, exprs[0].copy(cc, vm), exprs[1].copy(cc, vm), op, coll, sc);
     cmp.check = check;
     return copyType(cmp);
   }
@@ -480,7 +586,7 @@ public class CmpG extends Cmp {
 
   @Override
   public final void toXml(final QueryPlan plan) {
-    plan.add(plan.create(this, OP, op.name), exprs);
+    plan.add(plan.create(this, QueryText.OP, op.name), exprs);
   }
 
   @Override
