@@ -3,7 +3,6 @@ package org.basex.query.expr;
 import org.basex.query.*;
 import org.basex.query.util.collation.*;
 import org.basex.query.value.item.*;
-import org.basex.query.value.seq.*;
 import org.basex.query.var.*;
 import org.basex.util.*;
 import org.basex.util.hash.*;
@@ -11,7 +10,7 @@ import org.basex.util.hash.*;
 /**
  * General comparison of two items.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class CmpSimpleG extends CmpG {
@@ -27,16 +26,16 @@ public final class CmpSimpleG extends CmpG {
    */
   CmpSimpleG(final Expr expr1, final Expr expr2, final OpG op, final Collation coll,
       final StaticContext sc, final InputInfo info, final boolean check) {
-    super(expr1, expr2, op, coll, sc, info);
+    super(info, expr1, expr2, op, coll, sc);
     this.check = check;
   }
 
   @Override
   public Bln item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Item item1 = exprs[0].item(qc, info);
-    if(item1 == Empty.VALUE) return Bln.FALSE;
+    if(item1.isEmpty()) return Bln.FALSE;
     final Item item2 = exprs[1].item(qc, info);
-    return item2 == Empty.VALUE ? Bln.FALSE : Bln.get(eval(item1, item2));
+    return item2.isEmpty() ? Bln.FALSE : Bln.get(eval(item1, item2));
   }
 
   @Override
