@@ -5,6 +5,7 @@ import java.util.*;
 import org.basex.data.*;
 import org.basex.query.*;
 import org.basex.query.CompileContext.*;
+import org.basex.query.expr.CmpV.*;
 import org.basex.query.expr.constr.*;
 import org.basex.query.expr.gflwor.*;
 import org.basex.query.expr.path.*;
@@ -28,7 +29,7 @@ import org.basex.util.hash.*;
  * Abstract class for representing XQuery expressions.
  * Expression are divided into {@link ParseExpr} and {@link Value} classes.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public abstract class Expr extends ExprInfo {
@@ -169,13 +170,6 @@ public abstract class Expr extends ExprInfo {
     return null;
   }
 
-  /**
-   * Assigns a data reference, if supported.
-   * @param dt data reference
-   */
-  public void data(@SuppressWarnings("unused") final Data dt) {
-  }
-
   /**
    * Returns the result size, or {@code -1} if the size is unknown.
    * @return result of check
@@ -197,7 +191,7 @@ public abstract class Expr extends ExprInfo {
    * @return {@code true} if the variable is used
    */
   public final boolean uses(final Var var) {
-    // return true iff the the search was aborted, i.e. the variable is used
+    // return true iff the search was aborted, i.e. the variable is used
     return !accept(new ASTVisitor() {
       @Override
       public boolean used(final VarRef ref) {
@@ -247,7 +241,7 @@ public abstract class Expr extends ExprInfo {
 
   /**
    * Inlines an expression into this one, replacing all variable or context references.
-   * This function is called by {@link InlineContext#inline(Expr)} (see invocations of this
+   * This function is called by {@link InlineContext#inline(Expr)} (see invocations of these
    * functions for further inlinings).
    *
    * The variable reference is replaced in:
@@ -280,24 +274,40 @@ public abstract class Expr extends ExprInfo {
   public abstract Expr copy(CompileContext cc, IntObjMap<Var> vm);
 
   /**
-   * This function is called at compile time for expressions whose operands might be simplified.
+   * Simplifies the expression. Overwritten by many expressions;
+   * calls {@link #simplify(Simplify, CompileContext)} otherwise.
    * @param mode mode of simplification
    * @param cc compilation context
    * @return simplified or original expression
    * @see Simplify
    * @throws QueryException query exception
    */
-  @SuppressWarnings("unused")
   public Expr simplifyFor(final Simplify mode, final CompileContext cc) throws QueryException {
-    // return true if a deterministic expression returns at least one node
+    return simplify(mode, cc);
+  }
+
+  /**
+   * Simplifies the expression.
+   * @param mode mode of simplification
+   * @param cc compilation context
+   * @return simplified or original expression
+   * @see Simplify
+   * @throws QueryException query exception
+   */
+  public final Expr simplify(final Simplify mode, final CompileContext cc) throws QueryException {
     Expr expr = this;
     if(mode.oneOf(Simplify.EBV, Simplify.PREDICATE)) {
-      if(seqType().instanceOf(SeqType.NODE_OM) && !has(Flag.NDT)) expr = Bln.TRUE;
-    } else if(mode == Simplify.COUNT) {
+      // boolean(<a/>)  ->  true()
+      // E[()]  ->  E[false()]
+      final SeqType st = seqType();
+      final boolean nodes = st.instanceOf(SeqType.NODE_OM);
+      if((nodes || st.zero()) && !has(Flag.NDT)) expr = Bln.get(nodes);
+    } else if(mode == Simplify.COUNT && !(this instanceof Value)) {
+      // count(db:get('db')//with-known-result-size)  ->  replicate('', size)
       final long size = size();
       if(size != -1 && !has(Flag.NDT)) expr = SingletonSeq.get(Str.EMPTY, size);
     }
-    return cc.simplify(this, expr);
+    return expr != this ? cc.simplify(this, expr, mode) : this;
   }
 
   /**
@@ -334,11 +344,25 @@ public abstract class Expr extends ExprInfo {
 
   /**
    * Returns the specified argument/operand of an expression (function, list, etc).
-   * @param i index of argument
-   * @return arguments or {@code null}
+   * @param a index of argument
+   * @return argument or {@link Empty#UNDEFINED} if argument is undefined
    */
-  public final Expr arg(final int i) {
-    return args()[i];
+  public final Expr arg(final int a) {
+    final Expr[] args = args();
+    return args != null && a < args.length ? args[a] : Empty.UNDEFINED;
+  }
+
+  /**
+   * Optimizes an expression for positional access.
+   * Overwritten by {@link Int}, {@link Range}, {@link RangeSeq}}.
+   * @param op comparison operator
+   * @param cc compilation context
+   * @return boolean result, optimized or original expression
+   * @throws QueryException query exception
+   */
+  @SuppressWarnings("unused")
+  public Expr optimizePos(final OpV op, final CompileContext cc) throws QueryException {
+    return this;
   }
 
   /**
@@ -388,7 +412,7 @@ public abstract class Expr extends ExprInfo {
    * Tries to merge two expressions that are part of an EBV test.
    * Called by {@link And}, {@link Or}), {@link Step} and {@link Filter}.
    * Overwritten by {@link CmpG}, {@link CmpIR}, {@link CmpR}, {@link CmpSR},
-   * {@link ItrPos}, {@link Pos} and others.
+   * {@link IntPos}, {@link SimplePos} and others.
    * @param expr second expression
    * @param or union or intersection
    * @param cc compilation context
@@ -422,7 +446,7 @@ public abstract class Expr extends ExprInfo {
    * @param exprs expressions to visit
    * @return success flag
    */
-  protected static boolean visitAll(final ASTVisitor visitor, final Expr...exprs) {
+  protected static boolean visitAll(final ASTVisitor visitor, final Expr... exprs) {
     for(final Expr expr : exprs) {
       if(!expr.accept(visitor)) return false;
     }
@@ -430,7 +454,7 @@ public abstract class Expr extends ExprInfo {
   }
 
   /**
-   * Counts the number of expressions in this expression's sub-tree.
+   * Counts the number of expressions in this expression's subtree.
    * This method is e.g. called by {@link StaticFunc#inline} to check if an expression
    * is small enough to be inlined.
    * @return number of expressions
@@ -470,8 +494,7 @@ public abstract class Expr extends ExprInfo {
    *   <li>{@link CmpG#optimize(CompileContext)} or {@link CmpV#optimize(CompileContext)},
    *     in order to pre-evaluate equality tests.
    *   </li>
-   *   <li>{@link CmpG#optimize(CompileContext)} or
-   *     {@link Pos#get(Expr, CmpV.OpV, InputInfo, CompileContext)},
+   *   <li>{@link CmpG#optimize(CompileContext)},
    *     in order to compare the start and end value.
    *   </li>
    *   <li>{@link PathCache}, in order to find identical root values at runtime.
