@@ -3,7 +3,6 @@ package org.basex.query.expr;
 import org.basex.query.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
-import org.basex.query.value.seq.*;
 import org.basex.query.var.*;
 import org.basex.util.*;
 import org.basex.util.hash.*;
@@ -11,7 +10,7 @@ import org.basex.util.hash.*;
 /**
  * Simple map expression: item-based evaluation, no positional access.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ItemMap extends SimpleMap {
@@ -32,7 +31,7 @@ public final class ItemMap extends SimpleMap {
     final Value value = qf.value;
     try {
       final int el = exprs.length;
-      for(int e = 1; e < el && item != Empty.VALUE; e++) {
+      for(int e = 1; e < el && !item.isEmpty(); e++) {
         qf.value = item;
         item = exprs[e].item(qc, info);
       }
