@@ -15,14 +15,13 @@ import org.basex.query.value.array.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.map.*;
 import org.basex.query.value.node.*;
-import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 
 /**
  * Abstract parse expression. All non-value expressions are derived from this class.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public abstract class ParseExpr extends Expr {
@@ -65,7 +64,7 @@ public abstract class ParseExpr extends Expr {
   public final Item ebv(final QueryContext qc, final InputInfo ii) throws QueryException {
     if(seqType().zeroOrOne()) {
       final Item item = item(qc, info);
-      return item == Empty.VALUE ? Bln.FALSE : item;
+      return item.isEmpty() ? Bln.FALSE : item;
     }
 
     final Iter iter = iter(qc);
@@ -96,10 +95,14 @@ public abstract class ParseExpr extends Expr {
     return exprType.size();
   }
 
+  @Override
+  public Data data() {
+    return exprType.data();
+  }
+
   @Override
   public final void refineType(final Expr expr) {
     exprType.refine(expr);
-    if(data() == null) data(expr.data());
   }
 
   @Override
@@ -110,13 +113,13 @@ public abstract class ParseExpr extends Expr {
   // OPTIMIZATIONS ================================================================================
 
   /**
-   * Copies this expression's type to the specified expression.
+   * Assigns this expression's type to the specified expression.
    * @param <T> expression type
    * @param expr expression to be modified
    * @return specified expression
    */
   public final <T extends Expr> T copyType(final T expr) {
-    expr.refineType(this);
+    if(expr instanceof ParseExpr) ((ParseExpr) expr).exprType.assign(this);
     return expr;
   }
 
@@ -127,26 +130,9 @@ public abstract class ParseExpr extends Expr {
    */
   public final ParseExpr adoptType(final Expr expr) {
     exprType.assign(expr);
-    if(data() == null) data(expr.data());
     return this;
   }
 
-  /**
-   * Returns the common data reference for all expressions.
-   * @param exprs expressions
-   * @return data reference or {@code null}
-   */
-  static Data data(final Expr... exprs) {
-    Data data1 = null;
-    for(final Expr expr : exprs) {
-      if(expr.seqType().zero()) continue;
-      final Data data2 = expr.data();
-      if(data1 == null) data1 = data2;
-      if(data1 == null || data1 != data2) return null;
-    }
-    return data1;
-  }
-
   // VALIDITY CHECKS ==============================================================================
 
   /**
@@ -228,59 +214,58 @@ public abstract class ParseExpr extends Expr {
   // CONVERSIONS ==================================================================================
 
   /**
-   * Checks if the specified expression yields a string.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a token.
+   * @param expr expression
    * @param qc query context
    * @return token
    * @throws QueryException query exception
    */
   protected final byte[] toToken(final Expr expr, final QueryContext qc) throws QueryException {
     final Item item = expr.atomItem(qc, info);
-    if(item == Empty.VALUE) throw EMPTYFOUND_X.get(info, STRING);
+    if(item.isEmpty()) throw EMPTYFOUND_X.get(info, STRING);
     return toToken(item);
   }
 
   /**
-   * Checks if the specified expression yields a string or an empty sequence.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a token.
+   * @param expr expression
    * @param qc query context
    * @return token (zero-length if result is an empty sequence)
    * @throws QueryException query exception
    */
   protected final byte[] toZeroToken(final Expr expr, final QueryContext qc) throws QueryException {
     final Item item = expr.atomItem(qc, info);
-    return item == Empty.VALUE ? Token.EMPTY : toToken(item);
+    return item.isEmpty() ? Token.EMPTY : toToken(item);
   }
 
   /**
-   * Checks if the specified expression yields a string or an empty sequence.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a token.
+   * @param expr expression
    * @param qc query context
-   * @return token, or {@code null} if result is an empty sequence
+   * @return token, or {@code null} if the expression yields an empty sequence
    * @throws QueryException query exception
    */
   protected final byte[] toTokenOrNull(final Expr expr, final QueryContext qc)
       throws QueryException {
     final Item item = expr.atomItem(qc, info);
-    return item != Empty.VALUE ? toToken(item) : null;
+    return item.isEmpty() ? null : toToken(item);
   }
 
   /**
-   * Checks if the specified non-empty item is a string.
-   * @param item item to be checked
+   * Converts an item to a token.
+   * @param item item to be converted
    * @return token
    * @throws QueryException query exception
    */
   protected final byte[] toToken(final Item item) throws QueryException {
     final Type type = item.type;
     if(type.isStringOrUntyped()) return item.string(info);
-    throw item instanceof FItem ? FIATOM_X_X.get(info, item.type, item) :
-      typeError(item, STRING, info);
+    throw item instanceof FItem ? FIATOMIZE_X.get(info, item) : typeError(item, STRING, info);
   }
 
   /**
-   * Checks if the specified expression yields a string.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a string.
+   * @param expr expression
    * @param qc query context
    * @return string
    * @throws QueryException query exception
@@ -290,8 +275,31 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a boolean.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a string.
+   * @param item item to be converted
+   * @return string
+   * @throws QueryException query exception
+   */
+  protected final String toString(final Item item) throws QueryException {
+    return Token.string(toToken(item));
+  }
+
+  /**
+   * Evaluates an expression to a string.
+   * @param expr expression
+   * @param qc query context
+   * @return string, or {@code null} if the expression yields an empty sequence
+   * @throws QueryException query exception
+   */
+  protected final String toStringOrNull(final Expr expr, final QueryContext qc)
+      throws QueryException {
+    final Item item = expr.atomItem(qc, info);
+    return item.isEmpty() ? null : toString(item);
+  }
+
+  /**
+   * Evaluates an expression to a boolean.
+   * @param expr expression
    * @param qc query context
    * @return boolean
    * @throws QueryException query exception
@@ -301,8 +309,21 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified item is a boolean.
-   * @param item item be checked
+   * Evaluates an expression to a boolean.
+   * @param expr expression
+   * @param qc query context
+   * @return boolean, or {@code false} if the expression yields an empty sequence
+   * @throws QueryException query exception
+   */
+  protected final boolean toBooleanOrFalse(final Expr expr, final QueryContext qc)
+      throws QueryException {
+    final Item item = expr.atomItem(qc, info);
+    return !item.isEmpty() && toBoolean(item);
+  }
+
+  /**
+   * Converts an item to a boolean.
+   * @param item item to be converted
    * @return boolean
    * @throws QueryException query exception
    */
@@ -314,8 +335,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a double.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a double number.
+   * @param expr expression
    * @param qc query context
    * @return double
    * @throws QueryException query exception
@@ -325,7 +346,7 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified item is a double.
+   * Converts an item to a double number.
    * @param item item
    * @return double
    * @throws QueryException query exception
@@ -336,21 +357,21 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a number or {@code null}.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a number.
+   * @param expr expression
    * @param qc query context
-   * @return double or {@code null}
+   * @return number, or {@code null} if the expression yields an empty sequence
    * @throws QueryException query exception
    */
   protected final ANum toNumberOrNull(final Expr expr, final QueryContext qc)
       throws QueryException {
     final Item item = expr.atomItem(qc, info);
-    return item != Empty.VALUE ? toNumber(item) : null;
+    return item.isEmpty() ? null : toNumber(item);
   }
 
   /**
-   * Checks if the specified, non-empty item is a double.
-   * @param item item to be checked
+   * Converts an item to a number.
+   * @param item item to be converted
    * @return number
    * @throws QueryException query exception
    */
@@ -361,8 +382,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a float.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a float number.
+   * @param expr expression
    * @param qc query context
    * @return float
    * @throws QueryException query exception
@@ -374,8 +395,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields an integer.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a long number.
+   * @param expr expression
    * @param qc query context
    * @return integer value
    * @throws QueryException query exception
@@ -385,8 +406,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified item is an integer.
-   * @param item item to be checked
+   * Converts an item to an integer number.
+   * @param item item to be converted
    * @return number
    * @throws QueryException query exception
    */
@@ -397,8 +418,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a node.
-   * @param expr expression to be evaluated
+   * Converts an item to a node.
+   * @param expr expression
    * @param qc query context
    * @return node
    * @throws QueryException query exception
@@ -408,20 +429,20 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a node or {@code null}.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a node.
+   * @param expr expression
    * @param qc query context
-   * @return node or {@code null}
+   * @return node, or {@code null} if the expression yields an empty sequence
    * @throws QueryException query exception
    */
   protected final ANode toNodeOrNull(final Expr expr, final QueryContext qc) throws QueryException {
     final Item item = expr.item(qc, info);
-    return item == Empty.VALUE ? null : toNode(item);
+    return item.isEmpty() ? null : toNode(item);
   }
 
   /**
-   * Checks if the specified non-empty item is a node.
-   * @param item item to be checked
+   * Converts an item to a node.
+   * @param item item to be converted
    * @return node
    * @throws QueryException query exception
    */
@@ -431,8 +452,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the evaluated expression yields a non-empty item.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to an item.
+   * @param expr expression
    * @param qc query context
    * @return item
    * @throws QueryException query exception
@@ -442,8 +463,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a non-empty item.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to an item of the given type.
+   * @param expr expression
    * @param qc query context
    * @param type expected type
    * @return item
@@ -455,8 +476,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the evaluated expression yields a non-empty item.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to an atomized item of the given type.
+   * @param expr expression
    * @param qc query context
    * @return atomized item
    * @throws QueryException query exception
@@ -466,8 +487,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields an element.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to an element.
+   * @param expr expression
    * @param qc query context
    * @return element
    * @throws QueryException query exception
@@ -477,8 +498,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a binary item.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a binary item.
+   * @param expr expression
    * @param qc query context
    * @return binary item
    * @throws QueryException query exception
@@ -488,8 +509,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified item is a binary item.
-   * @param item item to be checked
+   * Converts an item to a binary item.
+   * @param item item to be converted
    * @return binary item
    * @throws QueryException query exception
    */
@@ -499,8 +520,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a string or binary item.
-   * @param expr expression to be evaluated
+   * Evaluates an expression (token, binary item) to a byte array.
+   * @param expr expression
    * @param qc query context
    * @return byte array
    * @throws QueryException query exception
@@ -510,9 +531,9 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a Base64 item.
+   * Evaluates an expression to a Base64 item.
    * @param empty allow empty result
-   * @param expr expression to be evaluated
+   * @param expr expression
    * @param qc query context
    * @return Base64 item
    * @throws QueryException query exception
@@ -523,21 +544,20 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified item is a Base64 item.
-   * @param empty allow empty result
+   * Converts an item to a base64 item.
+   * @param empty return {@code null} if the given item is empty
    * @param item item
-   * @return Base64 item, or {@code null} if the argument is an empty sequence and if
-   *   {@code empty} is true
+   * @return Base64 item or {@code null}
    * @throws QueryException query exception
    */
   protected final B64 toB64(final Item item, final boolean empty) throws QueryException {
-    if(empty && item == Empty.VALUE) return null;
+    if(empty && item.isEmpty()) return null;
     return (B64) checkType(item, BASE64_BINARY);
   }
 
   /**
-   * Checks if the specified item is a string or binary item.
-   * @param item item to be checked
+   * Converts an item (token, binary item) to a byte array.
+   * @param item item to be converted
    * @return byte array
    * @throws QueryException query exception
    */
@@ -548,27 +568,27 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a QName.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a QName.
+   * @param expr expression
+   * @param empty return {@code null} if the expression yields an empty sequence
    * @param qc query context
-   * @param empty allow empty result
-   * @return QName
+   * @return QName or {@code null}
    * @throws QueryException query exception
    */
-  protected final QNm toQNm(final Expr expr, final QueryContext qc, final boolean empty)
+  protected final QNm toQNm(final Expr expr, final boolean empty, final QueryContext qc)
       throws QueryException {
     return toQNm(expr.atomItem(qc, info), empty);
   }
 
   /**
-   * Checks if the specified item is a QName.
+   * Converts an item to a QName.
    * @param item item
-   * @param empty allow empty result
-   * @return QName, or {@code null} if the item is {@code null} and {@code empty} is true
+   * @param empty return {@code null} if the given item is empty
+   * @return QName or {@code null}
    * @throws QueryException query exception
    */
   protected final QNm toQNm(final Item item, final boolean empty) throws QueryException {
-    if(empty && item == Empty.VALUE) return null;
+    if(empty && item.isEmpty()) return null;
     final Type type = checkNoEmpty(item, QNAME).type;
     if(type == QNAME) return (QNm) item;
     if(type.isUntyped()) throw NSSENS_X_X.get(info, type, QNAME);
@@ -576,8 +596,8 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a function.
-   * @param expr expression to be evaluated
+   * Evaluates an expression to a function item.
+   * @param expr expression
    * @param qc query context
    * @return function item
    * @throws QueryException query exception
@@ -587,7 +607,7 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields a map.
+   * Evaluates an expression to a map.
    * @param expr expression
    * @param qc query context
    * @return map
@@ -598,10 +618,10 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified item is a map.
+   * Converts an item to a map.
    * @param item item to check
    * @return map
-   * @throws QueryException if the item is not a map
+   * @throws QueryException query exception
    */
   protected final XQMap toMap(final Item item) throws QueryException {
     if(item instanceof XQMap) return (XQMap) item;
@@ -609,7 +629,19 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields an array.
+   * Converts an item to an array member.
+   * @param item item to check
+   * @return member
+   * @throws QueryException query exception
+   */
+  protected final Value toMember(final Item item) throws QueryException {
+    final XQMap map = toMap(item);
+    if(map.mapSize() == 1 && map.contains(Str.VALUE, info)) return map.get(Str.VALUE, info);
+    throw INVCONVERT_X_X_X.get(info, item.type, "record(value as item()*)", item);
+  }
+
+  /**
+   * Evaluates an expression to an array.
    * @param expr expression
    * @param qc query context
    * @return array
@@ -620,7 +652,7 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Assures that the specified item item is an array.
+   * Converts an item to an array.
    * @param item item to check
    * @return the array
    * @throws QueryException if the item is not an array
@@ -631,24 +663,23 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified expression yields an item of the specified atomic type.
-   * @param expr expression to be evaluated
+   * Evaluates an expression and returns an item if it has the specified type.
+   * @param expr expression
+   * @param type expected type
    * @param qc query context
-   * @param type type to be checked
    * @return item
    * @throws QueryException query exception
    */
-  protected final Item checkType(final Expr expr, final QueryContext qc, final AtomType type)
+  protected final Item checkType(final Expr expr, final AtomType type, final QueryContext qc)
       throws QueryException {
     return checkType(expr.atomItem(qc, info), type);
   }
 
   /**
-   * Checks if the specified expression is an empty sequence; if yes, throws
-   * an exception.
-   * @param item item to be checked
-   * @param type type to be checked
-   * @return specified item
+   * Returns an item if it has the specified type.
+   * @param item item
+   * @param type expected type
+   * @return item
    * @throws QueryException query exception
    */
   protected final Item checkType(final Item item, final Type type) throws QueryException {
@@ -657,25 +688,25 @@ public abstract class ParseExpr extends Expr {
   }
 
   /**
-   * Checks if the specified item is no empty sequence.
-   * @param item item to be checked
+   * Returns an item if it is not empty.
+   * @param item item
    * @return specified item
    * @throws QueryException query exception
    */
   protected final Item checkNoEmpty(final Item item) throws QueryException {
-    if(item != Empty.VALUE) return item;
-    throw EMPTYFOUND.get(info);
+    if(item.isEmpty()) throw EMPTYFOUND.get(info);
+    return item;
   }
 
   /**
-   * Checks if the specified item is no empty sequence.
-   * @param item item to be checked
+   * Returns an item if it is not empty.
+   * @param item item
    * @param type expected type
    * @return specified item
    * @throws QueryException query exception
    */
   protected final Item checkNoEmpty(final Item item, final Type type) throws QueryException {
-    if(item != Empty.VALUE) return item;
-    throw EMPTYFOUND_X.get(info, type);
+    if(item.isEmpty()) throw EMPTYFOUND_X.get(info, type);
+    return item;
   }
 }
