@@ -6,13 +6,11 @@ import static org.basex.query.func.Function.*;
 import java.util.*;
 import java.util.function.*;
 
-import org.basex.data.*;
 import org.basex.query.*;
 import org.basex.query.CompileContext.*;
 import org.basex.query.expr.path.*;
 import org.basex.query.func.*;
 import org.basex.query.func.fn.*;
-import org.basex.query.func.util.*;
 import org.basex.query.util.*;
 import org.basex.query.util.list.*;
 import org.basex.query.value.item.*;
@@ -25,7 +23,7 @@ import org.basex.util.hash.*;
 /**
  * Simple map operator.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public abstract class SimpleMap extends Arr {
@@ -39,16 +37,17 @@ public abstract class SimpleMap extends Arr {
   }
 
   /**
-   * Creates a new, optimized map expression, or the first expression if only one was specified.
+   * Creates a new, optimized map expression.
    * @param cc compilation context
    * @param ii input info
-   * @param exprs one or more expressions
-   * @return filter root, path or filter expression
+   * @param exprs expressions
+   * @return list, single expression or empty sequence
    * @throws QueryException query exception
    */
   public static Expr get(final CompileContext cc, final InputInfo ii, final Expr... exprs)
       throws QueryException {
-    return exprs.length == 1 ? exprs[0] : new CachedMap(ii, exprs).optimize(cc);
+    final int el = exprs.length;
+    return el > 1 ? new CachedMap(ii, exprs).optimize(cc) : el > 0 ? exprs[0] : Empty.VALUE;
   }
 
   @Override
@@ -67,13 +66,7 @@ public abstract class SimpleMap extends Arr {
   public final Expr compile(final CompileContext cc) throws QueryException {
     final int el = exprs.length;
     for(int e = 0; e < el; e++) {
-      Expr expr = exprs[e];
-      try {
-        expr = expr.compile(cc);
-      } catch(final QueryException qe) {
-        // replace original expression with error
-        expr = cc.error(qe, expr);
-      }
+      final Expr expr = cc.compileOrError(exprs[e], e == 0);
       if(e == 0) cc.pushFocus(expr);
       else cc.updateFocus(expr);
       exprs[e] = expr;
@@ -137,14 +130,6 @@ public abstract class SimpleMap extends Arr {
   private Expr merge(final Expr expr, final Expr next, final CompileContext cc)
       throws QueryException {
 
-    // merge filter with context value as root
-    // A ! .[B]  ->  A[B]
-    if(next instanceof Filter) {
-      final Filter filter = (Filter) next;
-      if(filter.root instanceof ContextValue && !filter.mayBePositional())
-        return Filter.get(cc, info, expr, ((Filter) next).exprs);
-    }
-
     final long size = expr.size();
     if(!expr.has(Flag.NDT) && !next.has(Flag.POS)) {
       // merge expressions if next expression does not rely on the context
@@ -156,30 +141,29 @@ public abstract class SimpleMap extends Arr {
             expr.arg(1).seqType().instanceOf(SeqType.INTEGER_O)) {
           count = expr.arg(1);
         }
-        // (1 to 2) ! <x/>  ->  util:replicate(<x/>, 2, true())
-        // (1 to $c) ! 'A'  ->  util:replicate('A', $c, false())
+        // (1 to 2) ! <x/>  ->  replicate(<x/>, 2, true())
+        // (1 to $c) ! 'A'  ->  replicate('A', $c, false())
         if(count != null) return cc.replicate(next, count, info);
       }
 
       if(next instanceof StandardFunc && !next.has(Flag.NDT)) {
         // next operand relies on context and is a deterministic function call
         final Expr[] args = next.args();
-        if(_UTIL_REPLICATE.is(next) && ((UtilReplicate) next).singleEval(true) &&
+        if(REPLICATE.is(next) && ((FnReplicate) next).singleEval(true) &&
             args[0] instanceof ContextValue && !args[1].has(Flag.CTX)) {
-          if(_UTIL_REPLICATE.is(expr) && ((UtilReplicate) expr).singleEval(true)) {
-            // util:replicate(E, C) ! util:replicate(., D)  ->  util:replicate(E, C * D)
+          if(REPLICATE.is(expr) && ((FnReplicate) expr).singleEval(true)) {
+            // replicate(E, C) ! replicate(., D)  ->  replicate(E, C * D)
             final Expr cnt = new Arith(info, expr.arg(1), args[1], Calc.MULT).optimize(cc);
-            return cc.function(_UTIL_REPLICATE, info, expr.arg(0), cnt);
+            return cc.function(REPLICATE, info, expr.arg(0), cnt);
           }
           if(expr instanceof SingletonSeq && ((SingletonSeq) expr).singleItem()) {
-            // SINGLETONSEQ ! util:replicate(., C)  ->  util:replicate(SINGLETONSEQ, C)
-            return cc.function(_UTIL_REPLICATE, info, expr, args[1]);
+            // SINGLETONSEQ ! replicate(., C)  ->  replicate(SINGLETONSEQ, C)
+            return cc.function(REPLICATE, info, expr, args[1]);
           }
-        } else if(_UTIL_ITEM.is(next) && !args[0].has(Flag.CTX) &&
-            args[1] instanceof ContextValue) {
+        } else if(ITEMS_AT.is(next) && !args[0].has(Flag.CTX) && args[1] instanceof ContextValue) {
           if(expr instanceof RangeSeq) {
-            // (3 to 4) ! util:item(X, .)  ->  util:range(X, 3, 4)
-            // reverse(3 to 4) ! util:item(X, .)  ->  reverse(util:range(X, 3, 4))
+            // (A to B) ! items-at(E, .)  ->  util:range(E, A, B)
+            // reverse(A to B) ! items-at(E, .)  ->  reverse(util:range(E, A, B))
             final RangeSeq seq = (RangeSeq) expr;
             final long[] range = seq.range(false);
             final Expr func = cc.function(_UTIL_RANGE, info,
@@ -187,17 +171,21 @@ public abstract class SimpleMap extends Arr {
             return seq.asc ? func : cc.function(REVERSE, info, func);
           }
           if(expr instanceof Range) {
-            // (1 to $i) ! util:item(X, .)  ->  util:range(X, 1, $i)
+            // (START to END) ! items-at(X, .)  ->  util:range(X, START, END)
             return cc.function(_UTIL_RANGE, info, args[0], expr.arg(0), expr.arg(1));
           }
+          if(expr.seqType().instanceOf(SeqType.INTEGER_ZM)) {
+            // INTEGERS ! items-at(X, .)  ->  items-at(X, INTEGERS)
+            return cc.function(ITEMS_AT, info, args[0], expr);
+          }
         } else if(DATA.is(next) && (((FnData) next).contextAccess() ||
             args[0] instanceof ContextValue)) {
-          // ITEMS ! data(.)  ->  data(ITEMS)
+          // E ! data(.)  ->  data(E)
           return cc.function(DATA, info, expr);
         } else if(STRING_TO_CODEPOINTS.is(expr) && CODEPOINTS_TO_STRING.is(next) &&
             args[0] instanceof ContextValue) {
-          // string-to-codepoints(STRING) ! codepoints-to-string(.)  ->  util:chars(STRING)
-          return cc.function(_UTIL_CHARS, info, expr.args());
+          // string-to-codepoints(E) ! codepoints-to-string(.)  ->  characters(E)
+          return cc.function(CHARACTERS, info, expr.args());
         }
       }
 
@@ -214,7 +202,7 @@ public abstract class SimpleMap extends Arr {
 
       // try to merge deterministic expressions
       Expr input = expr;
-      if(_UTIL_REPLICATE.is(expr) && ((UtilReplicate) expr).singleEval(true)) {
+      if(REPLICATE.is(expr) && ((FnReplicate) expr).singleEval(true)) {
         input = expr.arg(0);
       } else if(expr instanceof SingletonSeq && ((SingletonSeq) expr).singleItem()) {
         input = ((SingletonSeq) expr).itemAt(0);
@@ -242,7 +230,7 @@ public abstract class SimpleMap extends Arr {
             // replace original expression with error
             ex = cc.error(qe, next);
           }
-          // util:replicate(1, 2) ! (. = 1)  ->  util:replicate(1 = 1, 2)
+          // replicate(1, 2) ! (. = 1)  ->  replicate(1 = 1, 2)
           return expr == input ? ex : cc.replicate(ex, Int.get(size), info);
         }
       }
@@ -271,14 +259,31 @@ public abstract class SimpleMap extends Arr {
       }
       if(inline) {
         try {
-          final InlineContext ic = new InlineContext(null, expr, cc);
-          return ic.inline(next);
+          return new InlineContext(null, expr, cc).inline(next);
         } catch(final QueryException qe) {
           // replace original expression with error
           return cc.error(qe, next);
         }
       }
     }
+
+    // merge filter with context value as root
+    // A ! .[B]  ->  A[B]
+    if(next instanceof Filter) {
+      final Filter filter = (Filter) next;
+      if(filter.root instanceof ContextValue && !filter.mayBePositional()) {
+        return Filter.get(cc, info, expr, filter.exprs);
+      }
+    }
+
+    // A ! (if(B) then C else ()  ->  A[B] ! C
+    if(next instanceof If) {
+      final If iff = (If) next;
+      if(iff.exprs[1] == Empty.VALUE && !iff.exprs[0].has(Flag.POS) &&
+          !iff.cond.seqType().mayBeNumber()) {
+        return get(cc, info, Filter.get(cc, info, expr, iff.cond), iff.exprs[0]);
+      }
+    }
     return null;
   }
 
@@ -313,7 +318,7 @@ public abstract class SimpleMap extends Arr {
     if(e == 1) return null;
 
     // all operands are steps
-    //   db:open('animals') ! xml  ->  db:open('animals')/xml
+    //   db:get('animals') ! xml  ->  db:get('animals')/xml
     //   a ! b ! c  ->  /a/b/c
     final Expr path = Path.get(cc, info, root, steps.finish());
     if(e == el) return path;
@@ -376,8 +381,9 @@ public abstract class SimpleMap extends Arr {
    * Determines the type and result size and drops expressions that will never be evaluated.
    * @param cc compilation context
    * @return optimized expression or {@code null}
+   * @throws QueryException query exception
    */
-  private Expr dropOps(final CompileContext cc) {
+  private Expr dropOps(final CompileContext cc) throws QueryException {
     final ExprList list = new ExprList(exprs.length);
     long min = 1, max = 1;
     for(final Expr expr : exprs) {
@@ -398,41 +404,46 @@ public abstract class SimpleMap extends Arr {
       }
     }
     final int ls = list.size();
-    if(exprs.length != ls) cc.info(OPTSIMPLE_X_X, (Supplier<?>) this::description, this);
-    if(ls == 1) return exprs[0];
+    if(ls != exprs.length) {
+      cc.info(OPTSIMPLE_X_X, (Supplier<?>) this::description, this);
+      return get(cc, info, list.finish());
+    }
 
-    exprType.assign(list.peek().seqType(), new long[] { min, max });
-    exprs = list.finish();
-    return size() == 0 && !has(Flag.NDT) ? cc.emptySeq(this) : null;
-  }
-
-  @Override
-  public Data data() {
-    return exprs[exprs.length - 1].data();
+    exprType.assign(exprs[ls - 1], new long[] { min, max });
+    return size() == 0 && !has(Flag.NDT, Flag.HOF) ? cc.emptySeq(this) : null;
   }
 
   /**
    * Converts the map to a path expression.
+   * @param mode mode of simplification
    * @param cc compilation context
    * @return converted or original expression
    * @throws QueryException query context
    */
-  private Expr toPath(final CompileContext cc) throws QueryException {
-    Expr root = exprs[0];
+  private Expr toPath(final Simplify mode, final CompileContext cc) throws QueryException {
     final ExprList steps = new ExprList();
+
+    Expr root = exprs[0].simplifyFor(mode, cc);
     if(root instanceof AxisPath) {
       final AxisPath path = (AxisPath) root;
       root = path.root;
       steps.add(path.steps);
     }
-    final int el = exprs.length;
-    for(int e = 1; e < el; e++) {
-      if(!(exprs[e] instanceof AxisPath)) return this;
-      final AxisPath path = (AxisPath) exprs[e];
-      if(path.root != null) return this;
-      steps.add(path.steps);
+    cc.pushFocus(root);
+    try {
+      final int el = exprs.length;
+      for(int e = 1; e < el; e++) {
+        final Expr expr = exprs[e].simplifyFor(mode, cc);
+        if(!(expr instanceof AxisPath)) return this;
+        final AxisPath path = (AxisPath) expr;
+        if(path.root != null) return this;
+        steps.add(path.steps);
+        cc.updateFocus(expr);
+      }
+    } finally {
+      cc.removeFocus();
     }
-    return cc.replaceWith(this, Path.get(cc, info, root, steps.finish()));
+    return Path.get(cc, info, root, steps.finish());
   }
 
   @Override
@@ -457,19 +468,19 @@ public abstract class SimpleMap extends Arr {
           expr = last == Bln.FALSE ? Bln.FALSE : get(cc, info, Arrays.copyOf(exprs, el - 1));
         } else {
           // nodes ! text() = string  ->  nodes/text() = string
-          expr = toPath(cc);
+          expr = toPath(mode, cc);
         }
       }
     }
-    return expr != this ? cc.simplify(this, expr).simplifyFor(mode, cc) :
-      super.simplifyFor(mode, cc);
+    return cc.simplify(this, expr, mode);
   }
 
   @Override
   public final boolean has(final Flag... flags) {
     // Context dependency, positional access: only check first expression.
     // Examples: . ! abc, position() ! a
-    if(Flag.CTX.in(flags) && exprs[0].has(Flag.CTX) ||
+    if(Flag.FCS.in(flags) ||
+       Flag.CTX.in(flags) && exprs[0].has(Flag.CTX) ||
        Flag.POS.in(flags) && exprs[0].has(Flag.POS)) return true;
     // check remaining flags
     final Flag[] flgs = Flag.POS.remove(Flag.CTX.remove(flags));
