@@ -3,7 +3,6 @@ package org.basex.query.expr.gflwor;
 import java.util.*;
 import java.util.function.*;
 
-import org.basex.data.*;
 import org.basex.query.*;
 import org.basex.query.CompileContext.*;
 import org.basex.query.expr.*;
@@ -23,7 +22,7 @@ import org.basex.util.hash.*;
 /**
  * General FLWOR expression.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class GFLWOR extends ParseExpr {
@@ -44,6 +43,17 @@ public final class GFLWOR extends ParseExpr {
     this.rtrn = rtrn;
   }
 
+  /**
+   * Constructor.
+   * @param info input info
+   * @param clause single clause
+   * @param rtrn return expression
+   */
+  public GFLWOR(final InputInfo info, final Clause clause, final Expr rtrn) {
+    this(info, new LinkedList<>(), rtrn);
+    clauses.add(clause);
+  }
+
   /**
    * Creates a new evaluator for this FLWOR expression.
    * @return the evaluator
@@ -117,17 +127,14 @@ public final class GFLWOR extends ParseExpr {
       return expr;
     }
 
-    exprType.assign(rtrn.seqType(), calcSize(true));
+    exprType.assign(rtrn, calcSize(true));
     return this;
   }
 
   @Override
   public Expr simplifyFor(final Simplify mode, final CompileContext cc) throws QueryException {
-    Expr expr = null;
-    if(mode == Simplify.COUNT) {
-      expr = removeOrderBy(cc);
-    }
-    return expr != null ? expr.simplifyFor(mode, cc) : super.simplifyFor(mode, cc);
+    return cc.simplify(this, mode == Simplify.COUNT &&
+        clauses.removeIf(clause -> clause instanceof OrderBy) ? optimize(cc) : this, mode);
   }
 
   /**
@@ -138,39 +145,51 @@ public final class GFLWOR extends ParseExpr {
    */
   private Expr simplify(final CompileContext cc) throws QueryException {
     // replace with expression of 'return' clause if all clauses were removed
-    if(clauses.isEmpty()) return rtrn;
+    //  return R  ->  R
+    final int cs = clauses.size();
+    if(cs == 0) return rtrn;
 
     // replace with 'if' expression if FLWOR starts with 'where'
+    //   where W return R              ->  if(W) then R else ()
+    //   where W for $f in F return R  ->  if(W) then (for $f in F return R) else ()
     final Expr first = clauses.getFirst();
     if(first instanceof Where) {
-      final Where where = (Where) clauses.removeFirst();
-      final Expr branch = clauses.isEmpty() ? rtrn : this;
-      return new If(info, where.expr, branch).optimize(cc);
+      return new If(info, ((Where) clauses.removeFirst()).expr, cs == 1 ? rtrn : this).optimize(cc);
     }
 
     if(first instanceof For) {
       // replace allowing empty with empty sequence
       //   for $_ allowing empty in () return $_  ->  ()
       final For fr = (For) first;
-      if(clauses.size() == 1 && fr.size() == 0 && !fr.has(Flag.NDT) && rtrn instanceof VarRef &&
+      if(cs == 1 && fr.size() == 0 && !fr.has(Flag.NDT) && rtrn instanceof VarRef &&
           ((VarRef) rtrn).var.is(fr.var)) return Empty.VALUE;
 
       // rewrite group by to distinct-values
       //   for $e in E group by $g := G return R
-      //   ->  for $g in distinct-values(for $e in E return G)) return R
-      if(clauses.size() == 2 && clauses.get(1) instanceof GroupBy) {
-        final GroupSpec grp = ((GroupBy) clauses.get(1)).group();
-        if(grp != null) {
-          final LinkedList<Clause> cls = new LinkedList<>();
-          cls.add(clauses.removeFirst());
-          final Expr flwor = new GFLWOR(info, cls, grp.expr).optimize(cc);
+      //   ->  for $g in distinct-values(for $e in E return G) return R
+      if(cs == 2 && clauses.get(1) instanceof GroupBy) {
+        final GroupSpec spec = ((GroupBy) clauses.get(1)).group();
+        if(spec != null) {
+          final Expr flwor = new GFLWOR(info, clauses.removeFirst(), spec.expr).optimize(cc);
           final Expr expr = cc.function(Function.DISTINCT_VALUES, info, flwor);
-          clauses.set(0, new For(grp.var, expr).optimize(cc));
+          clauses.set(0, new For(spec.var, expr).optimize(cc));
           return optimize(cc);
         }
       }
     }
 
+    // rewrite single group
+    //   group by $g := G return R
+    //   ->  for $g in G return R
+    if(first instanceof GroupBy && cs == 1) {
+      final GroupSpec spec = ((GroupBy) first).group();
+      if(spec != null) {
+        final Expr expr = cc.function(Function.DATA, info, spec.expr);
+        clauses.set(0, new For(spec.var, expr).optimize(cc));
+        return optimize(cc);
+      }
+    }
+
     // checks if clauses have side effects
     final Checks<Clause> ndt = clause -> clause.has(Flag.NDT);
     // checks if the return expression references the variable of a clause
@@ -192,7 +211,7 @@ public final class GFLWOR extends ParseExpr {
       } else if(!varrefs.any(clauses) && !ndt.any(clauses)) {
         // no referenced variables in return clause
         //   let $_ := 1 return <x/>  ->  <x/>
-        //   for $_ in 1 to 2 return 3  ->  util:replicate(3, 2)
+        //   for $_ in 1 to 2 return 3  ->  replicate(3, 2)
         return min == 1 ? rtrn : cc.replicate(rtrn, Int.get(min), info);
       }
     }
@@ -295,7 +314,7 @@ public final class GFLWOR extends ParseExpr {
             fr.remove(cc, fr.pos);
           } else {
             // replace with singleton sequence (will never be accessed)
-            //   for $i in 1 to 3 return <a/>  ->  for $i in util:replicate('', 3) return $i
+            //   for $i in 1 to 3 return <a/>  ->  for $i in replicate('', 3) return $i
             fr.expr = cc.replaceWith(fr.expr, SingletonSeq.get(Str.EMPTY, fs));
             fr.exprType.assign(AtomType.STRING);
           }
@@ -605,7 +624,7 @@ public final class GFLWOR extends ParseExpr {
           clauses.remove(c--);
         } else {
           // otherwise, remove remaining clauses
-          for(int d = clauses.size() - 1; d >= c; d--) clauses.remove(d);
+          clauses.subList(c, clauses.size()).clear();
           rtrn = Empty.VALUE;
         }
       } else if(!clause.has(Flag.NDT)) {
@@ -706,7 +725,7 @@ public final class GFLWOR extends ParseExpr {
         clauses.remove(d);
         if(count(pos.pos, c) == VarUsage.NEVER) {
           // for $e at $p in E where $p = P ...  ->  for $e in E[position() = P] ...
-          pos.addPredicate(cc, ItrPos.get(cmp.min, cmp.max, cmp.info()));
+          pos.addPredicate(cc, IntPos.get(cmp.min, cmp.max, cmp.info()));
           cc.info(QueryText.OPTPRED_X, expr);
           changed = true;
         } else {
@@ -808,10 +827,10 @@ public final class GFLWOR extends ParseExpr {
           final Count cnt = (Count) clauses.get(1);
           if(fst.pos != null) {
             // for $a at $b in ... count $c ...  ->  for $a at $b in ... let $c := $b ...
-            final VarRef ref = new VarRef(cnt.info(), fst.pos).optimize(cc);
+            final Expr ref = new VarRef(cnt.info(), fst.pos).optimize(cc);
             clauses.set(1, new Let(cnt.var, ref).optimize(cc));
           } else {
-            // for $a in 1 to 3 count $c ...  -> for $a at $c in 1 to 3 ...
+            // for $a in 1 to 3 count $c ...  ->  for $a at $c in 1 to 3 ...
             clauses.set(0, new For(fst.var, cnt.var, fst.score, fst.expr, false).optimize(cc));
             clauses.remove(1);
           }
@@ -946,11 +965,6 @@ public final class GFLWOR extends ParseExpr {
     return count(var, 0);
   }
 
-  @Override
-  public Data data() {
-    return rtrn.data();
-  }
-
   /**
    * Counts the number of usages of the given variable starting from the given clause.
    * @param var variable
@@ -1040,16 +1054,6 @@ public final class GFLWOR extends ParseExpr {
     throw qe;
   }
 
-  /**
-   * Removes order by clauses.
-   * @param cc compilation context
-   * @return rewritten expression or {@code null}
-   * @throws QueryException query exception
-   */
-  public Expr removeOrderBy(final CompileContext cc) throws QueryException {
-    return clauses.removeIf(clause -> clause instanceof OrderBy) ? optimize(cc) : null;
-  }
-
   @Override
   public Expr copy(final CompileContext cc, final IntObjMap<Var> vm) {
     final LinkedList<Clause> cls = new LinkedList<>();
@@ -1122,7 +1126,7 @@ public final class GFLWOR extends ParseExpr {
 
   @Override
   public void toXml(final QueryPlan plan) {
-    plan.add(plan.create(this), clauses.toArray(new Clause[0]), rtrn);
+    plan.add(plan.create(this), clauses.toArray(Clause[]::new), rtrn);
   }
 
   @Override
