@@ -16,6 +16,7 @@ import org.basex.query.expr.*;
 import org.basex.query.expr.List;
 import org.basex.query.expr.index.*;
 import org.basex.query.func.Function;
+import org.basex.query.func.fn.*;
 import org.basex.query.func.util.*;
 import org.basex.query.util.*;
 import org.basex.query.util.index.*;
@@ -30,7 +31,7 @@ import org.basex.util.*;
 /**
  * Path expression.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public abstract class Path extends ParseExpr {
@@ -38,8 +39,6 @@ public abstract class Path extends ParseExpr {
   public Expr root;
   /** Path steps. */
   public Expr[] steps;
-  /** Data reference (can be {@code null}). */
-  protected Data data;
 
   /**
    * Constructor.
@@ -136,13 +135,7 @@ public abstract class Path extends ParseExpr {
     cc.get(rt, () -> {
       final int sl = steps.length;
       for(int s = 0; s < sl; s++) {
-        Expr step = steps[s];
-        try {
-          step = step.compile(cc);
-        } catch(final QueryException ex) {
-          // replace original expression with error
-          step = cc.error(ex, step);
-        }
+        final Expr step = cc.compileOrError(steps[s], root == null && s == 0);
         steps[s] = step;
         cc.updateFocus(step);
       }
@@ -190,7 +183,7 @@ public abstract class Path extends ParseExpr {
     // return optimized expression
     if(expr != this) return expr;
 
-    // choose best path implementation (dummy will be used for type checking)
+    // choose the best path implementation (dummy will be used for type checking)
     return copyType(get(info, root == null && rt instanceof Dummy ? rt : root, steps));
   }
 
@@ -198,41 +191,50 @@ public abstract class Path extends ParseExpr {
   public final Expr simplifyFor(final Simplify mode, final CompileContext cc)
       throws QueryException {
 
+    Expr expr = this;
     if(mode.oneOf(Simplify.EBV, Simplify.PREDICATE)) {
+      // merge nested predicates. example: if(a[b])  ->  if(a/b)
       final Expr last = steps[steps.length - 1];
       if(last instanceof Step) {
         final Step step = (Step) last;
         if(step.exprs.length == 1 && step.seqType().type instanceof NodeType &&
             !step.exprs[0].seqType().mayBeNumber()) {
-          // merge nested predicates. example: if(a[b])  ->  if(a/b)
-          final Expr s = step.flattenEbv(this, true, cc);
-          if(s != step) {
-            step.exprs = new Expr[0];
-            return cc.simplify(this, s);
-          }
+          final Expr ex = step.flattenEbv(this, true, cc);
+          if(ex != step) expr = ex;
         }
       }
     }
-    return super.simplifyFor(mode, cc);
+    return cc.simplify(this, expr, mode);
+  }
+
+  /**
+   * Removes the last predicate from the last step and returns the optimized expression.
+   * An error will be raised if the last step is no XPath step.
+   * @param cc compilation context
+   * @return new path
+   * @throws QueryException query exception
+   */
+  public final Expr removePredicate(final CompileContext cc) throws QueryException {
+    final ExprList list = new ExprList(steps.length).add(steps);
+    final Step step = ((Step) list.pop()).removePredicate();
+    list.add(cc.get(root, () -> step.optimize(cc)));
+    return copyType(get(cc, info, root, list.finish()));
   }
 
   @Override
   public final boolean has(final Flag... flags) {
-    /* Context dependency: check if no root exists, or if it depends on context.
-     * Examples: text(); ./abc */
-    if(Flag.CTX.in(flags) && (root == null || root.has(Flag.CTX))) return true;
-    /* Positional access: only check root node (steps will refer to result of root node).
-     * Example: position()/a */
-    if(Flag.POS.in(flags) && root != null && root.has(Flag.POS)) return true;
+    // Context dependency, positional access: only check root expression.
+    // Examples: text(); ./abc; position()/a
+    if(Flag.FCS.in(flags) ||
+       Flag.CTX.in(flags) && (root == null || root.has(Flag.CTX)) ||
+       Flag.POS.in(flags) && root != null && root.has(Flag.POS)) return true;
     // check remaining flags
     final Flag[] flgs = Flag.POS.remove(Flag.CTX.remove(flags));
-    if(flgs.length != 0) {
-      for(final Expr step : steps) {
-        if(step.has(flgs)) return true;
-      }
-      return root != null && root.has(flgs);
+    if(flgs.length == 0) return false;
+    for(final Expr step : steps) {
+      if(step.has(flgs)) return true;
     }
-    return false;
+    return root != null && root.has(flgs);
   }
 
   /**
@@ -302,8 +304,8 @@ public abstract class Path extends ParseExpr {
    * @throws QueryException query exception
    */
   private Expr simplify(final CompileContext cc) throws QueryException {
-    // return root if it yields no result
-    if(root != null && root.seqType().zero()) return cc.replaceWith(this, root);
+    // root yields no result
+    if(root != null && root.seqType().zero()) return cc.emptySeq(this);
 
     // find empty results, remove redundant steps
     final int sl = steps.length;
@@ -339,31 +341,61 @@ public abstract class Path extends ParseExpr {
     // self step was removed: ensure that result will be in distinct document order
     if(removed && (list.isEmpty() || !(list.get(0).seqType().type instanceof NodeType))) {
       if(root == null) root = ContextValue.get(cc, info);
-      if(!root.ddo()) root = cc.simplify(root, cc.function(Function._UTIL_DDO, info, root));
+      if(!root.ddo()) {
+        root = cc.replaceWith(root, cc.function(Function._UTIL_DDO, info, root));
+      }
     }
 
     // no steps left: return root
     steps = list.finish();
-    return steps.length == 0 ? cc.simplify(this, root) : this;
+    return cc.replaceWith(this, steps.length == 0 ? root : this);
   }
 
   /**
    * Returns the path nodes that will result from this path.
    * @param rt root at compile time (can be {@code null})
+   * @param stats assess database statistics
    * @return path nodes, or {@code null} if nodes cannot be evaluated
    */
-  public final ArrayList<PathNode> pathNodes(final Expr rt) {
+  private ArrayList<PathNode> pathNodes(final Expr rt, final boolean stats) {
     // ensure that path starts with document nodes
-    if(rt == null || !rt.seqType().type.instanceOf(NodeType.DOCUMENT_NODE) || data == null ||
-        !data.meta.uptodate) return null;
+    final Data data = data();
+    return rt != null && rt.seqType().type.instanceOf(NodeType.DOCUMENT_NODE) && data != null &&
+        data.meta.uptodate ? pathNodes(data.paths.root(), stats) : null;
+  }
 
-    ArrayList<PathNode> nodes = data.paths.root();
-    for(final Expr step : steps) {
-      if(!(step instanceof Step)) return null;
-      nodes = ((Step) step).nodes(nodes, data);
-      if(nodes == null) return null;
+  /**
+   * Returns the path nodes that will result from this path.
+   * @param nodes current path nodes
+   * @param stats assess database statistics
+   * @return path nodes, or {@code null} if nodes cannot be collected
+   */
+  final ArrayList<PathNode> pathNodes(final ArrayList<PathNode> nodes, final boolean stats) {
+    ArrayList<PathNode> pn = nodes;
+    for(final Expr expr : steps) {
+      if(expr instanceof UtilRoot) {
+        pn = UtilRoot.nodes(pn);
+      } else if(expr instanceof Step) {
+        final Step step = (Step) expr;
+        pn = step.nodes(pn, stats);
+        // check if paths within predicates are correct
+        if(!stats && pn != null) {
+          for(final Expr ex : step.exprs) {
+            if(ex instanceof AxisPath) {
+              final AxisPath path = (AxisPath) ex;
+              if(path.root == null) {
+                final ArrayList<PathNode> tmp = path.pathNodes(pn, false);
+                if(tmp != null && tmp.isEmpty()) return tmp;
+              }
+            }
+          }
+        }
+      } else {
+        pn = null;
+      }
+      if(pn == null) break;
     }
-    return nodes;
+    return pn;
   }
 
   /**
@@ -371,7 +403,7 @@ public abstract class Path extends ParseExpr {
    * @return statistics or {@code null}
    */
   public ArrayList<Stats> pathStats() {
-    final ArrayList<PathNode> nodes = pathNodes(root);
+    final ArrayList<PathNode> nodes = pathNodes(root, true);
     if(nodes == null) return null;
 
     // loop through all nodes
@@ -398,7 +430,7 @@ public abstract class Path extends ParseExpr {
    * @param rt root at compile time (can be {@code null})
    * @return result of check
    */
-  public final boolean emptySteps(final Expr rt) {
+  private boolean emptySteps(final Expr rt) {
     if(rt != null) {
       Expr prev = rt;
       for(final Expr step : steps) {
@@ -467,36 +499,37 @@ public abstract class Path extends ParseExpr {
 
   /**
    * Assigns a sequence type and (if statically known) result size.
-   * @param rt compile time root (can be {@code null})
+   * @param rt root at compile time (can be {@code null})
    */
   private void seqType(final Expr rt) {
-    if(rt != null) data = rt.data();
-
-    final SeqType st = steps[steps.length - 1].seqType();
+    final Expr last = steps[steps.length - 1];
+    final Data data = last.data();
+    final SeqType st = last.seqType();
     Occ occ = Occ.ZERO_OR_MORE;
-    long size = size(rt);
+    long size = size(rt, data);
 
     if(size == -1 && rt != null) {
-      size = rt.size();
       occ = rt.seqType().occ;
+      size = rt.size();
 
       for(final Expr step : steps) {
+        occ = occ.union(step.seqType().occ);
         final long sz = step.size();
         size = size != -1 && sz != -1 ? size * sz : -1;
-        occ = occ.union(step.seqType().occ);
       }
       // more than one result: final size is unknown due to DDO
       if(size > 1) size = -1;
     }
-    exprType.assign(st, occ, size);
+    exprType.assign(st, occ, size).data(data);
   }
 
   /**
    * Computes the result size via database statistics.
-   * @param rt compile time root (can be {@code null})
+   * @param rt root at compile time (can be {@code null})
+   * @param data data reference
    * @return number of results (or {@code -1})
    */
-  private long size(final Expr rt) {
+  private long size(final Expr rt, final Data data) {
     // check if path will yield any results
     if(root != null && root.size() == 0) return 0;
     for(final Expr step : steps) {
@@ -516,7 +549,7 @@ public abstract class Path extends ParseExpr {
     for(int s = 0; s < sl; s++) {
       final Step curr = axisStep(s);
       if(curr != null) {
-        nodes = curr.nodes(nodes, data);
+        nodes = curr.nodes(nodes, true);
         if(nodes == null) return -1;
       } else if(s + 1 == sl) {
         lastSize = steps[s].size();
@@ -539,6 +572,7 @@ public abstract class Path extends ParseExpr {
    */
   private ArrayList<PathNode> pathNodes(final int last) {
     // skip request if no path index exists or might be out-of-date
+    final Data data = data();
     if(data == null || !data.meta.uptodate) return null;
 
     ArrayList<PathNode> nodes = data.paths.root();
@@ -571,11 +605,11 @@ public abstract class Path extends ParseExpr {
   /**
    * Returns an empty sequence if the path will yield no results.
    * @param cc compilation context
-   * @param rt compile time root (can be {@code null})
+   * @param rt root at compile time (can be {@code null})
    * @return original or new expression
    */
   private Expr removeEmpty(final CompileContext cc, final Expr rt) {
-    final ArrayList<PathNode> nodes = pathNodes(rt);
+    final ArrayList<PathNode> nodes = pathNodes(rt, false);
     if(nodes != null ? nodes.isEmpty() : emptySteps(rt)) {
       cc.info(QueryText.OPTPATH_X, this);
       return Empty.VALUE;
@@ -586,7 +620,7 @@ public abstract class Path extends ParseExpr {
   /**
    * Converts descendant to child steps.
    * @param cc compilation context
-   * @param rt compile time root (can be {@code null})
+   * @param rt root at compile time (can be {@code null})
    * @return original or new expression
    * @throws QueryException query exception
    */
@@ -595,6 +629,7 @@ public abstract class Path extends ParseExpr {
     // - if path does not start with document nodes
     // - if index does not exist or is out-dated
     // - if several namespaces occur in the input
+    final Data data = data();
     if(rt == null || !rt.seqType().type.instanceOf(NodeType.DOCUMENT_NODE) ||
         data == null || !data.meta.uptodate || data.defaultNs() == null) return this;
 
@@ -696,7 +731,7 @@ public abstract class Path extends ParseExpr {
    * Queries of type 1, 3, 5 will not yield any results if the string to be compared is empty.
    *
    * @param cc compilation context
-   * @param rt compile time root (can be {@code null})
+   * @param rt root at compile time (can be {@code null})
    * @return original or new expression
    * @throws QueryException query exception
    */
@@ -710,6 +745,7 @@ public abstract class Path extends ParseExpr {
     int predIndex = 0, stepIndex = 0;
 
     // check if path can be converted to an index access
+    final Data data = data();
     final int sl = steps.length;
     for(int s = 0; s < sl; s++) {
       // only accept descendant steps without positional predicates
@@ -724,7 +760,7 @@ public abstract class Path extends ParseExpr {
           new IndexStaticDb(data, info) :
           new IndexDynDb(root == null ? new ContextValue(info) : root, info);
 
-        // choose cheapest index access
+        // choose the cheapest index access
         for(int e = 0; e < el; e++) {
           final IndexInfo ii = new IndexInfo(db, cc, step);
           if(!step.exprs[e].indexAccessible(ii)) continue;
@@ -826,7 +862,7 @@ public abstract class Path extends ParseExpr {
       final NameTest test = (NameTest) step.test;
       if(test.part() != NamePart.LOCAL) return true;
       // only support unique paths with nodes on the correct level
-      final ArrayList<PathNode> pn = data.paths.desc(test.qname.local());
+      final ArrayList<PathNode> pn = data().paths.desc(test.qname.local());
       if(pn.size() != 1 || pn.get(0).level() != s + 1) return true;
     }
     return false;
@@ -853,9 +889,9 @@ public abstract class Path extends ParseExpr {
           if(st != filter.root) return Filter.get(cc, filter.info(), st, filter.exprs);
         }
       }
-      // util:replicate(a, 2)/b  ->  a/b
+      // replicate(a, 2)/b  ->  a/b
       if(step.seqType().type instanceof NodeType) {
-        if(_UTIL_REPLICATE.is(step) && ((UtilReplicate) step).singleEval(false)) return step.arg(0);
+        if(REPLICATE.is(step) && ((FnReplicate) step).singleEval(false)) return step.arg(0);
         if(step instanceof SingletonSeq) return ((SingletonSeq) step).itemAt(0);
       }
       return step;
@@ -1007,16 +1043,15 @@ public abstract class Path extends ParseExpr {
   private static Expr mergeStep(final Step curr, final Expr next, final Expr prev,
       final CompileContext cc) throws QueryException {
 
-    // do not merge steps if first one contains positional predicates
+    // do not merge if current step contains positional predicates
     if(curr.mayBePositional()) return null;
 
     // merge self steps:  child::*/self::a  ->  child::a
     final Step nxt = next instanceof Step ? (Step) next : null;
     if(nxt != null && nxt.axis == SELF && !nxt.mayBePositional()) {
       final Test test = curr.test.intersect(nxt.test);
-      if(test == null) return null;
-      curr.test = test;
-      return curr.addPredicates(nxt.exprs).optimize(prev, cc);
+      return test == null ? null :
+        Step.get(cc, prev, curr.info(), curr.axis, test, ExprList.concat(curr.exprs, nxt.exprs));
     }
 
     // merge descendant-or-self::node()
@@ -1032,10 +1067,7 @@ public abstract class Path extends ParseExpr {
       return false;
     };
     // example: //child::*  ->  descendant::*
-    if(simple.test(nxt)) {
-      nxt.axis = DESCENDANT;
-      return nxt.optimize(prev, cc);
-    }
+    if(simple.test(nxt)) return Step.get(cc, prev, nxt.info(), DESCENDANT, nxt.test, nxt.exprs);
 
     // function for merging steps inside union expressions
     final QueryFunction<Expr, Expr> rewrite = expr -> {
@@ -1048,7 +1080,9 @@ public abstract class Path extends ParseExpr {
         final Union union = (Union) expr;
         if(startWithChild.all(union.exprs)) {
           for(final Expr path : union.exprs) {
-            ((Step) ((Path) path).steps[0]).axis = DESCENDANT;
+            final Path p = (Path) path;
+            final Step s = (Step) p.steps[0];
+            p.steps[0] = Step.get(cc, prev, s.info(), DESCENDANT, s.test, s.exprs);
           }
           return union.optimize(cc);
         }
@@ -1108,12 +1142,13 @@ public abstract class Path extends ParseExpr {
     final CompileContext cc = ic.cc;
     final int sl = steps.length;
     final Expr rt = root != null ? root : cc.qc.focus.value;
-    if(changed) {
+    if(changed) cc.get(rt, () -> {
       for(int s = 0; s < sl; s++) {
-        final Expr step = steps[s];
-        steps[s] = step instanceof Step ? ((Step) step).optimize(rt, cc) : step.optimize(cc);
+        steps[s] = steps[s].optimize(cc);
+        cc.updateFocus(steps[s]);
       }
-    }
+      return null;
+    });
 
     changed |= ic.var != null && cc.ok(rt, () -> {
       boolean chngd = false;
@@ -1134,7 +1169,7 @@ public abstract class Path extends ParseExpr {
   @Override
   public final boolean accept(final ASTVisitor visitor) {
     if(root == null) {
-      visitor.lock(Locking.CONTEXT, false);
+      visitor.lock(Locking.CONTEXT);
     } else if(!root.accept(visitor)) {
       return false;
     }
