@@ -19,10 +19,10 @@ import org.basex.io.serial.*;
 import org.basex.query.*;
 import org.basex.query.CompileContext.*;
 import org.basex.query.expr.*;
-import org.basex.query.func.xquery.XQueryEval.*;
 import org.basex.query.iter.*;
 import org.basex.query.util.*;
 import org.basex.query.util.collation.*;
+import org.basex.query.util.list.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.map.*;
@@ -32,13 +32,14 @@ import org.basex.query.value.type.*;
 import org.basex.query.var.*;
 import org.basex.util.*;
 import org.basex.util.hash.*;
+import org.basex.util.list.*;
 import org.basex.util.options.*;
 import org.basex.util.similarity.*;
 
 /**
  * Built-in functions.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public abstract class StandardFunc extends Arr {
@@ -47,9 +48,6 @@ public abstract class StandardFunc extends Arr {
   /** Static context. */
   public StaticContext sc;
 
-  /** Data reference (can be {@code null}). */
-  private Data data;
-
   /**
    * Constructor.
    */
@@ -78,15 +76,14 @@ public abstract class StandardFunc extends Arr {
     checkPerm(cc.qc, definition.perm);
     simplifyArgs(cc);
 
+    // apply custom optimizations
     final Expr expr = opt(cc);
+    if(expr != this) return cc.replaceWith(this, expr);
+
+    // pre-evaluate if arguments are values and not too large
     final SeqType st = definition.seqType;
-    return
-      // return optimized expression
-      expr != this ? cc.replaceWith(this, expr) :
-      // pre-evaluate if arguments are values and not too large
-      allAreValues(st.occ.max > 1 || st.type instanceof FuncType) && isSimple() ? cc.preEval(this) :
-      // return original function
-      this;
+    return allAreValues(st.occ.max > 1 || st.type instanceof FuncType) && isSimple()
+        ? cc.preEval(this) : this;
   }
 
   /**
@@ -96,14 +93,14 @@ public abstract class StandardFunc extends Arr {
    * @throws QueryException query exception
    */
   protected void simplifyArgs(final CompileContext cc) throws QueryException {
-    final int el = exprs.length;
-    for(int e = 0; e < el; e++) {
+    final int al = args().length;
+    for(int a = 0; a < al; a++) {
       // consider variable-size parameters
-      final int p = Math.min(e, definition.params.length - 1);
-      final Type type = definition.params[p].type;
+      final int p = Math.min(a, definition.types.length - 1);
+      final Type type = definition.types[p].type;
       if(type.instanceOf(AtomType.ANY_ATOMIC_TYPE)) {
         final Simplify mode = type.instanceOf(AtomType.NUMERIC) ? Simplify.NUMBER : Simplify.STRING;
-        exprs[e] = exprs[e].simplifyFor(mode, cc);
+        arg(a, arg -> arg.simplifyFor(mode, cc));
       }
     }
   }
@@ -121,10 +118,7 @@ public abstract class StandardFunc extends Arr {
 
   @Override
   public final StandardFunc copy(final CompileContext cc, final IntObjMap<Var> vm) {
-    final int el = exprs.length;
-    final Expr[] arg = new Expr[el];
-    for(int e = 0; e < el; e++) arg[e] = exprs[e].copy(cc, vm);
-    return copyType(definition.get(sc, info, arg));
+    return copyType(definition.get(sc, info, copyAll(cc, vm, args())));
   }
 
   /**
@@ -150,7 +144,7 @@ public abstract class StandardFunc extends Arr {
    * @return original expression or function argument
    */
   protected final Expr optFirst(final boolean occ, final boolean atom, final Value value) {
-    final Expr expr = exprs.length > 0 ? exprs[0] : value;
+    final Expr expr = defined(0) ? arg(0) : value;
     if(expr != null) {
       final SeqType st = expr.seqType();
       if(st.zero()) return expr;
@@ -162,19 +156,21 @@ public abstract class StandardFunc extends Arr {
   /**
    * Serializes the data from the specified iterator.
    * @param iter data to serialize
-   * @param opts serialization parameters
+   * @param sopts serialization parameters
    * @param err error to raise
    * @param qc query context
    * @return result
    * @throws QueryException query exception
    */
-  protected final byte[] serialize(final Iter iter, final SerializerOptions opts,
+  protected final byte[] serialize(final Iter iter, final SerializerOptions sopts,
       final QueryError err, final QueryContext qc) throws QueryException {
 
     try {
       final ArrayOutput ao = new ArrayOutput();
-      try(Serializer ser = Serializer.get(ao, opts)) {
-        for(Item item; (item = qc.next(iter)) != null;) ser.serialize(item);
+      try(Serializer ser = Serializer.get(ao, sopts)) {
+        for(Item item; (item = qc.next(iter)) != null;) {
+          ser.serialize(item);
+        }
       }
       return new TokenBuilder(ao.finish()).normalize().finish();
     } catch(final QueryIOException ex) {
@@ -186,17 +182,24 @@ public abstract class StandardFunc extends Arr {
 
   @Override
   public boolean has(final Flag... flags) {
-    // check signature flags
+    // check function definition
     for(final Flag flag : flags) {
-      if(definition.has(flag)) return true;
+      if(flag == Flag.UPD ? updating() : definition.has(flag)) return true;
     }
-    // mix updates: higher-order function may be updating
-    if(Flag.UPD.in(flags) && sc.mixUpdates && definition.has(Flag.HOF)) return true;
     // check arguments (without function invocation; it only applies to function itself)
     final Flag[] flgs = Flag.HOF.remove(flags);
     return flgs.length != 0 && super.has(flgs);
   }
 
+  /**
+   * Indicates if this function is updating.
+   * @return result of check
+   */
+  public boolean updating() {
+    // mix updates: higher-order function may be updating
+    return definition.has(Flag.UPD) || sc.mixUpdates && definition.has(Flag.HOF);
+  }
+
   @Override
   public boolean vacuous() {
     return size() == 0 && !has(Flag.UPD);
@@ -204,7 +207,7 @@ public abstract class StandardFunc extends Arr {
 
   /**
    * Refines the type of a function item argument.
-   * @param expr expression
+   * @param expr function
    * @param cc compilation context
    * @param declType declared return type
    * @param argTypes argument types
@@ -242,48 +245,40 @@ public abstract class StandardFunc extends Arr {
    * @throws QueryException query exception
    */
   protected final Expr compileData(final CompileContext cc) throws QueryException {
-    if(exprs.length > 0 && exprs[0] instanceof Value) {
-      data = toData(cc.qc);
+    if(cc.dynamic && defined(0) && arg(0) instanceof Value) {
+      final Data data = toData(cc.qc);
+      exprType.data(data);
       cc.info(OPTOPEN_X, data.meta.name);
     }
     return this;
   }
 
   /**
-   * Tries to embed a positional function call in its first argument.
+   * Tries to embed a positional function call in the input argument.
    * @param cc compilation context
    * @param skip skip evaluation of remaining operands
-   * @return optimized expression or {@code null}
+   * @return optimized or original expression
    * @throws QueryException query exception
    */
   protected Expr embed(final CompileContext cc, final boolean skip) throws QueryException {
-    // util:last((1 to 8) ! <_>{ . }</_>)  ->  util:last((1 to 8)) ! <_>{ . }</_>
-    if(exprs[0] instanceof SimpleMap) {
-      final Expr[] ops = exprs[0].args();
-      if(((Checks<Expr>) op -> op == ops[0] || op.seqType().one()).all(ops)) {
-        exprs[0] = ops[0];
-        ops[0] = definition.get(sc, info, exprs).optimize(cc);
-        return skip ? ops[0] : SimpleMap.get(cc, info, ops);
+    // head($nodes ! name())  ->  head($nodes) ! name()
+    // foot((1 to 8) ! <_>{ . }</_>)  ->  foot((1 to 8)) ! <_>{ . }</_>
+    // do not rewrite positional access:  foot($nodes ! position())
+    if(arg(0) instanceof SimpleMap) {
+      final Expr[] ops = arg(0).args();
+      if(((Checks<Expr>) op -> op == ops[0] || op.seqType().one() && !op.has(Flag.POS)).all(ops)) {
+        final Expr[] args = new ExprList(args().clone()).set(0, ops[0]).finish();
+        final Expr fn = definition.get(sc, info, args).optimize(cc);
+        return skip ? fn : SimpleMap.get(cc, info, new ExprList(ops.clone()).set(0, fn).finish());
       }
     }
-    return null;
-  }
-
-  @Override
-  public final Data data() {
-    return data;
-  }
-
-  @Override
-  public final void data(final Data dt) {
-    data = dt;
+    return this;
   }
 
   /**
-   * Checks if the specified item has the specified Date type.
-   * If it is item, the specified Date is returned.
-   * @param item item to be checked
-   * @param type target type
+   * Converts an item to a date of the specified type.
+   * @param item item
+   * @param type expected type
    * @param qc query context
    * @return date
    * @throws QueryException query exception
@@ -294,50 +289,69 @@ public abstract class StandardFunc extends Arr {
   }
 
   /**
-   * Checks if the specified expression is a database node.
-   * Returns the node or an exception.
-   * @param item item to be checked
-   * @return item
+   * Converts an item to a database node.
+   * @param item item
+   * @param mainmem accept main-memory database nods
+   * @return database node
    * @throws QueryException query exception
    */
-  protected final DBNode toDBNode(final Item item) throws QueryException {
-    if(checkNoEmpty(item, NodeType.NODE) instanceof DBNode) return (DBNode) item;
+  protected final DBNode toDBNode(final Item item, final boolean mainmem) throws QueryException {
+    if(checkNoEmpty(item, NodeType.NODE) instanceof DBNode &&
+        (mainmem || !item.data().inMemory())) return (DBNode) item;
     throw DB_NODE_X.get(info, item);
   }
 
   /**
-   * Checks if the specified collation is supported.
-   * @param i index of argument
+   * Evaluates an expression to a collation.
+   * @param expr expression
    * @param qc query context
-   * @return collator or {@code null} (default collation)
+   * @return collation, or {@code null} for default collation
    * @throws QueryException query exception
    */
-  protected final Collation toCollation(final int i, final QueryContext qc) throws QueryException {
-    final byte[] coll = i >= exprs.length ? null : toToken(exprs[i], qc);
-    return Collation.get(coll, qc, sc, info, WHICHCOLL_X);
+  protected final Collation toCollation(final Expr expr, final QueryContext qc)
+      throws QueryException {
+    return toCollation(expr, false, qc);
   }
 
   /**
-   * Converts the specified argument to a file path.
-   * @param i index of argument
+   * Evaluates an expression to a collation.
+   * @param expr expression
+   * @param empty allow empty argument
    * @param qc query context
-   * @return file instance
+   * @return collation, or {@code null} for default collation
    * @throws QueryException query exception
    */
-  protected final Path toPath(final int i, final QueryContext qc) throws QueryException {
-    return toPath(toToken(exprs[i], qc));
+  protected final Collation toCollation(final Expr expr, final boolean empty, final QueryContext qc)
+      throws QueryException {
+    byte[] uri = null;
+    if(expr != Empty.UNDEFINED) {
+      final Item item = expr.atomItem(qc, info);
+      if(!item.isEmpty()) uri = toToken(item);
+      else if(!empty) checkNoEmpty(item);
+    }
+    return Collation.get(uri, qc, sc, info, WHICHCOLL_X);
   }
 
   /**
-   * Converts the specified string to a file path.
+   * Evaluates an expression to a file path.
+   * @param expr expression
+   * @param qc query context
+   * @return file path
+   * @throws QueryException query exception
+   */
+  protected final Path toPath(final Expr expr, final QueryContext qc) throws QueryException {
+    return toPath(toString(expr, qc));
+  }
+
+  /**
+   * Converts a path to a file path.
    * @param path path string
-   * @return file instance
+   * @return file path
    * @throws QueryException query exception
    */
-  protected final Path toPath(final byte[] path) throws QueryException {
+  protected final Path toPath(final String path) throws QueryException {
     try {
-      final String p = string(path);
-      return p.startsWith(IO.FILEPREF) ? Paths.get(new URI(p)) : Paths.get(p);
+      return path.startsWith(IO.FILEPREF) ? Paths.get(new URI(path)) : Paths.get(path);
     } catch(final InvalidPathException | URISyntaxException ex) {
       Util.debug(ex);
       throw FILE_INVALID_PATH_X.get(info, path);
@@ -345,50 +359,51 @@ public abstract class StandardFunc extends Arr {
   }
 
   /**
-   * Returns a valid reference if a file is found at the specified path or the static base uri.
-   * Otherwise, returns an error.
-   * @param i index of URI argument
+   * Evaluates an expression to a reference to an existing input resource.
+   * @param expr expression
    * @param qc query context
-   * @return input source, or exception
+   * @return input resource
    * @throws QueryException query exception
    */
-  protected final IO toIO(final int i, final QueryContext qc) throws QueryException {
-    return toIO(toToken(exprs[i], qc));
+  protected final IO toIO(final Expr expr, final QueryContext qc) throws QueryException {
+    return toIO(toString(expr, qc));
   }
 
   /**
-   * Converts the specified URI to a reference to a resource.
-   * @param uri file URI
+   * Returns a reference to an existing input resource.
+   * @param uri URI string
    * @return io reference
    * @throws QueryException query exception
    */
-  protected final IO toIO(final byte[] uri) throws QueryException {
-    final IO io = new QueryInput(string(uri), sc).io;
+  protected final IO toIO(final String uri) throws QueryException {
+    final IO io = sc.resolve(uri);
     if(!io.exists()) throw WHICHRES_X.get(info, io);
     if(io instanceof IOFile && io.isDir()) throw RESDIR_X.get(info, io);
     return io;
   }
 
   /**
-   * Returns the content of the specified input.
-   * @param i index of input argument (xs:anyURI with URI or xs:string with content)
+   * Evaluates an expression to an input resource.
+   * @param expr expression (xs:anyURI with URI or xs:string with content)
    * @param qc query context
-   * @return input content (UTF-8) with optional base URI
+   * @return input resource
    * @throws QueryException query exception
    */
-  protected final IOContent toContent(final int i, final QueryContext qc) throws QueryException {
-    final Item item = toItem(exprs[i], qc);
-    return item instanceof Uri ? toContent(item.string(info), qc) : new IOContent(toToken(item));
+  protected final IOContent toContent(final Expr expr, final QueryContext qc)
+      throws QueryException {
+    final Item item = toItem(expr, qc);
+    return item instanceof Uri ? toContent(string(item.string(info)), qc) :
+      new IOContent(toToken(item));
   }
 
   /**
-   * Returns the content of the specified input.
+   * Returns an input resource.
    * @param uri URI
    * @param qc query context
-   * @return input content (UTF-8) with attached base URI
+   * @return input resource
    * @throws QueryException query exception
    */
-  protected final IOContent toContent(final byte[] uri, final QueryContext qc)
+  protected final IOContent toContent(final String uri, final QueryContext qc)
       throws QueryException {
     checkPerm(qc, Perm.ADMIN);
     final IO io = toIO(uri);
@@ -400,113 +415,125 @@ public abstract class StandardFunc extends Arr {
   }
 
   /**
-   * Evaluates the specified URI.
+   * Returns a base URI for the given path and the associated option.
    * @param path custom path (can be {@code null})
-   * @param options options with base-uri property
+   * @param options options
+   * @param option base-uri option
    * @return base URI
    */
-  protected final String toBaseUri(final String path, final Options options) {
-    final String base = options.get(XQueryOptions.BASE_URI);
+  protected final String toBaseUri(final String path, final Options options,
+      final StringOption option) {
+    final String base = options.get(option);
     return base != null && !base.isEmpty() ? base :
       path != null && !path.isEmpty() ? path : string(sc.baseURI().string());
   }
 
   /**
-   * Returns a normalized encoding representation.
-   * @param i index of encoding argument
+   * Evaluates an expression to an encoding string.
+   * @param expr expression (can be {@code Empty#UNDEFINED})
    * @param err error to raise
    * @param qc query context
-   * @return string or {@code null}
+   * @return normalized encoding string or {@code null}
    * @throws QueryException query exception
    */
-  protected final String toEncodingOrNull(final int i, final QueryError err, final QueryContext qc)
-      throws QueryException {
+  protected final String toEncodingOrNull(final Expr expr, final QueryError err,
+      final QueryContext qc) throws QueryException {
 
-    if(i >= exprs.length) return null;
-    final byte[] encoding = toToken(exprs[i], qc);
+    final Item encoding = expr.atomItem(qc, info);
+    if(encoding.size() == 0) return null;
+
+    final String enc = toString(encoding);
     try {
-      final String enc = toString(exprs[i], qc);
       if(Charset.isSupported(enc)) return Strings.normEncoding(enc);
     } catch(final IllegalArgumentException ex) {
       // character set is invalid or unknown (e.g. empty string)
       Util.debug(ex);
     }
-    throw err.get(info, QueryError.similar(encoding,
-        Levenshtein.similar(encoding, Strings.encodings())));
+    throw err.get(info, QueryError.similar(enc,
+        Levenshtein.similar(token(enc), Strings.encodings())));
   }
 
   /**
-   * Returns the expression at the specified index as node or atomized item.
-   * Returns the item or throws an exception.
-   * @param i index of argument
+   * Converts an item to a node or an atomized item.
+   * @param expr expression
    * @param qc query context
    * @return node or atomized item
    * @throws QueryException query exception
    */
-  protected final Item toNodeOrAtomItem(final int i, final QueryContext qc) throws QueryException {
-    final Item item = toItem(exprs[i], qc);
+  protected final Item toNodeOrAtomItem(final Expr expr, final QueryContext qc)
+      throws QueryException {
+    final Item item = toItem(expr, qc);
     return item instanceof ANode ? item : item.atomItem(qc, info);
   }
 
   /**
-   * Parses the options at the specified index.
-   * @param <E> options type
-   * @param i index of argument (can exceed length of argument, or may yield an empty sequence)
-   * @param opts options
+   * Evaluates an expression to user options.
+   * @param expr expression (can be {@code Empty#UNDEFINED})
    * @param qc query context
-   * @return passed on options
+   * @return user options
    * @throws QueryException query exception
    */
-  protected final <E extends Options> E toOptions(final int i, final E opts, final QueryContext qc)
+  protected final HashMap<String, String> toOptions(final Expr expr, final QueryContext qc)
       throws QueryException {
-    return i >= exprs.length ? opts : new FuncOptions(info).assign(exprs[i].item(qc, info), opts);
+    return toOptions(expr, new Options(), false, qc).free();
   }
 
   /**
-   * Returns all keys and values of the specified binding argument.
-   * @param i index of argument
+   * Evaluates an expression, if it exists, and returns options.
+   * @param <E> options type
+   * @param expr expression (can be {@code Empty#UNDEFINED})
+   * @param options options template
+   * @param enforce raise error if a supplied option is unknown
    * @param qc query context
-   * @return resulting map
+   * @return options
    * @throws QueryException query exception
    */
-  protected final HashMap<String, Value> toBindings(final int i, final QueryContext qc)
+  protected final <E extends Options> E toOptions(final Expr expr, final E options,
+      final boolean enforce, final QueryContext qc) throws QueryException {
+    return new FuncOptions(info).assign(expr.item(qc, info), options, enforce);
+  }
+
+  /**
+   * Evaluates an expression to variable bindings.
+   * @param expr expression (can be {@code Empty#UNDEFINED})
+   * @param qc query context
+   * @return variable bindings
+   * @throws QueryException query exception
+   */
+  protected final HashMap<String, Value> toBindings(final Expr expr, final QueryContext qc)
       throws QueryException {
 
     final HashMap<String, Value> hm = new HashMap<>();
-    final int el = exprs.length;
-    if(i < el) {
-      final Item item = exprs[i].item(qc, info);
-      final XQMap map = item == Empty.VALUE ? XQMap.empty() : toMap(item);
-      map.apply((it, v) -> {
-        final byte[] key;
-        if(it.type.isStringOrUntyped()) {
-          key = it.string(null);
-        } else {
-          final QNm qnm = toQNm(it, false);
-          final TokenBuilder tb = new TokenBuilder();
-          if(qnm.uri() != null) tb.add('{').add(qnm.uri()).add('}');
-          key = tb.add(qnm.local()).finish();
-        }
-        hm.put(string(key), v);
-      });
-    }
+    final Item item = expr.item(qc, info);
+    final XQMap map = item.size() == 0 ? XQMap.empty() : toMap(item);
+    map.apply((key, value) -> {
+      final byte[] k;
+      if(key.type.isStringOrUntyped()) {
+        k = key.string(null);
+      } else {
+        final QNm qnm = toQNm(key, false);
+        final TokenBuilder tb = new TokenBuilder();
+        if(qnm.uri() != null) tb.add('{').add(qnm.uri()).add('}');
+        k = tb.add(qnm.local()).finish();
+      }
+      hm.put(string(k), value);
+    });
     return hm;
   }
 
   /**
-   * Returns a database instance for the first string argument of the function.
-   * This method assumes that the function has at least one argument.
+   * Evaluates the first expression to a database instance.
    * @param qc query context
-   * @return data instance
+   * @return database instance
    * @throws QueryException query exception
    */
   protected final Data toData(final QueryContext qc) throws QueryException {
-    return data != null ? data : qc.resources.database(toName(0, DB_NAME_X, qc), info);
+    final Data data = exprType.data();
+    return data != null ? data : qc.resources.database(toName(arg(0), false, DB_NAME_X, qc), info);
   }
 
   /**
-   * Checks if the current user has given permissions. If negative, an
-   * exception is thrown.
+   * Checks if the current user has given permissions. If negative, an exception is thrown.
    * @param qc query context
    * @param perm permission
    * @throws QueryException query exception
@@ -517,74 +544,101 @@ public abstract class StandardFunc extends Arr {
   }
 
   /**
-   * Casts and checks the function item for its arity.
+   * Evaluates an expression to a non-updating function item.
    * @param expr expression
-   * @param nargs number of arguments (arity)
+   * @param arity required number of arguments (arity)
    * @param qc query context
    * @return function item
    * @throws QueryException query exception
    */
-  protected final FItem toFunction(final Expr expr, final int nargs, final QueryContext qc)
+  protected final FItem toFunction(final Expr expr, final int arity, final QueryContext qc)
       throws QueryException {
-    return toFunction(expr, nargs, false, qc);
+    return toFunction(expr, arity, false, qc);
   }
 
   /**
-   * Casts and checks the function item for its arity.
+   * Evaluates an expression to a function item.
    * @param expr expression
-   * @param nargs number of arguments (arity)
+   * @param arity required number of arguments (arity)
    * @param qc query context
    * @param updating updating flag
    * @return function item
    * @throws QueryException query exception
    */
-  protected final FItem toFunction(final Expr expr, final int nargs, final boolean updating,
+  protected final FItem toFunction(final Expr expr, final int arity, final boolean updating,
       final QueryContext qc) throws QueryException {
 
     final FItem func = checkUp(toFunction(expr, qc), updating, sc);
-    final int fargs = func.arity();
-    if(fargs == nargs) return func;
-    throw FUNARITY_X_X.get(info, arguments(fargs), nargs);
+    final int farity = func.arity();
+    if(farity == arity) return func;
+    throw FUNARITY_X_X.get(info, arguments(farity), arity);
   }
 
   /**
-   * Checks if the specified expression is a valid name.
-   * @param i index of argument
-   * @param err error to raise
+   * Evaluates an expression to a name.
+   * @param expr expression
+   * @param empty allow empty name
+   * @param error error to raise
    * @param qc query context
-   * @return normalized path
+   * @return name
    * @throws QueryException query exception
    */
-  protected final String toName(final int i, final QueryError err, final QueryContext qc)
-      throws QueryException {
-    final String name = toString(exprs[i], qc);
-    if(Databases.validName(name)) return name;
-    throw err.get(info, name);
+  protected final String toName(final Expr expr, final boolean empty, final QueryError error,
+      final QueryContext qc) throws QueryException {
+    final String name = toString(expr, qc);
+    if(empty && name.length() == 0 || Databases.validName(name)) return name;
+    throw error.get(info, name);
   }
 
   /**
-   * Converts the specified dateTime to milliseconds.
+   * Evaluates an expression to a number of milliseconds.
    * @param expr expression
    * @param qc query context
-   * @return resulting value
+   * @return number of milliseconds
    * @throws QueryException query exception
    */
-  protected final long toMilliseconds(final Expr expr, final QueryContext qc)
-      throws QueryException {
-    final Dtm dtm = (Dtm) checkType(expr, qc, AtomType.DATE_TIME);
+  protected final long toMs(final Expr expr, final QueryContext qc) throws QueryException {
+    final Dtm dtm = (Dtm) checkType(expr, AtomType.DATE_TIME, qc);
     if(dtm.yea() > 292278993) throw INTRANGE_X.get(info, dtm.yea());
     return dtm.toJava().toGregorianCalendar().getTimeInMillis();
   }
 
   /**
-   * Tries to mark the specified argument for locking.
-   * @param visitor visitor
-   * @param i index of database argument
+   * Indicates if the supplied argument is defined.
+   * @param i index of argument
    * @return result of check
    */
-  protected final boolean dataLock(final ASTVisitor visitor, final int i) {
-    final String db = exprs[i] instanceof Str ? string(((Str) exprs[i]).string()) : null;
-    return visitor.lock(db, false);
+  protected final boolean defined(final int i) {
+    return arg(i) != Empty.UNDEFINED;
+  }
+
+  /**
+   * Tries to lock a database supplied by the specified argument.
+   * @param expr expression
+   * @param backup backup flag
+   * @param visitor visitor
+   * @return result of check
+   */
+  protected final boolean dataLock(final Expr expr, final boolean backup,
+      final ASTVisitor visitor) {
+    return visitor.lock(() -> {
+      final ArrayList<String> list = new ArrayList<>(1);
+      String name = expr instanceof Str ? string(((Str) expr).string()) :
+        expr instanceof Atm ? string(((Atm) expr).string(null)) : null;
+      if(name != null) {
+        if(backup) {
+          final String db = Databases.name(name);
+          if(db.isEmpty()) {
+            name = db;
+          } else {
+            list.add(db);
+          }
+        }
+        if(name.isEmpty()) name = null;
+      }
+      list.add(name);
+      return list;
+    });
   }
 
   @Override
@@ -600,11 +654,56 @@ public abstract class StandardFunc extends Arr {
 
   @Override
   public final void toXml(final QueryPlan plan) {
-    plan.add(plan.create(this, NAME, definition.id()), exprs);
+    final int undefined = undefined();
+    if(undefined == 0) {
+      plan.add(plan.create(this, NAME, definition.id()), args());
+    } else {
+      final int al = args().length;
+      final QNm[] names = definition.paramNames(al);
+      final ExprList args = new ExprList(al - undefined);
+      final StringList nms = new StringList(al - undefined);
+      for(int a = 0; a < al; a++) {
+        if(defined(a)) {
+          args.add(arg(a));
+          nms.add(names[a].toString());
+        }
+      }
+      plan.add(plan.create(this, NAME, definition.id(), ARG, String.join(", ", nms.finish())),
+          args.finish());
+    }
   }
 
   @Override
   public final void toString(final QueryString qs) {
-    qs.token(definition.id()).params(exprs);
+    final int undefined = undefined();
+    if(undefined == 0) {
+      qs.token(definition.id()).params(args());
+    } else {
+      final int al = args().length;
+      final QNm[] names = definition.paramNames(al);
+      final Object[] args = new Object[al - undefined];
+      boolean gap = false;
+      for(int a = 0, b = 0; a < al; a++) {
+        if(defined(a)) {
+          args[b++] = gap ? names[a] + " := " + arg(a) : arg(a);
+        } else {
+          gap = true;
+        }
+      }
+      qs.token(definition.id()).params(args);
+    }
+  }
+
+  /**
+   * Returns the number of undefined arguments.
+   * @return count
+   */
+  private int undefined() {
+    int c = 0;
+    final int al = args().length;
+    for(int a = 0; a < al; a++) {
+      if(!defined(a)) c++;
+    }
+    return c;
   }
 }
