@@ -11,17 +11,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class AdminDeleteLogs extends AdminFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final String name = toString(exprs[0], qc);
-    final LogFile file = qc.context.log.file(name);
-    if(file == null) throw WHICHRES_X.get(info, name);
-    if(file.current()) throw ADMIN_TODAY.get(info, name);
-    if(!file.delete()) throw ADMIN_DELETE_X.get(info, name);
+    final String date = toString(arg(0), qc);
+
+    final LogFile file = qc.context.log.file(date);
+    if(file == null) throw WHICHRES_X.get(info, date);
+    if(file.current()) throw ADMIN_TODAY.get(info, date);
+    if(!file.delete()) throw ADMIN_DELETE_X.get(info, date);
     return Empty.VALUE;
   }
 }
