@@ -12,12 +12,12 @@ import org.basex.server.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class AdminSessions extends AdminFn {
   @Override
-  public Value value(final QueryContext qc) throws QueryException {
+  public Value value(final QueryContext qc) {
     final ValueBuilder vb = new ValueBuilder(qc);
     for(final ClientListener cl : qc.context.sessions) {
       final Context ctx = cl.context();
