@@ -5,6 +5,7 @@ import static org.basex.util.Token.*;
 
 import java.io.*;
 
+import org.basex.io.in.*;
 import org.basex.io.out.*;
 import org.basex.query.*;
 import org.basex.query.iter.*;
@@ -15,21 +16,22 @@ import org.basex.util.hash.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ArchiveDelete extends ArchiveFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final B64 archive = toB64(exprs[0], qc, false);
+    final B64 archive = toB64(arg(0), qc, false);
+    final Iter entries = arg(1).iter(qc);
+
     // entries to be deleted
     final TokenSet names = new TokenSet();
-    final Iter iter = exprs[1].iter(qc);
-    for(Item en; (en = qc.next(iter)) != null;) {
+    for(Item en; (en = qc.next(entries)) != null;) {
       names.add(checkElemToken(en).string(info));
     }
 
-    try(ArchiveIn in = ArchiveIn.get(archive.input(info), info)) {
+    try(BufferInput bi = archive.input(info); ArchiveIn in = ArchiveIn.get(bi, info)) {
       final String format = in.format();
       if(in instanceof GZIPIn) throw ARCHIVE_MODIFY_X.get(info, format);
 
