@@ -8,6 +8,7 @@ import java.nio.file.*;
 import java.util.zip.*;
 
 import org.basex.io.*;
+import org.basex.io.in.*;
 import org.basex.io.out.*;
 import org.basex.query.*;
 import org.basex.query.value.item.*;
@@ -18,17 +19,17 @@ import org.basex.util.hash.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class ArchiveExtractTo extends ArchiveFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Path path = toPath(0, qc);
-    final B64 archive = toB64(exprs[1], qc, false);
-    final TokenSet hs = entries(2, qc);
+    final Path path = toPath(arg(0), qc);
+    final B64 archive = toB64(arg(1), qc, false);
+    final TokenSet hs = entries(arg(2), qc);
 
-    try(ArchiveIn in = ArchiveIn.get(archive.input(info), info)) {
+    try(BufferInput bi = archive.input(info); ArchiveIn in = ArchiveIn.get(bi, info)) {
       while(in.more()) {
         final ZipEntry ze = in.entry();
         final String name = ze.getName();
