@@ -6,6 +6,7 @@ import static org.basex.query.func.archive.ArchiveText.*;
 import java.io.*;
 import java.util.zip.*;
 
+import org.basex.io.in.*;
 import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.query.value.item.*;
@@ -15,20 +16,20 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ArchiveOptions extends StandardFunc {
   @Override
   public XQMap item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final B64 archive = toB64(exprs[0], qc, false);
+    final B64 archive = toB64(arg(0), qc, false);
     final String format;
     int level = -1;
 
-    try(ArchiveIn arch = ArchiveIn.get(archive.input(info), info)) {
-      format = arch.format();
-      while(arch.more()) {
-        final ZipEntry ze = arch.entry();
+    try(BufferInput bi = archive.input(info); ArchiveIn in = ArchiveIn.get(bi, info)) {
+      format = in.format();
+      while(in.more()) {
+        final ZipEntry ze = in.entry();
         if(ze.isDirectory()) continue;
         level = ze.getMethod();
         break;
@@ -43,6 +44,6 @@ public final class ArchiveOptions extends StandardFunc {
     if(level >= 0) mb.put(CreateOptions.ALGORITHM.name(),
         level == 8 ? DEFLATE : level == 0 ? STORED : UNKNOWN);
 
-    return mb.finish();
+    return mb.map();
   }
 }
