@@ -15,19 +15,19 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ArchiveWrite extends ArchiveCreate {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Path path = toPath(0, qc);
-    final Map<String, Item[]> map = toMap(1, qc);
-    final CreateOptions opts = toOptions(3, new CreateOptions(), qc);
+    final Path path = toPath(arg(0), qc);
+    final Map<String, Item[]> map = toMap(arg(1), arg(2), qc);
+    final CreateOptions options = toOptions(arg(3), new CreateOptions(), true, qc);
 
     try {
       try(BufferOutput out = new BufferOutput(new FileOutputStream(path.toFile()))) {
-        create(map, opts, out, qc);
+        create(map, options, out, qc);
       }
     } catch(final IOException ex) {
       throw ARCHIVE_ERROR_X.get(info, ex);
