@@ -11,31 +11,33 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ArrayFilter extends ArrayFn {
   @Override
   public XQArray item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final XQArray array = toArray(exprs[0], qc);
-    final FItem func = toFunction(exprs[1], 1, qc);
+    final XQArray array = toArray(arg(0), qc);
+    final FItem predicate = toFunction(arg(1), 1, qc);
 
-    final ArrayBuilder builder = new ArrayBuilder();
+    final ArrayBuilder ab = new ArrayBuilder();
     for(final Value value : array.members()) {
-      if(toBoolean(func.invoke(qc, info, value).item(qc, info))) builder.append(value);
+      if(toBoolean(predicate.invoke(qc, info, value).item(qc, info))) {
+        ab.append(value);
+      }
     }
-    return builder.array(this);
+    return ab.array(this);
   }
 
   @Override
   protected Expr opt(final CompileContext cc) throws QueryException {
-    final Expr expr1 = exprs[0];
-    if(expr1 == XQArray.empty()) return expr1;
+    final Expr array = arg(0);
+    if(array == XQArray.empty()) return array;
 
-    final Type type1 = expr1.seqType().type;
-    if(type1 instanceof ArrayType) {
-      exprs[1] = coerceFunc(exprs[1], cc, SeqType.BOOLEAN_O, ((ArrayType) type1).declType);
-      exprType.assign(type1);
+    final Type type = array.seqType().type;
+    if(type instanceof ArrayType) {
+      arg(1, arg -> coerceFunc(arg, cc, SeqType.BOOLEAN_O, ((ArrayType) type).declType));
+      exprType.assign(type);
     }
     return this;
   }
