@@ -12,25 +12,26 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ArrayFoldRight extends ArrayFn {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    final XQArray array = toArray(exprs[0], qc);
-    Value result = exprs[1].value(qc);
-    final FItem func = toFunction(exprs[2], 2, qc);
+    final XQArray array = toArray(arg(0), qc);
+    Value result = arg(1).value(qc);
+    final FItem action = toFunction(arg(2), 2, qc);
 
-    final ListIterator<Value> iter = array.iterator(array.arraySize());
-    while(iter.hasPrevious()) result = func.invoke(qc, info, iter.previous(), result);
+    for(final ListIterator<Value> iter = array.iterator(array.arraySize()); iter.hasPrevious();) {
+      result = action.invoke(qc, info, iter.previous(), result);
+    }
     return result;
   }
 
   @Override
   protected Expr opt(final CompileContext cc) throws QueryException {
-    final Expr expr1 = exprs[0], expr2 = exprs[1];
-    if(expr1 == XQArray.empty()) return expr2;
+    final Expr array = arg(0), zero = arg(1);
+    if(array == XQArray.empty()) return zero;
 
     FnFoldLeft.opt(this, cc, true, false);
     return this;
