@@ -2,25 +2,26 @@ package org.basex.query.func.array;
 
 import org.basex.query.*;
 import org.basex.query.expr.*;
-import org.basex.query.value.item.*;
+import org.basex.query.value.array.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ArrayReverse extends ArrayFn {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return toArray(exprs[0], qc).reverseArray(qc);
+  public XQArray item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    final XQArray array = toArray(arg(0), qc);
+    return array.reverseArray(qc);
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Type type = exprs[0].seqType().type;
+    final Type type = arg(0).seqType().type;
     if(type instanceof ArrayType) exprType.assign(type);
     return this;
   }
