@@ -5,27 +5,26 @@ import static org.basex.query.QueryError.*;
 import org.basex.query.*;
 import org.basex.query.expr.*;
 import org.basex.query.value.array.XQArray;
-import org.basex.query.value.item.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ArrayTail extends ArrayFn {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final XQArray array = toArray(exprs[0], qc);
+  public XQArray item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    final XQArray array = toArray(arg(0), qc);
     if(array.isEmptyArray()) throw ARRAYEMPTY.get(info);
     return array.tail();
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Type type = exprs[0].seqType().type;
+    final Type type = arg(0).seqType().type;
     if(type instanceof ArrayType) exprType.assign(type);
     return this;
   }
