@@ -15,21 +15,21 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class BinDecodeString extends BinFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final B64 b64 = toB64(exprs[0], qc, true);
-    final String encoding = toEncodingOrNull(1, BIN_UE_X, qc);
-    final Long off = exprs.length > 2 ? toLong(exprs[2], qc) : null;
-    final Long len = exprs.length > 3 ? toLong(exprs[3], qc) : null;
-    if(b64 == null) return Empty.VALUE;
+    final B64 binary = toB64(arg(0), qc, true);
+    final String encoding = toEncodingOrNull(arg(1), BIN_UE_X, qc);
+    final Item offset = arg(2).atomItem(qc, info);
+    final Item size = arg(3).atomItem(qc, info);
+    if(binary == null) return Empty.VALUE;
 
-    byte[] bytes = b64.binary(info);
+    byte[] bytes = binary.binary(info);
     final int bl = bytes.length;
-    final int[] bounds = bounds(off, len, bl);
+    final int[] bounds = bounds(offset, offset.isEmpty() ? Empty.VALUE : size, bl);
     final int o = bounds[0], tl = bounds[1];
     if(o > 0 || tl < bl) bytes = Arrays.copyOfRange(bytes, o, o + tl);
 
