@@ -11,19 +11,19 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class BinHex extends BinFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    byte[] token = token(0, qc);
-    if(token == null) return Empty.VALUE;
+    byte[] string = toTokenOrNull(arg(0), qc);
+    if(string == null) return Empty.VALUE;
 
     // add leading zero
-    if((token.length & 1) != 0) token = concat(ZERO, token);
+    if((string.length & 1) != 0) string = concat(ZERO, string);
     try {
-      return B64.get(Hex.parse(token, info));
+      return B64.get(Hex.parse(string, info));
     } catch(final QueryException ex) {
       Util.debug(ex);
       throw BIN_NNC.get(info);
