@@ -11,13 +11,15 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class BinToOctets extends StandardFunc {
   @Override
   public Iter iter(final QueryContext qc) throws QueryException {
-    final byte[] bytes = toB64(exprs[0], qc, false).binary(info);
+    final B64 binary = toB64(arg(0), qc, false);
+    final byte[] bytes = binary.binary(info);
+
     return new BasicIter<Int>(bytes.length) {
       @Override
       public Int get(final long i) {
@@ -32,6 +34,6 @@ public final class BinToOctets extends StandardFunc {
 
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    return ConvertBinaryToIntegers.toValue(toB64(exprs[0], qc, false).binary(info));
+    return ConvertBinaryToIntegers.toValue(toB64(arg(0), qc, false).binary(info));
   }
 }
