@@ -12,18 +12,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ClientConnect extends ClientFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final String host = toString(exprs[0], qc);
-    final String user = toString(exprs[2], qc);
-    final String pass = toString(exprs[3], qc);
-    final int port = (int) toLong(exprs[1], qc);
+    final String host = toString(arg(0), qc);
+    final String username = toString(arg(2), qc);
+    final String password = toString(arg(3), qc);
+    final int port = (int) toLong(arg(1), qc);
     try {
-      return sessions(qc).add(new ClientSession(host, port, user, pass));
+      return sessions(qc).add(new ClientSession(host, port, username, password));
     } catch(final IOException ex) {
       throw CLIENT_CONNECT_X.get(info, ex);
     }
