@@ -14,14 +14,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ClientExecute extends ClientFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final ClientSession cs = session(qc, false);
-    final String cmd = toString(exprs[1], qc);
+    final String cmd = toString(arg(1), qc);
 
     try {
       final ArrayOutput ao = new ArrayOutput();
