@@ -13,14 +13,15 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ConvertDayTimeToInteger extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final DTDur dur = (DTDur) checkType(exprs[0], qc, AtomType.DAY_TIME_DURATION);
-    final BigDecimal ms = dur.sec.multiply(Dec.BD_1000);
+    final DTDur value = (DTDur) checkType(arg(0), AtomType.DAY_TIME_DURATION, qc);
+
+    final BigDecimal ms = value.sec.multiply(Dec.BD_1000);
     if(ms.compareTo(Dec.BD_MAXLONG) > 0) throw INTRANGE_X.get(info, ms);
     return Int.get(ms.longValue());
   }
