@@ -9,16 +9,17 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class ConvertDecodeKey extends ConvertIntegersToBase64 {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] string = toToken(exprs[0], qc);
-    final boolean lax = exprs.length > 1 && toBoolean(exprs[1], qc);
-    final byte[] key = XMLToken.decode(string, lax);
-    if(key == null) throw CONVERT_KEY_X.get(info, string);
-    return Str.get(key);
+    final byte[] key = toToken(arg(0), qc);
+    final boolean lax = toBooleanOrFalse(arg(1), qc);
+
+    final byte[] string = XMLToken.decode(key, lax);
+    if(string == null) throw CONVERT_KEY_X.get(info, key);
+    return Str.get(string);
   }
 }
