@@ -7,15 +7,16 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class ConvertEncodeKey extends ConvertIntegersToBase64 {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] string = toToken(exprs[0], qc);
-    final boolean lax = exprs.length > 1 && toBoolean(exprs[1], qc);
-    final byte[] key = XMLToken.encode(string, lax);
-    return Str.get(key);
+    final byte[] key = toToken(arg(0), qc);
+    final boolean lax = toBooleanOrFalse(arg(1), qc);
+
+    final byte[] string = XMLToken.encode(key, lax);
+    return Str.get(string);
   }
 }
