@@ -8,16 +8,16 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Lukas Kircher
  */
 public final class CryptoDecrypt extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] data = toBytes(exprs[0], qc);
-    final String type = toString(exprs[1], qc);
-    final byte[] key = toBytes(exprs[2], qc);
-    final String algorithm = toString(exprs[3], qc);
-    return new Encryption(info).encryption(data, type, key, algorithm, false);
+    final byte[] value = toBytes(arg(0), qc);
+    final String type = toString(arg(1), qc);
+    final byte[] key = toBytes(arg(2), qc);
+    final String algorithm = toString(arg(3), qc);
+    return new Encryption(info).encryption(value, type, key, algorithm, false);
   }
 }
