@@ -3,17 +3,19 @@ package org.basex.query.func.crypto;
 import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.query.value.item.*;
+import org.basex.query.value.node.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Lukas Kircher
  */
 public final class CryptoValidateSignature extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return new DigitalSignature(info).validateSignature(toNode(exprs[0], qc));
+    final ANode node = toNode(arg(0), qc);
+    return new DigitalSignature(info).validateSignature(node);
   }
 }
