@@ -13,18 +13,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class CsvSerialize extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Iter iter = exprs[0].iter(qc);
-    final CsvSerialOptions copts = toOptions(1, new CsvSerialOptions(), qc);
+    final Iter input = arg(0).iter(qc);
+    final CsvSerialOptions options = toOptions(arg(1), new CsvSerialOptions(), true, qc);
 
     final SerializerOptions sopts = new SerializerOptions();
     sopts.set(SerializerOptions.METHOD, SerialMethod.CSV);
-    sopts.set(SerializerOptions.CSV, copts);
-    return Str.get(serialize(iter, sopts, INVALIDOPT_X, qc));
+    sopts.set(SerializerOptions.CSV, options);
+    return Str.get(serialize(input, sopts, INVALIDOPT_X, qc));
   }
 }
