@@ -9,14 +9,14 @@ import org.basex.query.value.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class DbAttribute extends DbText {
   @Override
   public final Iter iter(final QueryContext qc) throws QueryException {
     final Data data = toData(qc);
-    return attribute(data, valueAccess(data, qc), qc, 2);
+    return attribute(arg(2), data, valueAccess(data, qc), qc);
   }
 
   @Override
