@@ -9,14 +9,14 @@ import org.basex.query.value.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DbAttributeRange extends DbTextRange {
   @Override
   public Iter iter(final QueryContext qc) throws QueryException {
     final Data data = toData(qc);
-    return attribute(data, rangeAccess(data, qc), qc, 3);
+    return attribute(arg(3), data, rangeAccess(data, qc), qc);
   }
 
   @Override
