@@ -12,7 +12,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class DbCopy extends DbAccess {
@@ -29,7 +29,7 @@ public class DbCopy extends DbAccess {
    * @throws QueryException query exception
    */
   final void copy(final QueryContext qc, final boolean keep) throws QueryException {
-    final String name = toName(0, qc), newname = toName(1, qc);
+    final String name = toName(arg(0), false, qc), newname = toName(arg(1), false, qc);
     if(name.equals(newname)) throw DB_CONFLICT4_X.get(info, name, newname);
 
     // source database does not exist
@@ -41,6 +41,6 @@ public class DbCopy extends DbAccess {
 
   @Override
   public final boolean accept(final ASTVisitor visitor) {
-    return dataLock(visitor, 0) && dataLock(visitor, 1) && super.accept(visitor);
+    return dataLock(arg(1), false, visitor) && super.accept(visitor);
   }
 }
