@@ -11,18 +11,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
-public final class DbCreateBackup extends DbAccess {
+public final class DbCreateBackup extends BackupFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final String name = toName(0, qc);
-    final CreateBackupOptions opts = toOptions(1, new CreateBackupOptions(), qc);
-    if(!qc.context.soptions.dbExists(name)) throw DB_OPEN1_X.get(info, name);
+    final String name = toName(arg(0), true, qc);
+    final CreateBackupOptions options = toOptions(arg(1), new CreateBackupOptions(), true, qc);
+    if(!name.isEmpty() && !qc.context.soptions.dbExists(name)) throw DB_OPEN1_X.get(info, name);
 
-    final String comment = opts.get(CreateBackupOptions.COMMENT);
-    final boolean compress = opts.get(CreateBackupOptions.COMPRESS);
+    final String comment = options.get(CreateBackupOptions.COMMENT);
+    final boolean compress = options.get(CreateBackupOptions.COMPRESS);
     qc.updates().add(new BackupCreate(name, comment, compress, qc, info), qc);
     return Empty.VALUE;
   }
