@@ -1,6 +1,7 @@
 package org.basex.query.func.db;
 
 import org.basex.data.*;
+import org.basex.index.resource.*;
 import org.basex.io.*;
 import org.basex.query.*;
 import org.basex.query.up.*;
@@ -14,14 +15,14 @@ import org.basex.util.list.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DbDelete extends DbAccess {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Data data = toData(qc);
-    final String path = toDbPath(1, qc);
+    final String path = toDbPath(arg(1), qc);
 
     // delete XML resources
     final IntList docs = data.resources.docs(path);
@@ -30,11 +31,11 @@ public final class DbDelete extends DbAccess {
     for(int d = 0; d < ds; d++) {
       updates.add(new DeleteNode(docs.get(d), data, info), qc);
     }
-
-    // delete binary resources
-    final IOFile bin = data.meta.binary(path);
-    if(bin != null) updates.add(new DBDelete(data, bin, info), qc);
-
+    // delete file resources
+    for(final ResourceType type : Resources.BINARIES) {
+      final IOFile bin = data.meta.file(path, type);
+      if(bin != null) updates.add(new DBDelete(data, bin, info), qc);
+    }
     return Empty.VALUE;
   }
 }
