@@ -11,13 +11,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DbDrop extends DbAccess {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final String name = toName(0, qc);
+    final String name = toName(arg(0), false, qc);
     if(!qc.context.soptions.dbExists(name)) throw DB_OPEN1_X.get(info, name);
     qc.updates().add(new DBDrop(name, qc, info), qc);
     return Empty.VALUE;
