@@ -9,19 +9,19 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DbPath extends DbAccess {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    ANode node, parent = toNode(exprs[0], qc);
+    ANode node, parent = toNode(arg(0), qc);
     do {
       node = parent;
       parent = node.parent();
     } while(parent != null);
 
-    final DBNode dbnode = toDBNode(node);
+    final DBNode dbnode = toDBNode(node, false);
     return dbnode.kind() == Data.DOC ? Str.get(dbnode.data().text(dbnode.pre(), true)) : Str.EMPTY;
   }
 }
