@@ -4,20 +4,21 @@ import static org.basex.query.QueryError.*;
 
 import org.basex.data.*;
 import org.basex.query.*;
+import org.basex.query.expr.*;
 import org.basex.query.value.item.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DbProperty extends DbAccess {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final Data data = toData(qc);
-    final String name = toString(exprs[1], qc);
+    final String name = toString(arg(1), qc);
     final MetaProp prop = MetaProp.get(name);
     if(prop == null) throw DB_PROPERTY_X.get(info, name);
 
@@ -27,4 +28,9 @@ public final class DbProperty extends DbAccess {
     if(value instanceof Long)    return Int.get((Long)    value);
     return Str.get(value.toString());
   }
+
+  @Override
+  protected Expr opt(final CompileContext cc) throws QueryException {
+    return cc.dynamic && allAreValues(true) ? value(cc.qc) : compileData(cc);
+  }
 }
