@@ -9,7 +9,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DbSystem extends StandardFunc {
@@ -18,6 +18,6 @@ public final class DbSystem extends StandardFunc {
 
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) {
-    return DbInfo.toNode(Info.info(qc.context), SYSTEM);
+    return DbInfo.toNode(SYSTEM, Info.info(qc.context));
   }
 }
