@@ -3,6 +3,8 @@ package org.basex.query.func.fetch;
 import static org.basex.query.QueryError.*;
 
 import java.io.*;
+import java.net.http.*;
+import java.util.*;
 
 import org.basex.io.*;
 import org.basex.query.*;
@@ -13,19 +15,20 @@ import org.basex.util.http.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
-public final class FetchContentType extends FetchXml {
+public final class FetchContentType extends FetchDoc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final IO io = toIO(0, qc);
+    final IO io = toIO(arg(0), qc);
 
     MediaType mt = null;
     if(io instanceof IOUrl) {
       try {
-        final String ct = ((IOUrl) io).connection().getContentType();
-        if(ct != null) mt = new MediaType(ct);
+        final HttpHeaders headers = ((IOUrl) io).response().headers();
+        final Optional<String> value = headers.firstValue(HTTPText.CONTENT_TYPE);
+        if(value.isPresent()) mt = new MediaType(value.get());
       } catch(final IOException ex) {
         throw FETCH_OPEN_X.get(info, ex);
       }
