@@ -10,14 +10,16 @@ import org.basex.query.value.seq.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FileDelete extends FileFn {
   @Override
   public Item item(final QueryContext qc) throws QueryException, IOException {
-    final Path path = toPath(0, qc);
-    if(toBoolean(1, qc)) {
+    final Path path = toPath(arg(0), qc);
+    final boolean recursive = toBooleanOrFalse(arg(1), qc);
+
+    if(recursive) {
       delete(path, qc);
     } else {
       Files.delete(path);
