@@ -8,13 +8,13 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FileName extends FileFn {
   @Override
   public Item item(final QueryContext qc) throws QueryException {
-    final Path path = toPath(0, qc).getFileName();
+    final Path path = toPath(arg(0), qc).getFileName();
     return path == null ? Str.EMPTY : Str.get(path.toString());
   }
 }
