@@ -9,13 +9,13 @@ import org.basex.query.value.seq.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FileParent extends FileFn {
   @Override
   public Item item(final QueryContext qc) throws QueryException {
-    final Path parent = absolute(toPath(0, qc)).getParent();
+    final Path parent = absolute(toPath(arg(0), qc)).getParent();
     return parent == null ? Empty.VALUE : get(parent, true);
   }
 }
