@@ -10,13 +10,13 @@ import org.basex.query.value.item.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FileSize extends FileFn {
   @Override
   public Item item(final QueryContext qc) throws IOException, QueryException {
-    final Path path = toPath(0, qc);
+    final Path path = toPath(arg(0), qc);
     final BasicFileAttributes attrs = Files.readAttributes(path, BasicFileAttributes.class);
     return Int.get(attrs.isDirectory() ? 0 : attrs.size());
   }
