@@ -11,14 +11,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnAbs extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final ANum num = toNumberOrNull(exprs[0], qc);
-    return num == null ? Empty.VALUE : num.abs();
+    final ANum value = toNumberOrNull(arg(0), qc);
+    return value == null ? Empty.VALUE : value.abs();
   }
 
   @Override
@@ -26,7 +26,7 @@ public final class FnAbs extends StandardFunc {
     final Expr expr = optFirst();
     if(expr != this) return expr;
 
-    Type type = exprs[0].seqType().type;
+    Type type = arg(0).seqType().type;
     if(type.isUntyped()) type = AtomType.DOUBLE;
     if(type.isNumber()) {
       exprType.assign(type.instanceOf(AtomType.INTEGER) ? AtomType.INTEGER : type);
