@@ -14,25 +14,27 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnCompare extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] token1 = toTokenOrNull(exprs[0], qc), token2 = toTokenOrNull(exprs[1], qc);
-    final Collation coll = toCollation(2, qc);
-    if(token1 == null || token2 == null) return Empty.VALUE;
-    final long diff = coll == null ? diff(token1, token2) : coll.compare(token1, token2);
+    final byte[] value1 = toTokenOrNull(arg(0), qc);
+    final byte[] value2 = toTokenOrNull(arg(1), qc);
+    final Collation coll = toCollation(arg(2), qc);
+
+    if(value1 == null || value2 == null) return Empty.VALUE;
+    final long diff = diff(value1, value2, coll);
     return Int.get(diff < 0 ? -1 : diff > 0 ? 1 : 0);
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Expr expr1 = exprs[0], expr2 = exprs[1];
-    final SeqType st1 = expr1.seqType(), st2 = expr2.seqType();
-    if(st1.zero()) return expr1;
-    if(st2.zero()) return expr2;
+    final Expr value1 = arg(0), value2 = arg(1);
+    final SeqType st1 = value1.seqType(), st2 = value2.seqType();
+    if(st1.zero()) return value1;
+    if(st2.zero()) return value2;
     if(st1.oneOrMore() && !st1.mayBeArray() && st2.oneOrMore() && !st2.mayBeArray())
       exprType.assign(Occ.EXACTLY_ONE);
     return this;
