@@ -12,23 +12,27 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnContains extends StandardFunc {
   @Override
   public Bln item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] string = toZeroToken(exprs[0], qc), sub = toZeroToken(exprs[1], qc);
-    final Collation coll = toCollation(2, qc);
-    return Bln.get(coll == null ? Token.contains(string, sub) : coll.contains(string, sub, info));
+    final byte[] value = toZeroToken(arg(0), qc);
+    final byte[] substring = toZeroToken(arg(1), qc);
+    final Collation coll = toCollation(arg(2), qc);
+
+    return Bln.get(coll == null ? Token.contains(value, substring) :
+      coll.contains(value, substring, info));
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Expr expr1 = exprs[0], expr2 = exprs[1];
+    final Expr value = arg(0), substring = arg(1);
     // contains($a, ''), contains($a, $a)
-    if(exprs.length < 3 && expr1.seqType().type.isStringOrUntyped() && !expr1.has(Flag.NDT)) {
-      if(expr2 == Empty.VALUE || expr2 == Str.EMPTY || expr1.equals(expr2)) return Bln.TRUE;
+    if(!defined(2) && value.seqType().type.isStringOrUntyped() && !value.has(Flag.NDT)) {
+      if(substring == Empty.VALUE || substring == Str.EMPTY || value.equals(substring))
+        return Bln.TRUE;
     }
     return this;
   }
