@@ -4,6 +4,7 @@ import static org.basex.util.Token.*;
 
 import org.basex.index.*;
 import org.basex.query.*;
+import org.basex.query.expr.*;
 import org.basex.query.func.*;
 import org.basex.query.iter.*;
 import org.basex.query.util.collation.*;
@@ -14,19 +15,19 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnContainsToken extends StandardFunc {
   @Override
   public Bln item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] token = trim(toToken(exprs[1], qc));
-    final Collation coll = toCollation(2, qc);
+    final byte[] token = trim(toToken(arg(1), qc));
+    final Collation coll = toCollation(arg(2), qc);
     if(token.length != 0) {
-      final Iter iter = exprs[0].iter(qc);
-      for(Item item; (item = qc.next(iter)) != null;) {
-        for(final byte[] tok : distinctTokens(toToken(item))) {
-          if(coll == null ? eq(token, tok) : coll.compare(token, tok) == 0) return Bln.TRUE;
+      final Iter value = arg(0).iter(qc);
+      for(Item item; (item = qc.next(value)) != null;) {
+        for(final byte[] distinct : distinctTokens(toToken(item))) {
+          if(eq(token, distinct, coll)) return Bln.TRUE;
         }
       }
     }
@@ -36,7 +37,8 @@ public final class FnContainsToken extends StandardFunc {
   @Override
   public boolean indexAccessible(final IndexInfo ii) throws QueryException {
     // support limited to default collation
-    return exprs.length == 2 && exprs[1].seqType().zeroOrOne() &&
-      ii.create(exprs[1], ii.type(exprs[0], IndexType.TOKEN), true, info);
+    final Expr value = arg(0), token = arg(1);
+    return !defined(2) && token.seqType().zeroOrOne() &&
+      ii.create(token, ii.type(value, IndexType.TOKEN), true, info);
   }
 }
