@@ -1,17 +1,16 @@
 package org.basex.query.func.fn;
 
 import org.basex.query.*;
-import org.basex.query.func.*;
 import org.basex.query.value.item.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
-public final class FnCurrentTime extends StandardFunc {
+public final class FnCurrentTime extends DynamicFn {
   @Override
   public Tim item(final QueryContext qc, final InputInfo ii) throws QueryException {
     return qc.dateTime().time;
