@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnDefaultCollation extends StandardFunc {
   @Override
   public Uri item(final QueryContext qc, final InputInfo ii) {
     final Collation coll = sc.collation;
-    return Uri.uri(coll == null ? QueryText.COLLATION_URI : coll.uri());
+    return Uri.get(coll == null ? QueryText.COLLATION_URI : coll.uri());
   }
 }
