@@ -8,17 +8,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
-public final class FnDoc extends Docs {
+public final class FnDoc extends FnDocAvailable {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     return doc(qc);
   }
 
   @Override
-  protected Expr opt(final CompileContext cc) {
-    return optFirst();
+  protected Expr opt(final CompileContext cc) throws QueryException {
+    final Expr expr = optFirst();
+    return expr != this ? expr : super.opt(cc);
   }
 }
