@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnEnvironmentVariable extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final String value = System.getenv(toString(exprs[0], qc));
+    final String value = System.getenv(toString(arg(0), qc));
     return value != null ? Str.get(value) : Empty.VALUE;
   }
 }
