@@ -7,27 +7,26 @@ import org.basex.query.expr.*;
 import org.basex.query.func.*;
 import org.basex.query.iter.*;
 import org.basex.query.value.item.*;
-import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnExactlyOne extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     // if possible, retrieve single item
-    final Expr expr = exprs[0];
+    final Expr input = arg(0);
     Item item;
-    if(expr.seqType().zeroOrOne()) {
-      item = expr.item(qc, info);
-      if(item != Empty.VALUE) return item;
+    if(input.seqType().zeroOrOne()) {
+      item = input.item(qc, info);
+      if(!item.isEmpty()) return item;
     } else {
-      final Iter iter = expr.iter(qc);
+      final Iter iter = input.iter(qc);
       item = iter.next();
       if(item != null && iter.next() != null) item = null;
       if(item != null) return item;
@@ -37,13 +36,12 @@ public final class FnExactlyOne extends StandardFunc {
 
   @Override
   protected Expr opt(final CompileContext cc) throws QueryException {
-    final Expr expr = exprs[0];
-    final SeqType st = expr.seqType();
-    if(st.one()) return expr;
-    if(st.zero() || expr.size() > 1) throw EXACTLYONE.get(info);
+    final Expr input = arg(0);
+    final SeqType st = input.seqType();
+    if(st.one()) return input;
+    if(st.zero() || input.size() > 1) throw EXACTLYONE.get(info);
 
-    exprType.assign(st.with(Occ.EXACTLY_ONE));
-    data(expr.data());
+    exprType.assign(st.with(Occ.EXACTLY_ONE)).data(input);
     return this;
   }
 }
