@@ -10,7 +10,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnExists extends FnEmpty {
@@ -22,12 +22,7 @@ public final class FnExists extends FnEmpty {
   @Override
   public Expr simplifyFor(final Simplify mode, final CompileContext cc) throws QueryException {
     // if(exists(nodes))  ->  if(nodes)
-    if(mode.oneOf(Simplify.EBV, Simplify.PREDICATE)) {
-      final Expr expr = exprs[0];
-      if(expr.seqType().type instanceof NodeType) {
-        return cc.simplify(this, expr.simplifyFor(mode, cc));
-      }
-    }
-    return this;
+    return cc.simplify(this, mode.oneOf(Simplify.EBV, Simplify.PREDICATE) &&
+        arg(0).seqType().type instanceof NodeType ? arg(0) : this, mode);
   }
 }
