@@ -10,14 +10,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnFloor extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final ANum num = toNumberOrNull(exprs[0], qc);
-    return num == null ? Empty.VALUE : num.floor();
+    final ANum value = toNumberOrNull(arg(0), qc);
+    return value == null ? Empty.VALUE : value.floor();
   }
 
   @Override
