@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnFunctionName extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final QNm name = toFunction(exprs[0], qc).funcName();
+    final QNm name = toFunction(arg(0), qc).funcName();
     return name == null ? Empty.VALUE : name;
   }
 }
