@@ -13,18 +13,21 @@ import org.basex.util.list.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
-public final class FnInScopePrefixes extends StandardFunc {
+public class FnInScopePrefixes extends StandardFunc {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    final Atts atts = toElem(exprs[0], qc).nsScope(sc).add(XML, XML_URI);
+    final Atts atts = toElem(arg(0), qc).nsScope(sc).add(XML, XML_URI);
+
     final int as = atts.size();
     final TokenList tl = new TokenList();
     for(int a = 0; a < as; ++a) {
       final byte[] key = atts.name(a);
-      if(key.length + atts.value(a).length != 0) tl.add(key);
+      if(key.length + atts.value(a).length != 0) {
+        tl.add(key);
+      }
     }
     return StrSeq.get(tl);
   }
