@@ -6,12 +6,12 @@ import org.basex.query.iter.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnInnermost extends FnOutermost {
   @Override
   public Iter iter(final QueryContext qc) throws QueryException {
-    return most(qc, false);
+    return iter(false, qc);
   }
 }
