@@ -10,12 +10,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnIriToUri extends StandardFunc {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return Str.get(encodeUri(toZeroToken(exprs[0], qc), true));
+    return Str.get(encodeUri(toZeroToken(arg(0), qc), true));
   }
 }
