@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class FnJsonToXml extends FnParseJson {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Item item = exprs[0].atomItem(qc, info);
-    return item == Empty.VALUE ? Empty.VALUE : parse(toToken(item), true, qc);
+    final Item json = arg(0).atomItem(qc, info);
+    return json.isEmpty() ? Empty.VALUE : parse(toToken(json), true, qc);
   }
 }
