@@ -12,14 +12,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnLang extends Ids {
   @Override
   public Bln item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] lang = lc(toZeroToken(exprs[0], qc));
-    final ANode node = toNode(ctxArg(1, qc), qc);
+    final byte[] lang = lc(toZeroToken(arg(0), qc));
+    final ANode node = toNode(context(qc), qc);
     for(ANode nd = node; nd != null; nd = nd.parent()) {
       final BasicNodeIter atts = nd.attributeIter();
       for(ANode at; (at = atts.next()) != null;) {
