@@ -3,8 +3,6 @@ package org.basex.query.func.fn;
 import static org.basex.query.func.Function.*;
 import static org.basex.util.Token.*;
 
-import java.util.regex.*;
-
 import org.basex.query.*;
 import org.basex.query.expr.*;
 import org.basex.query.value.item.*;
@@ -14,31 +12,31 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnMatches extends RegEx {
   @Override
   public Bln item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] value = toZeroToken(exprs[0], qc), pttrn = toToken(exprs[1], qc);
+    final byte[] value = toZeroToken(arg(0), qc), pattern = toToken(arg(1), qc);
+    final Expr flags = defined(2) ? arg(2) : null;
 
-    if(exprs.length < 3) {
-      final int ch = patternChar(pttrn);
+    if(flags == null) {
+      final int ch = patternChar(pattern);
       if(ch != -1) return Bln.get(contains(value, ch));
     }
-    final Pattern pattern = pattern(pttrn, exprs.length == 3 ? exprs[2] : null, qc, false);
-    return Bln.get(pattern.matcher(string(value)).find());
+    return Bln.get(pattern(pattern, flags, qc, false).matcher(string(value)).find());
   }
 
   @Override
   protected Expr opt(final CompileContext cc) throws QueryException {
-    final Expr expr1 = exprs[0], expr2 = exprs[1];
+    final Expr value = arg(0), pattern = arg(1);
 
-    final SeqType st1 = expr1.seqType();
-    if(st1.zero() || st1.one() && st1.type.isStringOrUntyped()) {
-      if(expr2 instanceof Str && exprs.length < 3) {
-        if(expr2 == Str.EMPTY) return Bln.TRUE;
-        for(final byte b : ((Str) expr2).string()) {
+    final SeqType st = value.seqType();
+    if(st.zero() || st.one() && st.type.isStringOrUntyped()) {
+      if(pattern instanceof Str && !defined(2)) {
+        if(pattern == Str.EMPTY) return Bln.TRUE;
+        for(final byte b : ((Str) pattern).string()) {
           if(contains(REGEX_CHARS, b)) return this;
         }
         return cc.function(CONTAINS, info, args());
