@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnMonthsFromDuration extends DateTime {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Item item = exprs[0].atomItem(qc, info);
-    return item == Empty.VALUE ? Empty.VALUE : Int.get(checkDur(item).mon());
+    final Item value = arg(0).atomItem(qc, info);
+    return value == Empty.VALUE ? Empty.VALUE : Int.get(checkDur(value).mon());
   }
 }
