@@ -13,17 +13,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnNamespaceUriForPrefix extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] pref = toZeroToken(exprs[0], qc);
-    final ANode an = toElem(exprs[1], qc);
-    if(eq(pref, XML)) return Uri.uri(XML_URI, false);
-    final Atts at = an.nsScope(sc);
-    final byte[] s = at.value(pref);
-    return s == null || s.length == 0 ? Empty.VALUE : Uri.uri(s, false);
+    final byte[] prefix = toZeroToken(arg(0), qc);
+    final ANode element = toElem(arg(1), qc);
+
+    if(eq(prefix, XML)) return Uri.get(XML_URI, false);
+    final Atts at = element.nsScope(sc);
+    final byte[] uri = at.value(prefix);
+    return uri == null || uri.length == 0 ? Empty.VALUE : Uri.get(uri, false);
   }
 }
