@@ -7,12 +7,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnNormalizeSpace extends ContextFn {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return Str.get(Token.normalize(toZeroToken(ctxArg(0, qc), qc)));
+    return Str.get(Token.normalize(toZeroToken(context(qc), qc)));
   }
 }
