@@ -3,7 +3,6 @@ package org.basex.query.func.fn;
 import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 
-import java.text.*;
 import java.text.Normalizer.Form;
 
 import org.basex.query.*;
@@ -14,25 +13,25 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnNormalizeUnicode extends StandardFunc {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] str = toZeroToken(exprs[0], qc);
+    final byte[] value = toZeroToken(arg(0), qc);
 
-    Form form = Form.NFC;
-    if(exprs.length == 2) {
-      final byte[] n = uc(trim(toToken(exprs[1], qc)));
-      if(n.length == 0) return Str.get(str);
+    Form frm = Form.NFC;
+    if(defined(1)) {
+      final byte[] form = uc(trim(toToken(arg(1), qc)));
+      if(form.length == 0) return Str.get(value);
       try {
-        form = Form.valueOf(string(n));
+        frm = Form.valueOf(string(form));
       } catch(final IllegalArgumentException ex) {
         Util.debug(ex);
-        throw NORMUNI_X.get(info, n);
+        throw NORMUNI_X.get(info, form);
       }
     }
-    return ascii(str) ? Str.get(str) : Str.get(Normalizer.normalize(string(str), form));
+    return Str.get(Token.normalize(value, frm));
   }
 }
