@@ -1,24 +1,18 @@
 package org.basex.query.func.fn;
 
 import org.basex.query.*;
-import org.basex.query.expr.*;
 import org.basex.query.value.item.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
-public final class FnParseXmlFragment extends Parse {
+public final class FnParseXmlFragment extends FnParseXml {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     return parseXml(qc, true);
   }
-
-  @Override
-  protected Expr opt(final CompileContext cc) {
-    return optFirst();
-  }
 }
