@@ -11,15 +11,15 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnPrefixFromQName extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final QNm qname = toQNm(exprs[0], qc, true);
-    return qname == null || !qname.hasPrefix() ? Empty.VALUE :
-      AtomType.NCNAME.cast(Str.get(qname.prefix()), qc, sc, info);
+    final QNm value = toQNm(arg(0), true, qc);
+    return value == null || !value.hasPrefix() ? Empty.VALUE :
+      AtomType.NCNAME.cast(Str.get(value.prefix()), qc, sc, info);
   }
 
   @Override
