@@ -13,18 +13,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnQName extends StandardFunc {
   @Override
   public QNm item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] uri = toZeroToken(exprs[0], qc);
-    final byte[] name = toToken(exprs[1], qc);
-    final byte[] str = !contains(name, ':') && eq(uri, XML_URI) ? concat(XML_COLON, name) : name;
-    if(!XMLToken.isQName(str)) throw valueError(AtomType.QNAME, name, info);
-    final QNm qname = new QNm(str, uri);
-    if(qname.hasPrefix() && uri.length == 0) throw valueError(AtomType.ANY_URI, qname.uri(), info);
-    return qname;
+    final byte[] uri = toZeroToken(arg(0), qc), qname = toToken(arg(1), qc);
+    final byte[] name = !contains(qname, ':') && eq(uri, XML_URI)
+        ? concat(XML_COLON, qname) : qname;
+    if(!XMLToken.isQName(name)) throw valueError(AtomType.QNAME, qname, info);
+    final QNm qnm = new QNm(name, uri);
+    if(qnm.hasPrefix() && uri.length == 0) throw valueError(AtomType.ANY_URI, qnm.uri(), info);
+    return qnm;
   }
 }
