@@ -7,21 +7,21 @@ import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.query.iter.*;
 import org.basex.query.value.item.*;
-import org.basex.query.value.seq.*;
 import org.basex.util.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnSerialize extends StandardFunc {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Iter iter = exprs[0].iter(qc);
-    final Item so = exprs.length > 1 ? exprs[1].item(qc, info) : Empty.VALUE;
-    final SerializerOptions sopts = FuncOptions.serializer(so, info);
-    return Str.get(serialize(iter, sopts, SER_X, qc));
+    final Iter input = arg(0).iter(qc);
+    final Item options = arg(1).item(qc, info);
+
+    final SerializerOptions sopts = FuncOptions.serializer(options, info);
+    return Str.get(serialize(input, sopts, SER_X, qc));
   }
 }
