@@ -3,29 +3,37 @@ package org.basex.query.func.fn;
 import static org.basex.util.Token.*;
 
 import org.basex.query.*;
+import org.basex.query.expr.*;
 import org.basex.query.func.*;
 import org.basex.query.iter.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.seq.*;
+import org.basex.util.list.*;
 
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnStringToCodepoints extends StandardFunc {
   @Override
   public Iter iter(final QueryContext qc) throws QueryException {
-    final byte[] token = toZeroToken(exprs[0], qc);
-    final int tl = token.length;
+    final byte[] value = toZeroToken(arg(0), qc);
+    final int tl = value.length;
 
-    if(ascii(token)) {
+    if(ascii(value)) {
       return new BasicIter<Int>(tl) {
         @Override
         public Int get(final long i) {
-          return Int.get(token[(int) i]);
+          return Int.get(value[(int) i]);
+        }
+        @Override
+        public Value value(final QueryContext q, final Expr expr) throws QueryException {
+          final LongList list = new LongList(Seq.initialCapacity(size));
+          for(final byte b : value) list.add(b);
+          return IntSeq.get(list);
         }
       };
     }
@@ -36,8 +44,8 @@ public final class FnStringToCodepoints extends StandardFunc {
       @Override
       public Int next() {
         if(t == tl) return null;
-        final int cp = cp(token, t);
-        t += cl(token, t);
+        final int cp = cp(value, t);
+        t += cl(value, t);
         return Int.get(cp);
       }
     };
@@ -45,6 +53,9 @@ public final class FnStringToCodepoints extends StandardFunc {
 
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    return IntSeq.get(cps(toZeroToken(exprs[0], qc)));
+    final int[] cps = cps(toZeroToken(arg(0), qc));
+    final LongList list = new LongList(cps.length);
+    for(final int cp : cps) list.add(cp);
+    return IntSeq.get(list);
   }
 }
