@@ -8,18 +8,18 @@ import org.basex.query.value.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FnUnordered extends StandardFunc {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
     // implementation for dynamic function lookup
-    return exprs[0].value(qc);
+    return arg(0).value(qc);
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    return exprs[0];
+    return arg(0);
   }
 }
