@@ -9,24 +9,24 @@ import org.basex.query.value.node.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
-public final class FnUriCollection extends Docs {
+public final class FnUriCollection extends FnCollection {
   @Override
   public Iter iter(final QueryContext qc) throws QueryException {
-    final Iter iter = collection(qc).iter();
-    final long size = iter.size();
+    final Iter uri = collection(qc).iter();
+    final long size = uri.size();
 
     return new Iter() {
       @Override
       public Item next() throws QueryException {
-        final Item item = qc.next(iter);
+        final Item item = qc.next(uri);
         return item != null ? toUri(item) : null;
       }
       @Override
       public Item get(final long i) throws QueryException {
-        return toUri(iter.get(i));
+        return toUri(uri.get(i));
       }
       @Override
       public long size() {
@@ -48,6 +48,6 @@ public final class FnUriCollection extends Docs {
    * @return URI
    */
   private static Uri toUri(final Item item) {
-    return Uri.uri(((ANode) item).baseURI(), false);
+    return Uri.get(((ANode) item).baseURI(), false);
   }
 }
