@@ -9,12 +9,11 @@ import org.basex.query.util.format.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
-import org.basex.util.list.*;
 
 /**
  * Formatting functions.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 abstract class Format extends StandardFunc {
@@ -26,24 +25,16 @@ abstract class Format extends StandardFunc {
    * @throws QueryException query exception
    */
   final Item formatDate(final AtomType tp, final QueryContext qc) throws QueryException {
-    final int el = exprs.length;
-    if(el == 3 || el == 4) throw Functions.wrongArity(definition, el, new IntList(), info);
+    final Item value = arg(0).atomItem(qc, info);
+    if(value.isEmpty()) return Empty.VALUE;
 
-    final Item item = exprs[0].atomItem(qc, info);
-    if(item == Empty.VALUE) return Empty.VALUE;
+    final byte[] picture = toZeroToken(arg(1), qc);
+    final byte[] language = toZeroToken(arg(2), qc);
+    byte[] calendar = toTokenOrNull(arg(3), qc);
+    if(calendar != null) calendar = trim(calendar);
+    final byte[] place = toZeroToken(arg(4), qc);
 
-    final byte[] picture = toZeroToken(exprs[1], qc);
-
-    final boolean more = el == 5;
-    final byte[] language = more ? toZeroToken(exprs[2], qc) : EMPTY;
-    byte[] calendar = null;
-    if(more) {
-      calendar = toTokenOrNull(exprs[3], qc);
-      if(calendar != null) calendar = trim(calendar);
-    }
-    final byte[] place = more ? toZeroToken(exprs[4], qc) : EMPTY;
-
-    final ADate date = toDate(item, tp, qc);
+    final ADate date = toDate(value, tp, qc);
     final Formatter form = Formatter.get(language);
     return Str.get(form.formatDate(date, language, picture, calendar, place, sc, info));
   }
