@@ -9,7 +9,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class FtCount extends FtAccess {
@@ -17,8 +17,10 @@ public final class FtCount extends FtAccess {
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
     final FTPosData tmp = qc.ftPosData;
     qc.ftPosData = new FTPosData();
-    final Iter iter = exprs[0].iter(qc);
-    for(Item item; (item = qc.next(iter)) != null;) toDBNode(item);
+    final Iter nodes = arg(0).iter(qc);
+    for(Item item; (item = qc.next(nodes)) != null;) {
+      toDBNode(item, true);
+    }
     final int size = qc.ftPosData.size();
     qc.ftPosData = tmp;
     return Int.get(size);
