@@ -7,12 +7,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class HashHash extends HashFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return hash(toString(exprs[1], qc), qc);
+    return hash(toString(arg(1), qc), qc);
   }
 }
