@@ -13,24 +13,26 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class HofTopKWith extends HofFn {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    final Comparator<Item> comp = getComp(1, qc);
-    final long k = Math.min(toLong(exprs[2], qc), Integer.MAX_VALUE);
+    final Iter input = arg(0).iter(qc);
+    final Comparator<Item> comparator = comparator(qc);
+    final long k = Math.min(toLong(arg(2), qc), Integer.MAX_VALUE);
     if(k < 1) return Empty.VALUE;
 
-    final Iter iter = exprs[0].iter(qc);
-    final MinHeap<Item, Item> heap = new MinHeap<>(comp);
+    final MinHeap<Item, Item> heap = new MinHeap<>(comparator);
     try {
-      for(Item item; (item = qc.next(iter)) != null;) {
+      for(Item item; (item = qc.next(input)) != null;) {
         heap.insert(item, item);
         if(heap.size() > k) heap.removeMin();
       }
-    } catch(final QueryRTException ex) { throw ex.getCause(); }
+    } catch(final QueryRTException ex) {
+      throw ex.getCause();
+    }
 
     final ValueBuilder vb = new ValueBuilder(qc);
     while(!heap.isEmpty()) vb.addFront(heap.removeMin());
@@ -40,7 +42,7 @@ public final class HofTopKWith extends HofFn {
   @Override
   protected Expr opt(final CompileContext cc) {
     // even single items must be sorted, as the input might be invalid
-    final Expr expr = exprs[0];
-    return expr.seqType().zero() ? expr : adoptType(expr);
+    final Expr input = arg(0);
+    return input.seqType().zero() ? input : adoptType(input);
   }
 }
