@@ -10,27 +10,27 @@ import org.basex.query.value.type.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class HofUntil extends StandardFunc {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    final FItem pred = toFunction(exprs[0], 1, qc), func = toFunction(exprs[1], 1, qc);
-    Value value = exprs[2].value(qc);
+    final FItem predicate = toFunction(arg(0), 1, qc), action = toFunction(arg(1), 1, qc);
+    Value value = arg(2).value(qc);
 
-    while(!toBoolean(pred.invoke(qc, info, value).item(qc, info))) {
-      value = func.invoke(qc, info, value);
+    while(!toBoolean(predicate.invoke(qc, info, value).item(qc, info))) {
+      value = action.invoke(qc, info, value);
     }
     return value;
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Expr expr2 = exprs[1], expr3 = exprs[2];
-    final FuncType ft = expr2.funcType();
+    final Expr action = arg(1), zero = arg(2);
+    final FuncType ft = action.funcType();
     if(ft != null) {
-      final SeqType st = ft.declType.intersect(expr3.seqType());
+      final SeqType st = ft.declType.intersect(zero.seqType());
       if(st != null) exprType.assign(st);
     }
     return this;
