@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class HtmlDoc extends HtmlParse {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] uri = toTokenOrNull(exprs[0], qc);
-    return uri != null ? parse(toIO(uri), qc) : Empty.VALUE;
+    final String href = toStringOrNull(arg(0), qc);
+    return href != null ? parse(toIO(href), qc) : Empty.VALUE;
   }
 }
