@@ -11,18 +11,18 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class InspectFunctionAnnotations extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    XQMap map = XQMap.empty();
-    for(final Ann ann : toFunction(exprs[0], qc).annotations()) {
+    final MapBuilder mb = new MapBuilder(info);
+    for(final Ann ann : toFunction(arg(0), qc).annotations()) {
       final ValueBuilder vb = new ValueBuilder(qc);
       for(final Item arg : ann.value()) vb.add(arg);
-      map = map.put(ann.name(), vb.value(), info);
+      mb.put(ann.name(), vb.value());
     }
-    return map;
+    return mb.map();
   }
 }
