@@ -8,12 +8,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class InspectModule extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return new PlainDoc(qc, info).parse(toContent(toToken(exprs[0], qc), qc));
+    return new PlainDoc(qc, info).parse(toContent(toString(arg(0), qc), qc));
   }
 }
