@@ -41,7 +41,7 @@ import org.w3c.dom.Text;
  * This class contains common methods for executing Java code and mapping
  * Java objects to XQuery values.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public abstract class JavaCall extends Arr {
@@ -168,7 +168,7 @@ public abstract class JavaCall extends Arr {
       return new Object[0];
     }
 
-    // convert empty number to smallest type
+    // convert empty number to the smallest type
     if(arg instanceof ANum) {
       final double d = ((ANum) arg).dbl();
       if((param == byte.class  || param == Byte.class)      && (byte)  d == d) return (byte)   d;
@@ -176,7 +176,7 @@ public abstract class JavaCall extends Arr {
       if((param == char.class  || param == Character.class) && (char)  d == d) return (char)   d;
       if((param == int.class   || param == Integer.class)   && (int)   d == d) return (int)    d;
       if((param == float.class || param == Float.class)     && (float) d == d) return (float)  d;
-      if(param == double.class || param == Double.class)                       return (double) d;
+      if(param == double.class || param == Double.class)                       return d;
     }
 
     // convert to Java object
@@ -187,7 +187,7 @@ public abstract class JavaCall extends Arr {
 
     // return value
     // - if argument is an instance of the function parameter, or
-    // - if value is null and and parameter is not primitive
+    // - if value is null and parameter is not primitive
     if(param.isInstance(value) || value == null && !param.isPrimitive()) return value;
 
     // give up
@@ -200,7 +200,7 @@ public abstract class JavaCall extends Arr {
    * @param candidates candidates
    * @return best candidate, or {@code null} if multiple candidates are left
    */
-  final JavaCandidate bestCandidate(final ArrayList<JavaCandidate> candidates) {
+  static JavaCandidate bestCandidate(final ArrayList<JavaCandidate> candidates) {
     if(((Checks<JavaCandidate>) jc -> jc.exact).any(candidates)) {
       for(int c = candidates.size() - 1; c >= 0; c--) {
         if(!candidates.get(c).exact) candidates.remove(c);
@@ -314,13 +314,13 @@ public abstract class JavaCall extends Arr {
           final Iterator<?> ir = (Iterator<?>) object;
           while(ir.hasNext()) vb.add(toValue(ir.next(), qc, info, wrap));
         } else if(object instanceof Map) {
-          XQMap map = XQMap.empty();
+          final MapBuilder mb = new MapBuilder(info);
           for(final Map.Entry<?, ?> entry : ((Map<?, ?>) object).entrySet()) {
             final Item key = toValue(entry.getKey(), qc, info, wrap).item(qc, info);
-            final Value val = toValue(entry.getValue(), qc, info, wrap);
-            map = map.put(key, val, info);
+            final Value value = toValue(entry.getValue(), qc, info, wrap);
+            mb.put(key, value);
           }
-          vb.add(map);
+          vb.add(mb.map());
         } else {
           vb.add(Str.get(object.toString()));
         }
@@ -443,7 +443,7 @@ public abstract class JavaCall extends Arr {
       throw noMember(name, types, arity, string(qname.string()), arities, names.finish(), info);
     }
     if(cs > 1) throw JAVAMULTIPLE_X_X.get(info, qname.string(),
-        paramTypes(candidates.toArray(new Executable[0]), false));
+        paramTypes(candidates.toArray(Executable[]::new), false));
 
     // single method found: add module locks to query context
     final Method method = candidates.get(0);
