@@ -8,25 +8,25 @@ import org.basex.query.value.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class LazyCache extends StandardFunc {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    final Value value = exprs[0].value(qc);
-    final boolean lazy = exprs.length > 1 && toBoolean(exprs[1], qc);
+    final Value value = arg(0).value(qc);
+    final boolean lazy = toBooleanOrFalse(arg(1), qc);
     value.cache(lazy, info);
     return value;
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    return adoptType(exprs[0]);
+    return adoptType(arg(0));
   }
 
   @Override
   public boolean ddo() {
-    return exprs[0].ddo();
+    return arg(0).ddo();
   }
 }
