@@ -8,12 +8,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class LazyIsLazy extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return Bln.get(toAtomItem(exprs[0], qc) instanceof Lazy);
+    return Bln.get(toAtomItem(arg(0), qc) instanceof Lazy);
   }
 }
