@@ -10,22 +10,22 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class MapContains extends StandardFunc {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final XQMap map = toMap(exprs[0], qc);
-    final Item key = toAtomItem(exprs[1], qc);
+  public Bln item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    final XQMap map = toMap(arg(0), qc);
+    final Item key = toAtomItem(arg(1), qc);
 
     return Bln.get(map.contains(key, info));
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Expr expr1 = exprs[0];
-    if(expr1 == XQMap.empty()) return Bln.FALSE;
+    final Expr map = arg(0);
+    if(map == XQMap.empty()) return Bln.FALSE;
 
     return this;
   }
