@@ -12,22 +12,22 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class MapEntry extends StandardFunc {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Item key = toAtomItem(exprs[0], qc);
-    final Value value = exprs[1].value(qc);
+  public XQMap item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    final Item key = toAtomItem(arg(0), qc);
+    final Value value = arg(1).value(qc);
 
     return XQMap.entry(key, value, info);
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final AtomType type1 = exprs[0].seqType().type.atomic();
-    if(type1 != null) exprType.assign(MapType.get(type1, exprs[1].seqType()));
+    final AtomType type = arg(0).seqType().type.atomic();
+    if(type != null) exprType.assign(MapType.get(type, arg(1).seqType()));
     return this;
   }
 
