@@ -10,20 +10,20 @@ import org.basex.query.value.type.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class MapKeys extends StandardFunc {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    final XQMap map = toMap(exprs[0], qc);
+    final XQMap map = toMap(arg(0), qc);
 
     return map.keys();
   }
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Type type = exprs[0].seqType().type;
+    final Type type = arg(0).seqType().type;
     if(type instanceof MapType) exprType.assign(((MapType) type).keyType());
     return this;
   }
