@@ -12,14 +12,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class MapRemove extends StandardFunc {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    XQMap map = toMap(exprs[0], qc);
-    final Iter keys = exprs[1].iter(qc);
+  public XQMap item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    XQMap map = toMap(arg(0), qc);
+    final Iter keys = arg(1).iter(qc);
 
     for(Item item; (item = qc.next(keys)) != null;) {
       map = map.delete(toAtomItem(item, qc), info);
@@ -29,10 +29,10 @@ public final class MapRemove extends StandardFunc {
 
   @Override
   protected Expr opt(final CompileContext cc) {
-    final Expr expr1 = exprs[0];
-    if(expr1 == XQMap.empty()) return expr1;
+    final Expr map = arg(0);
+    if(map == XQMap.empty()) return map;
 
-    final Type type = expr1.seqType().type;
+    final Type type = map.seqType().type;
     if(type instanceof MapType) exprType.assign(type);
     return this;
   }
