@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class MapSize extends StandardFunc {
   @Override
-  public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final XQMap map = toMap(exprs[0], qc);
+  public Int item(final QueryContext qc, final InputInfo ii) throws QueryException {
+    final XQMap map = toMap(arg(0), qc);
 
     return Int.get(map.mapSize());
   }
