@@ -10,13 +10,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class MathSinh extends MathFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Item item = exprs[0].atomItem(qc, info);
-    return item == Empty.VALUE ? Empty.VALUE : Dbl.get(sinh(toDouble(item)));
+    final Item radians = arg(0).atomItem(qc, info);
+    return radians.isEmpty() ? Empty.VALUE : Dbl.get(sinh(toDouble(radians)));
   }
 }
