@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ProcProperty extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final String name = toString(exprs[0], qc), value = Prop.get(name);
+    final String name = toString(arg(0), qc), value = Prop.get(name);
     return value == null ? Empty.VALUE : Str.get(value);
   }
 }
