@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class ProfSleep extends StandardFunc {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final long ms = toLong(exprs[0], qc);
+    final long ms = toLong(arg(0), qc);
 
     // allow interruption of long sleeps; abort loop if maximum sleep time has been reached
     final Performance perf = new Performance();
