@@ -13,7 +13,7 @@ import org.basex.util.list.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Dirk Kirsten
  */
 public final class RandomGaussian extends StandardFunc {
@@ -22,9 +22,9 @@ public final class RandomGaussian extends StandardFunc {
 
   @Override
   public Iter iter(final QueryContext qc) throws QueryException {
-    final long num = toLong(exprs[0], qc);
+    final long count = toLong(arg(0), qc);
     return new Iter() {
-      long c = num;
+      long c = count;
 
       @Override
       public Item next() {
@@ -35,9 +35,9 @@ public final class RandomGaussian extends StandardFunc {
 
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    final long num = toLong(exprs[0], qc);
-    final DoubleList values = new DoubleList(Seq.initialCapacity(num));
-    for(long n = 0; n < num; n++) values.add(RND.nextGaussian());
+    final long count = toLong(arg(0), qc);
+    final DoubleList values = new DoubleList(Seq.initialCapacity(count));
+    for(long c = 0; c < count; c++) values.add(RND.nextGaussian());
     return DblSeq.get(values.finish());
   }
 }
