@@ -12,7 +12,7 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Dirk Kirsten
  */
 public final class RandomInteger extends StandardFunc {
@@ -21,9 +21,14 @@ public final class RandomInteger extends StandardFunc {
 
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    if(exprs.length == 0) return Int.get(RND.nextInt());
-    final long max = toLong(exprs[0], qc);
-    if(max > 0 && max <= Integer.MAX_VALUE) return Int.get(RND.nextInt((int) max));
-    throw RANDOM_BOUNDS_X.get(info, max);
+    final long next;
+    if(defined(0)) {
+      final long max = toLong(arg(0), qc);
+      if(max <= 0 || max > Integer.MAX_VALUE) throw RANDOM_BOUNDS_X.get(info, max);
+      next = RND.nextInt((int) max);
+    } else {
+      next = RND.nextInt();
+    }
+    return Int.get(next);
   }
 }
