@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class RepoDelete extends RepoFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    new RepoManager(qc.context, info).delete(toString(exprs[0], qc));
+    new RepoManager(qc.context, info).delete(toString(arg(0), qc));
     return Empty.VALUE;
   }
 }
