@@ -7,12 +7,12 @@ import org.basex.query.util.*;
 /**
  * Functions on EXPath packages.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 abstract class RepoFn extends StandardFunc {
   @Override
   public final boolean accept(final ASTVisitor visitor) {
-    return visitor.lock(Locking.REPO, false) && super.accept(visitor);
+    return visitor.lock(Locking.REPO) && super.accept(visitor);
   }
 }
