@@ -8,13 +8,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class UnitAssert extends UnitFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    if(exprs[0].ebv(qc, info).bool(info)) return Empty.VALUE;
-    throw error(exprs.length > 1 ? toNodeOrAtomItem(1, qc) : null);
+    if(arg(0).ebv(qc, info).bool(info)) return Empty.VALUE;
+    throw error(defined(1) ? toNodeOrAtomItem(arg(1), qc) : null);
   }
 }
