@@ -3,8 +3,8 @@ package org.basex.query.func.unit;
 import static org.basex.query.QueryError.*;
 
 import org.basex.query.*;
-import org.basex.query.func.fn.*;
 import org.basex.query.iter.*;
+import org.basex.query.util.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.seq.*;
 import org.basex.util.*;
@@ -12,14 +12,14 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class UnitAssertEquals extends UnitFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final Iter iter1 = exprs[0].iter(qc), iter2 = exprs[1].iter(qc);
-    final DeepEqual comp = new DeepEqual(info);
+    final Iter iter1 = arg(0).iter(qc), iter2 = arg(1).iter(qc);
+    final DeepEqual deep = new DeepEqual(info, qc, null, null);
     Item item1, item2;
     int c = 1;
     while(true) {
@@ -27,10 +27,10 @@ public final class UnitAssertEquals extends UnitFn {
       item2 = iter2.next();
       final boolean empty1 = item1 == null, empty2 = item2 == null;
       if(empty1 && empty2) return Empty.VALUE;
-      if(empty1 || empty2 || !comp.equal(item1.iter(), item2.iter())) break;
+      if(empty1 || empty2 || !deep.equal(item1, item2)) break;
       c++;
     }
-    final Item item = exprs.length > 2 ? toNodeOrAtomItem(2, qc) : null;
+    final Item item = defined(2) ? toNodeOrAtomItem(arg(2), qc) : null;
     throw new UnitException(info, UNIT_FAIL_X_X_X, item1, item2, c).value(item);
   }
 }
