@@ -7,12 +7,12 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class UserExists extends UserFn {
   @Override
   public Item item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    return Bln.get(qc.context.users.get(toName(0, qc)) != null);
+    return Bln.get(qc.context.users.get(toName(arg(0), qc)) != null);
   }
 }
