@@ -9,13 +9,13 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class UserInfo extends UserFn {
   @Override
   public ANode item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final ANode node = exprs.length > 0 ? toUser(0, qc).info() : qc.context.users.info();
+    final ANode node = defined(0) ? toUser(arg(0), qc).info() : qc.context.users.info();
     return node == null ? new FElem(INFO) : node;
   }
 }
