@@ -8,14 +8,14 @@ import org.basex.query.value.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class UserListDetails extends UserList {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
     // return information on single user
-    if(exprs.length > 0) return toUser(0, qc).toXML(qc, info);
+    if(defined(0)) return toUser(arg(0), qc).toXML(qc, info);
 
     // return information for all users
     final Context ctx = qc.context;
