@@ -3,8 +3,8 @@ package org.basex.query.func.web;
 import static org.basex.query.QueryError.*;
 import static org.basex.util.Token.*;
 
-import java.io.*;
 import java.net.*;
+import java.nio.charset.StandardCharsets;
 
 import org.basex.query.*;
 import org.basex.query.value.item.*;
@@ -13,20 +13,17 @@ import org.basex.util.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class WebDecodeUrl extends WebFn {
   @Override
   public Str item(final QueryContext qc, final InputInfo ii) throws QueryException {
-    final byte[] uri = toToken(exprs[0], qc);
+    final String value = toString(arg(0), qc);
 
     final byte[] decoded;
     try {
-      decoded = token(URLDecoder.decode(string(uri), Strings.UTF8));
-    } catch(final UnsupportedEncodingException ex) {
-      // UTF8 is always supported
-      throw Util.notExpected(ex);
+      decoded = token(URLDecoder.decode(value, StandardCharsets.UTF_8));
     } catch(final IllegalArgumentException ex) {
       Util.debug(ex);
       throw WEB_INVALID2_X.get(info, ex.getLocalizedMessage());
