@@ -6,12 +6,12 @@ import org.basex.query.value.*;
 /**
  * Function implementation.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class XQueryEvalUpdate extends XQueryEval {
   @Override
   public Value value(final QueryContext qc) throws QueryException {
-    return eval(toContent(0, qc), true, qc);
+    return eval(toContent(arg(0), qc), true, qc);
   }
 }
