@@ -1,5 +1,7 @@
 package org.basex.query.scope;
 
+import java.util.*;
+
 import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.query.var.*;
@@ -8,14 +10,14 @@ import org.basex.util.hash.*;
 /**
  * An XQuery module.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public abstract class AModule extends StaticScope {
   /** User-defined functions. */
-  public TokenObjMap<StaticFunc> funcs;
+  public ArrayList<StaticFunc> funcs;
   /** Static variables. */
-  public TokenObjMap<StaticVar> vars;
+  public ArrayList<StaticVar> vars;
   /** URIs of modules. */
   public TokenSet modules;
   /** Namespaces. */
@@ -31,18 +33,18 @@ public abstract class AModule extends StaticScope {
 
   /**
    * Assigns module properties.
-   * @param f user-defined functions
-   * @param v static variables
-   * @param m URIs of modules
-   * @param n namespaces
+   * @param fn user-defined functions
+   * @param vr static variables
+   * @param md URIs of modules
+   * @param ns namespaces
    * @param d documentation string
    */
-  public void set(final TokenObjMap<StaticFunc> f, final TokenObjMap<StaticVar> v,
-      final TokenSet m, final TokenMap n, final String d) {
-    funcs = f;
-    vars = v;
-    modules = m;
-    namespaces = n;
+  public void set(final ArrayList<StaticFunc> fn, final ArrayList<StaticVar> vr, final TokenSet md,
+      final TokenMap ns, final String d) {
+    funcs = fn;
+    vars = vr;
+    modules = md;
+    namespaces = ns;
     doc(d);
   }
 }
