@@ -1,12 +1,13 @@
 package org.basex.query.scope;
 
 import org.basex.query.*;
+import org.basex.query.expr.*;
 import org.basex.query.util.*;
 
 /**
  * An XQuery library module.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class LibraryModule extends AModule {
@@ -24,7 +25,8 @@ public final class LibraryModule extends AModule {
   }
 
   @Override
-  public void comp(final CompileContext cc) {
+  public Expr compile(final CompileContext cc) {
+    return null;
   }
 
   @Override
