@@ -13,24 +13,24 @@ import org.basex.util.*;
 /**
  * Update primitive for the {@link Function#_DB_ALTER_BACKUP} function.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class BackupAlter extends NameUpdate {
   /** Name of the new backup. */
-  private final String newName;
+  private final String newname;
 
   /**
    * Constructor.
    * @param name backup to be renamed
-   * @param newName name of new backup
+   * @param newname name of new backup
    * @param qc query context
    * @param info input info
    */
-  public BackupAlter(final String name, final String newName, final QueryContext qc,
+  public BackupAlter(final String name, final String newname, final QueryContext qc,
       final InputInfo info) {
     super(UpdateType.BACKUPALTER, name, qc, info);
-    this.newName = newName;
+    this.newname = newname;
   }
 
   @Override
@@ -40,7 +40,7 @@ public final class BackupAlter extends NameUpdate {
   @Override
   public void apply() throws QueryException {
     try {
-      AlterBackup.alter(name, newName, qc.context.soptions);
+      AlterBackup.alter(name, newname, qc.context.soptions);
     } catch(final IOException ex) {
       Util.debug(ex);
       throw UPDROPBACK_X_X.get(info, name, operation());
