@@ -13,18 +13,18 @@ import org.basex.util.*;
 /**
  * Update primitive for the {@link Function#_DB_CREATE_BACKUP} function.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Lukas Kircher
  */
 public final class BackupCreate extends NameUpdate {
   /** Comment string. */
-  final String comment;
+  private final String comment;
   /** Compress flag. */
-  final boolean compress;
+  private final boolean compress;
 
   /**
    * Constructor.
-   * @param name name of database to be backed up
+   * @param name name of database (empty string for general data)
    * @param comment comment
    * @param compress compress data
    * @param qc query context
@@ -50,8 +50,13 @@ public final class BackupCreate extends NameUpdate {
     }
   }
 
+  @Override
+  public void merge(final Update update) throws QueryException {
+    throw DB_CONFLICT2_X_X.get(info, name, operation());
+  }
+
   @Override
   public String operation() {
-    return "backed up";
+    return "created";
   }
 }
