@@ -12,25 +12,25 @@ import org.basex.util.list.*;
 /**
  * Update primitive for the {@link Function#_DB_ALTER} function.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DBAlter extends NameUpdate {
   /** Name of the new database. */
-  private final String newName;
+  private final String newname;
 
   /**
    * Constructor.
    * @param name database to be renamed
-   * @param newName name of new database
+   * @param newname name of new database
    * @param qc query context
    * @param info input info
    */
-  public DBAlter(final String name, final String newName, final QueryContext qc,
+  public DBAlter(final String name, final String newname, final QueryContext qc,
       final InputInfo info) {
 
     super(UpdateType.DBALTER, name, qc, info);
-    this.newName = newName;
+    this.newname = newname;
   }
 
   @Override
@@ -40,8 +40,8 @@ public final class DBAlter extends NameUpdate {
   @Override
   public void apply() throws QueryException {
     close();
-    close(newName, qc, info);
-    if(!AlterDB.alter(name, newName, qc.context.soptions))
+    close(newname, qc, info);
+    if(!AlterDB.alter(name, newname, qc.context.soptions))
       throw UPDBERROR_X_X.get(info, name, operation());
   }
 
@@ -53,6 +53,6 @@ public final class DBAlter extends NameUpdate {
   @Override
   public void databases(final StringList db) {
     super.databases(db);
-    db.add(newName);
+    db.add(newname);
   }
 }
