@@ -4,10 +4,10 @@ import org.basex.query.*;
 import org.basex.util.*;
 
 /**
- * A <i>deep</i> node containing elements in the left and right digit and a sub-tree in
+ * A <i>deep</i> node containing elements in the left and right digit and a subtree in
  * the middle.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  *
  * @param <N> node type
@@ -67,7 +67,7 @@ final class DeepTree<N, E> extends FingerTree<N, E> {
    * @param <N> node type
    * @param <E> element type
    * @param left left digit
-   * @param leftSize size of the left sub-tree
+   * @param leftSize size of the left subtree
    * @param right right digit
    * @param size size of this tree
    * @return the deep node
@@ -96,7 +96,7 @@ final class DeepTree<N, E> extends FingerTree<N, E> {
    * @param <N> node type
    * @param <E> element type
    * @param left left digit
-   * @param middle middle sub-tree
+   * @param middle middle subtree
    * @param right right digit
    * @return the deep node
    */
@@ -812,35 +812,27 @@ final class DeepTree<N, E> extends FingerTree<N, E> {
 
   @Override
   void toString(final StringBuilder sb, final int indent) {
-    for(int i = 0; i < indent; i++) sb.append("  ");
-    sb.append("Deep(").append(size).append(")[\n");
+    sb.append("  ".repeat(indent)).append("Deep(").append(size).append(")[\n");
 
     // left digit
-    for(int i = 0; i < indent + 1; i++) sb.append("  ");
-    sb.append("Left(").append(leftSize).append(")[\n");
+    sb.append("  ".repeat(indent + 1)).append("Left(").append(leftSize).append(")[\n");
     for(final Node<N, E> e : left) {
       toString(e, sb, indent + 2);
       sb.append('\n');
     }
-    for(int i = 0; i < indent + 1; i++) sb.append("  ");
-    sb.append("]\n");
+    sb.append("  ".repeat(indent + 1)).append("]\n");
 
     // middle tree
     middle.toString(sb, indent + 1);
     sb.append('\n');
 
     // right digit
-    for(int i = 0; i < indent + 1; i++) sb.append("  ");
-    sb.append("Right[\n");
+    sb.append("  ".repeat(indent + 1)).append("Right[\n");
     for(final Node<N, E> e : right) {
       toString(e, sb, indent + 2);
       sb.append('\n');
     }
-    for(int i = 0; i < indent + 1; i++) sb.append("  ");
-    sb.append("]\n");
-
-    for(int i = 0; i < indent; i++) sb.append("  ");
-    sb.append(']');
+    sb.append("  ".repeat(indent + 1)).append("]\n").append("  ".repeat(indent)).append(']');
   }
 
   @Override
@@ -881,8 +873,8 @@ final class DeepTree<N, E> extends FingerTree<N, E> {
    * @param <N> node type
    * @param <E> element type
    * @param arr input array
-   * @param from first index, inclusive (may be negative)
-   * @param to last index, exclusive (may be greater than {@code arr.length})
+   * @param from first index, inclusive (can be negative)
+   * @param to last index, exclusive (can be greater than {@code arr.length})
    * @return resulting array
    */
   static <N, E> Node<N, E>[] slice(final NodeLike<N, E>[] arr, final int from, final int to) {
