@@ -16,7 +16,7 @@ import org.basex.util.list.*;
 /**
  * Formatter for decimal numbers.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DecFormatter extends FormatUtil {
@@ -29,9 +29,9 @@ public final class DecFormatter extends FormatUtil {
   public final int zero;
 
   /** Infinity. */
-  public byte[] inf = token("Infinity");
+  public byte[] inf = Token.INFINITY;
   /** NaN. */
-  public byte[] nan = token("NaN");
+  public byte[] nan = Token.NAN;
   /** Pattern-separator character. */
   public int pattern = ';';
 
@@ -381,7 +381,7 @@ public final class DecFormatter extends FormatUtil {
     final double d = item.dbl(ii);
     if(Double.isNaN(d)) return nan;
 
-    // Rule 2: check if value if negative (smaller than zero or -0)
+    // Rule 2: check if value is negative (smaller than zero or -0)
     final boolean neg = d < 0 || d == 0 && Double.doubleToLongBits(d) == Long.MIN_VALUE;
     final Picture pic = pics[neg && pics.length == 2 ? 1 : 0];
     final IntList res = new IntList(), intgr = new IntList(), fract = new IntList();
