@@ -9,7 +9,7 @@ import org.basex.util.*;
 /**
  * Cache for checking QNames after their construction.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 final class QNmCheck {
@@ -44,7 +44,7 @@ final class QNmCheck {
 
     if(name.hasPrefix()) {
       name.uri(parser.sc.ns.uri(name.prefix()));
-      if(check && !name.hasURI()) throw parser.error(NOURI_X, info, name.string());
+      if(check && !name.hasURI()) throw parser.error(NOURI_X, info, name.prefix());
     } else if(nsElem) {
       name.uri(parser.sc.elemNS);
     }
