@@ -5,7 +5,7 @@ import java.util.*;
 /**
  * Escape sequence.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class Escape extends RegExp {
@@ -127,7 +127,7 @@ public final class Escape extends RegExp {
       s += Character.charCount(rng[1] = string.codePointAt(s));
       ranges.add(rng);
     }
-    return ranges.toArray(new int[0][]);
+    return ranges.toArray(int[][]::new);
   }
 
   /**
@@ -148,7 +148,7 @@ public final class Escape extends RegExp {
         ranges.remove(i + 1);
       }
     }
-    return ranges.toArray(new int[0][]);
+    return ranges.toArray(int[][]::new);
   }
 
   /**
@@ -168,7 +168,7 @@ public final class Escape extends RegExp {
     if(start <= Character.MAX_CODE_POINT)
       ranges.add(new int[] { start, Character.MAX_CODE_POINT });
 
-    return ranges.toArray(new int[0][]);
+    return ranges.toArray(int[][]::new);
   }
 
   /**
