@@ -11,7 +11,7 @@ import org.basex.util.*;
 /**
  * An array containing more members than fit into a {@link SmallArray}.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 final class BigArray extends XQArray {
@@ -567,7 +567,7 @@ final class BigArray extends XQArray {
       sub = middle.listIterator(m);
     }
 
-    return new ListIterator<Value>() {
+    return new ListIterator<>() {
       int pos = startPos;
 
       @Override
