@@ -9,7 +9,7 @@ import org.basex.util.*;
 /**
  * Time item ({@code xs:time}).
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class Tim extends ADate {
@@ -47,9 +47,9 @@ public final class Tim extends ADate {
   }
 
   @Override
-  public void timeZone(final DTDur zone, final boolean spec, final InputInfo ii)
+  public void timeZone(final DTDur dur, final boolean undefined, final InputInfo ii)
       throws QueryException {
-    tz(zone, spec, ii);
+    super.timeZone(dur, undefined, ii);
     clean();
   }
 
