@@ -6,7 +6,6 @@ import org.basex.query.*;
 import org.basex.query.expr.*;
 import org.basex.query.iter.*;
 import org.basex.query.util.fingertree.*;
-import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.seq.*;
 import org.basex.query.value.type.*;
@@ -15,7 +14,7 @@ import org.basex.util.*;
 /**
  * A sequence containing more items than fit into a {@link SmallSeq}.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 final class BigSeq extends TreeSeq {
@@ -420,7 +419,7 @@ final class BigSeq extends TreeSeq {
       sub = middle.listIterator(m);
     }
 
-    return new ListIterator<Item>() {
+    return new ListIterator<>() {
       int pos = startPos;
 
       @Override
@@ -501,7 +500,7 @@ final class BigSeq extends TreeSeq {
 
   @Override
   public BasicIter<Item> iter() {
-    return new BasicIter<Item>(size) {
+    return new BasicIter<>(size) {
       private Iterator<Item> sub;
 
       @Override
@@ -514,19 +513,16 @@ final class BigSeq extends TreeSeq {
         if(sub == null) sub = middle.iterator();
         return sub.next();
       }
-
-      @Override
-      public Value iterValue() {
-        return BigSeq.this;
-      }
-
       @Override
       public Item get(final long i) {
         return itemAt(i);
       }
-
       @Override
-      public Value value(final QueryContext qc, final Expr expr) {
+      public boolean valueIter() {
+        return true;
+      }
+      @Override
+      public BigSeq value(final QueryContext qc, final Expr expr) {
         return BigSeq.this;
       }
     };
