@@ -23,7 +23,7 @@ import org.basex.util.similarity.*;
 /**
  * XQuery atomic types.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public enum AtomType implements Type {
@@ -873,17 +873,17 @@ public enum AtomType implements Type {
         final InputInfo ii) throws QueryException {
 
       if(!item.type.isStringOrUntyped()) throw typeError(item, this, ii);
-      final Uri u = Uri.uri(item.string(ii));
+      final Uri u = Uri.get(item.string(ii));
       if(!u.isValid()) throw castError(item, ii);
       return u;
     }
     @Override
     public Uri cast(final Object value, final QueryContext qc, final InputInfo ii) {
-      return Uri.uri(token(value));
+      return Uri.get(token(value));
     }
     @Override
     public Uri read(final DataInput in, final QueryContext qc) throws IOException {
-      return Uri.uri(in.readToken());
+      return Uri.get(in.readToken());
     }
   },
 
@@ -896,9 +896,9 @@ public enum AtomType implements Type {
       if(item.type != STRING && !item.type.isUntyped()) throw typeError(item, this, ii);
       final byte[] nm = trim(item.string(ii));
       if(!XMLToken.isQName(nm)) throw castError(item, ii);
-      final QNm qn = new QNm(nm, sc);
-      if(!qn.hasURI() && qn.hasPrefix()) throw NSDECL_X.get(ii, qn.prefix());
-      return qn;
+      final QNm qnm = new QNm(nm, sc);
+      if(!qnm.hasURI() && qnm.hasPrefix()) throw NSDECL_X.get(ii, qnm.prefix());
+      return qnm;
     }
     @Override
     public QNm cast(final Object value, final QueryContext qc, final InputInfo ii) {
@@ -914,7 +914,7 @@ public enum AtomType implements Type {
   NOTATION("NOTATION", ANY_ATOMIC_TYPE, XS_URI, false, false, false, false, Type.ID.NOT);
 
   /** Language pattern. */
-  private static final Pattern LANGPATTERN = Pattern.compile("[A-Za-z]{1,8}(-[A-Za-z0-9]{1,8})*");
+  private static final Pattern LANGPATTERN = Pattern.compile("[A-Za-z]{1,8}(-[A-Za-z\\d]{1,8})*");
 
   /** Cached enums (faster). */
   public static final AtomType[] VALUES = values();
@@ -1017,7 +1017,9 @@ public enum AtomType implements Type {
 
     if(type instanceof AtomType) {
       final List<AtomType> arr = new ArrayList<>();
-      for(AtomType at = (AtomType) type; (at = at.parent) != null;) arr.add(at);
+      for(AtomType at = (AtomType) type; (at = at.parent) != null;) {
+        arr.add(at);
+      }
       for(AtomType p = this; (p = p.parent) != null;)
         if(arr.contains(p)) return p;
     }
