@@ -20,7 +20,7 @@ import org.basex.util.*;
 /**
  * Stores a sequence type definition.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class SeqType {
@@ -55,6 +55,8 @@ public final class SeqType {
   public static final SeqType DOUBLE_ZM = DOUBLE.seqType(ZERO_OR_MORE);
   /** Float number. */
   public static final SeqType FLOAT_O = FLOAT.seqType();
+  /** Decimal number. */
+  public static final SeqType DECIMAL_O = DECIMAL.seqType();
   /** Zero or one decimal number. */
   public static final SeqType DECIMAL_ZO = DECIMAL.seqType(ZERO_OR_ONE);
   /** Single integer. */
@@ -178,6 +180,12 @@ public final class SeqType {
   public static final SeqType FUNCTION_ZO = FUNCTION.seqType(ZERO_OR_ONE);
   /** Zero of more functions. */
   public static final SeqType FUNCTION_ZM = FUNCTION.seqType(ZERO_OR_MORE);
+  /** Predicate function. */
+  public static final SeqType PREDICATE_O = FuncType.get(BOOLEAN_O, ITEM_O).seqType();
+  /** Predicate function. */
+  public static final SeqType PREDICATE_ZM = FuncType.get(BOOLEAN_O, ITEM_ZM).seqType();
+  /** Predicate function. */
+  public static final SeqType BIPREDICATE_O = FuncType.get(BOOLEAN_O, ITEM_O, ITEM_O).seqType();
   /** Single map. */
   public static final SeqType MAP_O = MAP.seqType();
   /** Zero or one map. */
@@ -263,13 +271,19 @@ public final class SeqType {
    * @return result of check
    */
   public boolean instance(final Value value) {
-    // try shortcut (but value type may be too general)
-    if(value.seqType().instanceOf(this)) return true;
-
     // check cardinality
-    if(!occ.check(value.size())) return false;
+    final long size = value.size();
+    if(!occ.check(size)) return false;
 
-    // value type may be too general: check type of each item
+    // single item, empty sequence
+    if(size == 1) return instance((Item) value);
+    if(size == 0) return true;
+
+    // sequence: try shortcut, based on value type
+    final SeqType st = value.seqType();
+    if(st.type.instanceOf(type) && st.kindInstanceOf(this)) return true;
+
+    // if type is too general, check type of each item
     for(final Item item : value) {
       if(!instance(item)) return false;
     }
@@ -333,29 +347,6 @@ public final class SeqType {
     }
   }
 
-  /**
-   * Treats the specified value as this sequence type.
-   * @param value value to check
-   * @param name name of variable (can be {@code null})
-   * @param qc query context
-   * @param ii input info
-   * @throws QueryException query exception
-   */
-  public void treat(final Value value, final QNm name, final QueryContext qc, final InputInfo ii)
-      throws QueryException {
-
-    // try shortcut (but value type may be too general)
-    if(value.seqType().instanceOf(this)) return;
-
-    // check cardinality
-    if(!occ.check(value.size())) throw typeError(value, this, name, ii, false);
-
-    for(final Item item : value) {
-      qc.checkStop();
-      if(!instance(item)) throw typeError(value, this, name, ii, false);
-    }
-  }
-
   /**
    * Promotes the specified value to this sequence type.
    * @param value value to promote
@@ -413,7 +404,9 @@ public final class SeqType {
         } else if(tp == UNTYPED_ATOMIC) {
           if(type.nsSensitive()) throw NSSENS_X_X.get(ii, item.type, type);
           final Iter iter2 = type.cast(item1, qc, sc, ii).iter();
-          for(Item item2; (item2 = qc.next(iter2)) != null;) items.add(item2);
+          for(Item item2; (item2 = qc.next(iter2)) != null;) {
+            items.add(item2);
+          }
         } else if(type == DOUBLE && (tp == FLOAT || tp.instanceOf(DECIMAL))) {
           items.add(Dbl.get(item1.dbl(ii)));
         } else if(type == FLOAT && tp.instanceOf(DECIMAL)) {
@@ -455,6 +448,7 @@ public final class SeqType {
    * @return resulting type
    */
   public SeqType union(final SeqType st) {
+    if(this == st) return this;
     // ignore general type of empty sequence
     final Type tp = st.zero() ? type : zero() ? st.type : type.union(st.type);
     final Occ oc = occ.union(st.occ);
@@ -479,11 +473,12 @@ public final class SeqType {
 
   /**
    * Computes the intersection of two sequence types, i.e. the most general type that is
-   * sub-type of both types. If no such type exists, {@code null} is returned.
+   * subtype of both types. If no such type exists, {@code null} is returned.
    * @param st second type
    * @return resulting type or {@code null}
    */
   public SeqType intersect(final SeqType st) {
+    if(this == st) return this;
     final Type tp = type.intersect(st.type);
     if(tp == null) return null;
     final Occ oc = occ.intersect(st.occ);
@@ -557,9 +552,8 @@ public final class SeqType {
    */
   public boolean instanceOf(final SeqType st) {
     // empty sequence: only check cardinality
-    return zero() ? !st.oneOrMore() :
-      (st.type == ITEM || type.instanceOf(st.type)) &&
-      occ.instanceOf(st.occ) && kindInstanceOf(st);
+    return this == st || (zero() ? !st.oneOrMore() :
+      type.instanceOf(st.type) && occ.instanceOf(st.occ) && kindInstanceOf(st));
   }
 
   /**
