@@ -3,9 +3,10 @@ package org.basex.util;
 import java.util.*;
 
 /**
- * This class is used to iterate through objects of an array.
+ * This class is used to iterate over the elements of an array, or parts of it.
+ * {@code null} references are skipped. An iterator cannot be used twice.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  * @param <E> generic object type
  */
@@ -49,7 +50,7 @@ public final class ArrayIterator<E> implements Iterator<E>, Iterable<E> {
       if(array[start] != null) return true;
       ++start;
     }
-    return start < end;
+    return false;
   }
 
   @Override
