@@ -13,7 +13,7 @@ import org.basex.util.*;
 /**
  * Japanese lexer using igo (http://igo.sourceforge.jp/).
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Toshio HIRAI
  */
 final class JapaneseTokenizer extends Tokenizer {
@@ -326,10 +326,8 @@ final class JapaneseTokenizer extends Tokenizer {
     pos++;
     String n = currToken.getSurface();
     final int hinshi = currToken.getHinshi();
-    if(st &&
-       (hinshi == Morpheme.HINSHI_DOUSHI ||
-        hinshi == Morpheme.HINSHI_KEIYOUSHI)) {
-        n = currToken.getBaseForm();
+    if(st && (hinshi == Morpheme.HINSHI_DOUSHI || hinshi == Morpheme.HINSHI_KEIYOUSHI)) {
+      n = currToken.getBaseForm();
     }
     byte[] t = token(n);
     final boolean a = ascii(t);
@@ -511,7 +509,7 @@ final class JapaneseTokenizer extends Tokenizer {
     }
 
     /**
-     * Returns whether the avoid token.
+     * Checks for a mark.
      * @return result
      */
     public boolean isMark() {
