@@ -28,7 +28,7 @@ import org.basex.util.similarity.*;
  * If an instance of this class contains no pre-defined options, assigned options will
  * be added as free options.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public class Options implements Iterable<Option<?>> {
@@ -199,7 +199,7 @@ public class Options implements Iterable<Option<?>> {
   /**
    * Returns the requested string.
    * @param option option to be found
-   * @return value
+   * @return value or {@code null})
    */
   public final synchronized String get(final StringOption option) {
     return (String) get((Option<?>) option);
@@ -208,7 +208,7 @@ public class Options implements Iterable<Option<?>> {
   /**
    * Returns the requested number.
    * @param option option to be found
-   * @return value
+   * @return value or {@code null})
    */
   public final synchronized Integer get(final NumberOption option) {
     return (Integer) get((Option<?>) option);
@@ -217,7 +217,7 @@ public class Options implements Iterable<Option<?>> {
   /**
    * Returns the requested boolean.
    * @param option option to be found
-   * @return value
+   * @return value or {@code null})
    */
   public final synchronized Boolean get(final BooleanOption option) {
     return (Boolean) get((Option<?>) option);
@@ -226,7 +226,7 @@ public class Options implements Iterable<Option<?>> {
   /**
    * Returns the requested function.
    * @param option option to be found
-   * @return value
+   * @return value or {@code null})
    */
   public final synchronized FuncItem get(final FuncOption option) {
     return (FuncItem) get((Option<?>) option);
@@ -235,7 +235,7 @@ public class Options implements Iterable<Option<?>> {
   /**
    * Returns the requested string array.
    * @param option option to be found
-   * @return value
+   * @return value or {@code null})
    */
   public final synchronized String[] get(final StringsOption option) {
     return (String[]) get((Option<?>) option);
@@ -244,7 +244,7 @@ public class Options implements Iterable<Option<?>> {
   /**
    * Returns the requested integer array.
    * @param option option to be found
-   * @return value
+   * @return value or {@code null})
    */
   public final synchronized int[] get(final NumbersOption option) {
     return (int[]) get((Option<?>) option);
@@ -254,7 +254,7 @@ public class Options implements Iterable<Option<?>> {
    * Returns the requested options.
    * @param option option to be found
    * @param <O> options
-   * @return value
+   * @return value or {@code null})
    */
   @SuppressWarnings({ "unchecked", "cast"})
   public final synchronized <O extends Options> O get(final OptionsOption<O> option) {
@@ -265,7 +265,7 @@ public class Options implements Iterable<Option<?>> {
    * Returns the requested enum value.
    * @param option option to be found
    * @param <E> enumeration value
-   * @return value
+   * @return value or {@code null})
    */
   @SuppressWarnings({ "unchecked", "cast"})
   public final synchronized <E extends Enum<E>> E get(final EnumOption<E> option) {
@@ -370,7 +370,7 @@ public class Options implements Iterable<Option<?>> {
    * it will be added as free option.
    * @param name name of option
    * @param value value to be assigned
-   * @param error error
+   * @param error raise error if a supplied option is unknown
    * @param ii input info
    * @throws BaseXException database exception
    * @throws QueryException query exception
@@ -427,10 +427,10 @@ public class Options implements Iterable<Option<?>> {
       for(final Item key : map.keys()) {
         if(!tb.isEmpty()) tb.add(',');
         tb.add(key.string(ii)).add('=');
-        final Value vl = map.get(key, ii);
-        if(!vl.isItem()) throw new BaseXException(
-            Text.OPT_EXPECT_X_X_X, AtomType.STRING, vl.seqType(), vl);
-        tb.add(string(((Item) vl).string(ii)).replace(",", ",,"));
+        final Value val = map.get(key, ii);
+        if(!val.isItem()) throw new BaseXException(
+            Text.OPT_EXPECT_X_X_X, AtomType.STRING, val.seqType(), val);
+        tb.add(string(((Item) val).string(ii)).replace(",", ",,"));
       }
     } else if(item instanceof QNm) {
       tb.add(((QNm) item).id());
@@ -502,7 +502,7 @@ public class Options implements Iterable<Option<?>> {
    */
   public final synchronized String error(final String name) {
     final Object similar = Levenshtein.similar(token(name),
-        options.keySet().toArray(new String[0]));
+        options.keySet().toArray(String[]::new));
     return similar != null ? Util.info(Text.UNKNOWN_OPT_SIMILAR_X_X, name, similar) :
       Util.info(Text.UNKNOWN_OPTION_X, name);
   }
@@ -568,7 +568,7 @@ public class Options implements Iterable<Option<?>> {
   /**
    * Parses and assigns options from the specified map.
    * @param map map
-   * @param error raise error if option is unknown
+   * @param error raise error if a supplied option is unknown
    * @param ii input info
    * @throws BaseXException database exception
    * @throws QueryException query exception
@@ -658,7 +658,7 @@ public class Options implements Iterable<Option<?>> {
       final Object obj = f.get(null);
       if(obj instanceof Option) opts.add((Option<?>) obj);
     }
-    return opts.toArray(new Option[0]);
+    return opts.toArray(Option[]::new);
   }
 
   /**
