@@ -13,7 +13,7 @@ import org.junit.jupiter.api.Test;
 /**
  * Local concurrency tests.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class LocalConcurrencyTest extends SandboxTest {
@@ -42,7 +42,7 @@ public final class LocalConcurrencyTest extends SandboxTest {
     } finally {
       while(counter.get() < runs) Performance.sleep(1);
       if(error[0] != null) {
-        error[0].printStackTrace();
+        Util.stack(error[0]);
         fail(error[0].toString());
       }
       execute(new DropDB("store"));
