@@ -24,10 +24,12 @@ import org.junit.jupiter.api.Test;
 /**
  * This class tests the functions of the Database Module.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class DbModuleTest extends QueryPlanTest {
+  /** Invalid characters for database names. */
+  private static final char[] INVALID = ",*?;\\/:\"<>|".toCharArray();
   /** Test file. */
   private static final String XML = "src/test/resources/input.xml";
   /** Test file. */
@@ -93,31 +95,31 @@ public final class DbModuleTest extends QueryPlanTest {
         COLLECTION.args(" '" + NAME + "/doc' || $i") + ")", 3);
 
     // specify parsing options
-    query(func.args(NAME, " '<a> </a>'", "chop.xml",
-        " map { '" + lc(MainOptions.CHOP) + "': true() }"));
-    query(_DB_OPEN.args(NAME, "chop.xml"), "<a/>");
-    query(func.args(NAME, " '<a> </a>'", "nochop.xml",
-        " map { '" + lc(MainOptions.CHOP) + "': false() }"));
-    query(_DB_OPEN.args(NAME, "nochop.xml"), "<a> </a>");
+    query(func.args(NAME, " '<a> </a>'", "strip.xml",
+        " map { '" + lc(MainOptions.STRIPWS) + "': true() }"));
+    query(_DB_GET.args(NAME, "strip.xml"), "<a/>");
+    query(func.args(NAME, " '<a> </a>'", "nostrip.xml",
+        " map { '" + lc(MainOptions.STRIPWS) + "': false() }"));
+    query(_DB_GET.args(NAME, "nostrip.xml"), "<a> </a>");
 
     // specify parsing options
     query(func.args(NAME, CSV, "csv.xml",
         " map { 'parser': 'csv', 'csvparser': 'header=true' }"));
-    query("exists(" + _DB_OPEN.args(NAME, "csv.xml") + "//City)", true);
+    query("exists(" + _DB_GET.args(NAME, "csv.xml") + "//City)", true);
     query(func.args(NAME, CSV, "csv.xml",
         " map { 'parser': 'csv', 'csvparser': map { 'header': 'true' } }"));
-    query("exists(" + _DB_OPEN.args(NAME, "csv.xml") + "//City)", true);
+    query("exists(" + _DB_GET.args(NAME, "csv.xml") + "//City)", true);
     query(func.args(NAME, CSV, "csv.xml",
         " map { 'parser': 'csv', 'csvparser': map { 'header': true() } }"));
-    query("exists(" + _DB_OPEN.args(NAME, "csv.xml") + "//City)", true);
+    query("exists(" + _DB_GET.args(NAME, "csv.xml") + "//City)", true);
 
     final String addcache = " map { 'addcache': true() }";
     query(func.args(NAME, " <cache/>", "C1.xml", addcache));
-    query("exists(" + _DB_OPEN.args(NAME, "C1.xml") + ")", true);
+    query("exists(" + _DB_GET.args(NAME, "C1.xml") + ")", true);
     query(func.args(NAME, " <cache/>", "C2.xml", addcache));
-    query("exists(" + _DB_OPEN.args(NAME, "C2.xml") + ")", true);
+    query("exists(" + _DB_GET.args(NAME, "C2.xml") + ")", true);
     query(func.args(NAME, XML, "C3.xml", addcache));
-    query("exists(" + _DB_OPEN.args(NAME, "C3.xml") + ")", true);
+    query("exists(" + _DB_GET.args(NAME, "C3.xml") + ")", true);
 
     error(func.args(NAME, CSV, "csv.xml",
         " map { 'parser': ('csv', 'html') }"), BASEX_OPTIONS_X_X);
@@ -149,8 +151,8 @@ public final class DbModuleTest extends QueryPlanTest {
     query(func.args(NAME + 'a', NAME));
 
     // invalid names
-    error(func.args("x", " ''"), DB_NAME_X);
-    error(func.args(" ''", "x"), DB_NAME_X);
+    for(final char ch : INVALID) error(func.args("x", ch), DB_NAME_X);
+    for(final char ch : INVALID) error(func.args(ch, "x"), DB_NAME_X);
 
     // same name is disallowed
     error(func.args(NAME, NAME), DB_CONFLICT4_X);
@@ -171,8 +173,8 @@ public final class DbModuleTest extends QueryPlanTest {
     query(func.args(NAME + 'a', NAME));
 
     // invalid names
-    error(func.args("x", " ''"), DB_NAME_X);
-    error(func.args(" ''", "x"), DB_NAME_X);
+    for(final char ch : INVALID) error(func.args("x", ch), DB_NAME_X);
+    for(final char ch : INVALID) error(func.args(ch, "x"), DB_NAME_X);
 
     // same name is disallowed
     error(func.args(NAME, NAME), DB_CONFLICT4_X);
@@ -230,7 +232,7 @@ public final class DbModuleTest extends QueryPlanTest {
   @Test public void contentType() {
     final Function func = _DB_CONTENT_TYPE;
     query(_DB_ADD.args(NAME, " <a/>", "xml"));
-    query(_DB_STORE.args(NAME, "binary", "bla"));
+    query(_DB_PUT_BINARY.args(NAME, "bla", "binary"));
     query(func.args(NAME, "xml"), MediaType.APPLICATION_XML.toString());
     query(func.args(NAME, "binary"), MediaType.APPLICATION_OCTET_STREAM.toString());
     error(func.args(NAME, "test"), WHICHRES_X);
@@ -251,8 +253,8 @@ public final class DbModuleTest extends QueryPlanTest {
     }
 
     // invalid names
-    error(func.args("x", " ''"), DB_NAME_X);
-    error(func.args(" ''", "x"), DB_NAME_X);
+    for(final char ch : INVALID) error(func.args("x", ch), DB_NAME_X);
+    for(final char ch : INVALID) error(func.args(ch, "x"), DB_NAME_X);
 
     // same name is disallowed
     error(func.args(NAME, NAME), DB_CONFLICT4_X);
@@ -271,20 +273,20 @@ public final class DbModuleTest extends QueryPlanTest {
 
     // create DB w/ initial content
     query(func.args(NAME, " <dummy/>", "t1.xml"));
-    query(_DB_OPEN.args(NAME) + "/root()", "<dummy/>");
+    query(_DB_GET.args(NAME) + "/root()", "<dummy/>");
 
     // create DB w/ initial content via document constructor
     query(func.args(NAME, " document { <dummy/> }", "t2.xml"));
-    query(_DB_OPEN.args(NAME) + "/root()", "<dummy/>");
+    query(_DB_GET.args(NAME) + "/root()", "<dummy/>");
 
     // create DB w/ initial content given as string
     query(func.args(NAME, " <dummy/>", "t1.xml"));
-    query(_DB_OPEN.args(NAME) + "/root()", "<dummy/>");
+    query(_DB_GET.args(NAME) + "/root()", "<dummy/>");
 
     // create DB w/ initial content multiple times
     query(func.args(NAME, " <dummy/>", "t1.xml"));
     query(func.args(NAME, " <dummy/>", "t1.xml"));
-    query(_DB_OPEN.args(NAME) + "/root()", "<dummy/>");
+    query(_DB_GET.args(NAME) + "/root()", "<dummy/>");
 
     // try to create DB twice during same query
     error(func.args(NAME) + ',' + func.args(NAME), DB_CONFLICT1_X_X);
@@ -317,11 +319,11 @@ public final class DbModuleTest extends QueryPlanTest {
 
     // run update on existing DB then drop it and create a new one
     query(func.args(NAME, " <a/>", "a.xml"));
-    query("insert node <dummy/> into " + _DB_OPEN.args(NAME));
+    query("insert node <dummy/> into " + _DB_GET.args(NAME));
     query(func.args(NAME, " <dummy/>", "t1.xml") +
-        ", insert node <dummy/> into " + _DB_OPEN.args(NAME) + ',' +
+        ", insert node <dummy/> into " + _DB_GET.args(NAME) + ',' +
         _DB_DROP.args(NAME));
-    query(_DB_OPEN.args(NAME) + "/root()", "<dummy/>");
+    query(_DB_GET.args(NAME) + "/root()", "<dummy/>");
 
     // eventually drop database
     query(_DB_DROP.args(NAME));
@@ -355,18 +357,18 @@ public final class DbModuleTest extends QueryPlanTest {
 
     // specify parsing options
     query(func.args(NAME, " '<a> </a>'", "a.xml",
-        " map { '" + lc(MainOptions.CHOP) + "': true() }"));
-    query(_DB_OPEN.args(NAME), "<a/>");
+        " map { '" + lc(MainOptions.STRIPWS) + "': true() }"));
+    query(_DB_GET.args(NAME), "<a/>");
     query(func.args(NAME, " '<a> </a>'", "a.xml",
-        " map { '" + lc(MainOptions.CHOP) + "': false() }"));
-    query(_DB_OPEN.args(NAME), "<a> </a>");
+        " map { '" + lc(MainOptions.STRIPWS) + "': false() }"));
+    query(_DB_GET.args(NAME), "<a> </a>");
 
-    query("(# db:chop false #) { " + func.args(NAME, " '<a> </a>'", "a.xml") + " }");
-    query(_DB_OPEN.args(NAME), "<a> </a>");
+    query("(# db:stripws true #) { " + func.args(NAME, " '<a> </a>'", "a.xml") + " }");
+    query(_DB_GET.args(NAME), "<a/>");
 
     final String path = "src/test/resources/example.json";
     query("(# db:parser json #) { " + func.args(NAME, path, "a.json") + " }");
-    query(_DB_OPEN.args(NAME) + "/* ! name()", "json");
+    query(_DB_GET.args(NAME) + "/* ! name()", "json");
 
     // specify unknown or invalid options
     error(func.args(NAME, " ()", " ()", " map { 'xyz': 'abc' }"),
@@ -377,6 +379,9 @@ public final class DbModuleTest extends QueryPlanTest {
         BASEX_OPTIONS_X_X);
     error(func.args(NAME, " ()", " ()", " map { '" + lc(MainOptions.TEXTINDEX) + "': 'nope' }"),
         BASEX_OPTIONS_X_X);
+
+    // invalid names
+    for(final char ch : INVALID) error(func.args(ch), DB_NAME_X);
   }
 
   /** Test method. */
@@ -401,6 +406,11 @@ public final class DbModuleTest extends QueryPlanTest {
     query(func.args(NAME));
     query("count(" + _DB_BACKUPS.args(NAME) + ")", 1);
 
+    // create and drop backup of general data
+    query(func.args(""));
+    query("count(" + _DB_BACKUPS.args("") + ")", 1);
+    query("count(" + _DB_BACKUPS.args() + ")", 2);
+
     final int size1 = Integer.parseInt(query(_DB_BACKUPS.args(NAME) + "/@size ! data()"));
     query(func.args(NAME, " map { 'compress': false() }"));
     final int size2 = Integer.parseInt(query(_DB_BACKUPS.args(NAME) + "/@size ! data()"));
@@ -409,9 +419,9 @@ public final class DbModuleTest extends QueryPlanTest {
     query(func.args(NAME, " map { 'comment': 'BLA' }"));
     query(_DB_BACKUPS.args(NAME) + "/@comment ! data()", "BLA");
 
-    // invalid name
-    error(func.args(""), DB_NAME_X);
-    // try to backup non-existing database
+    // invalid names
+    for(final char ch : INVALID) error(func.args(ch), DB_NAME_X);
+    // try to back up non-existing database
     error(func.args(NAME + "backup"), DB_OPEN1_X);
   }
 
@@ -427,22 +437,30 @@ public final class DbModuleTest extends QueryPlanTest {
   @Test public void dir() {
     final Function func = _DB_DIR;
     query(_DB_ADD.args(NAME, " <a/>", "xml/doc.xml"));
-    query(_DB_STORE.args(NAME, "binary/binary.data", "bla"));
+    query(_DB_PUT_BINARY.args(NAME, "bla", "binary/binary.data"));
+    query(_DB_PUT_VALUE.args(NAME, " 1 to 5", "value/value.data"));
 
     String call = func.args(NAME, "xml");
-    query(call + "/@raw/data()", false);
+    query(call + "/@type/data()", "xml");
     query(call + "/@content-type/data()", MediaType.APPLICATION_XML.toString());
     query(call + "/@modified-date/xs:dateTime(.)");
-    query(call + "/@size/data()", "");
+    query(call + "/@size/data()", 2);
     query(call + "/text()", "doc.xml");
 
     call = func.args(NAME, "binary/");
-    query(call + "/@raw/data()", true);
+    query(call + "/@type/data()", "binary");
     query(call + "/@content-type/data()", MediaType.APPLICATION_OCTET_STREAM.toString());
     query(call + "/@modified-date/xs:dateTime(.) > xs:dateTime('1971-01-01T00:00:01')", true);
     query(call + "/@size/data()", 3);
     query(call + "/text()", "binary.data");
 
+    call = func.args(NAME, "value/");
+    query(call + "/@type/data()", "value");
+    query(call + "/@content-type/data()", MediaType.APPLICATION_OCTET_STREAM.toString());
+    query(call + "/@modified-date/xs:dateTime(.) > xs:dateTime('1971-01-01T00:00:01')", true);
+    query(call + "/@size/data()", 6);
+    query(call + "/text()", "value.data");
+
     query(func.args(NAME, "test"), "");
     error(func.args("notAvailable", ""), DB_OPEN2_X);
   }
@@ -457,8 +475,8 @@ public final class DbModuleTest extends QueryPlanTest {
     query(func.args(dbName));
     query(_DB_EXISTS.args(dbName), false);
 
-    // invalid name
-    error(func.args(" ''"), DB_NAME_X);
+    // invalid names
+    for(final char ch : INVALID) error(func.args(ch), DB_NAME_X);
     // try to drop non-existing DB
     error(func.args(dbName), DB_OPEN1_X);
   }
@@ -475,10 +493,15 @@ public final class DbModuleTest extends QueryPlanTest {
     query(_DB_CREATE_BACKUP.args(NAME));
     query(func.args(' ' + query(_DB_BACKUPS.args(NAME))));
 
+    // create and drop backup of general data
+    query(_DB_CREATE_BACKUP.args(""));
+    query(func.args(' ' + query(_DB_BACKUPS.args(""))));
+
     // invalid name
-    error(func.args(""), DB_NAME_X);
+    for(final char ch : INVALID) error(func.args(String.valueOf(ch)), DB_NAME_X);
     // backup file does not exist
     error(func.args(NAME), DB_NOBACKUP_X);
+    error(func.args(""), DB_NOBACKUP_X);
     // check if drop is called before create
     error(_DB_CREATE_BACKUP.args(NAME) + ',' + func.args(NAME), DB_NOBACKUP_X);
   }
@@ -487,7 +510,7 @@ public final class DbModuleTest extends QueryPlanTest {
   @Test public void exists() {
     final Function func = _DB_EXISTS;
     query(_DB_ADD.args(NAME, " <a/>", "x/xml"));
-    query(_DB_STORE.args(NAME, "x/binary", "bla"));
+    query(_DB_PUT_BINARY.args(NAME, "bla", "x/binary"));
     // checks if the specified resources exist (false expected for directories)
     query(func.args(NAME), true);
     query(func.args(NAME, "x/xml"), true);
@@ -523,103 +546,8 @@ public final class DbModuleTest extends QueryPlanTest {
   }
 
   /** Test method. */
-  @Test public void info() {
-    final Function func = _DB_INFO;
-    query("count(" + func.args(NAME) + "//" +
-        SIZE.replaceAll("[- ]", "").toLowerCase(Locale.ENGLISH) + ')', 1);
-  }
-
-  /** Test method. */
-  @Test public void isRaw() {
-    final Function func = _DB_IS_RAW;
-    query(_DB_ADD.args(NAME, " <a/>", "xml"));
-    query(_DB_STORE.args(NAME, "binary", "bla"));
-    query(func.args(NAME, "xml"), false);
-    query(func.args(NAME, "binary"), true);
-    query(func.args(NAME, "xxx"), false);
-  }
-
-  /** Test method. */
-  @Test public void isXML() {
-    final Function func = _DB_IS_XML;
-    query(_DB_ADD.args(NAME, " <a/>", "xml"));
-    query(_DB_STORE.args(NAME, "binary", "bla"));
-    query(func.args(NAME, "xml"), true);
-    query(func.args(NAME, "binary"), false);
-    query(func.args(NAME, "xxx"), false);
-  }
-
-  /** Test method. */
-  @Test public void list() {
-    // add documents
-    final Function func = _DB_LIST;
-    execute(new Add("test/docs", FLDR));
-    contains(func.args(NAME), "test/docs");
-    contains(func.args(NAME, "test/"), "test/docs");
-    contains(func.args(NAME, "test/docs/input.xml"), "input.xml");
-
-    query(_DB_STORE.args(NAME, "bin/b", "b"));
-    query(func.args(NAME, "bin/"), "bin/b");
-    query(func.args(NAME, "bin/b"), "bin/b");
-
-    // create two other database and compare substring
-    execute(new CreateDB(NAME + 1));
-    execute(new CreateDB(NAME + 2));
-    contains(func.args(), NAME + 1 + '\n' + NAME + 2);
-    execute(new DropDB(NAME + 1));
-    execute(new DropDB(NAME + 2));
-  }
-
-  /** Test method. */
-  @Test public void listDetails() {
-    final Function func = _DB_LIST_DETAILS;
-    query(func.args() + "/@resources/string()", 1);
-
-    query(_DB_ADD.args(NAME, " <a/>", "xml/xml.xml"));
-    query(_DB_STORE.args(NAME, "binary/binary.data", "bla"));
-
-    String call = func.args(NAME, "xml/");
-    query(call + "/@raw/data()", false);
-    query(call + "/@content-type/data()", MediaType.APPLICATION_XML.toString());
-    query(call + "/@modified-date/xs:dateTime(.)");
-    query(call + "/@size/data()", 2);
-    query(call + "/text()", "xml/xml.xml");
-
-    call = func.args(NAME, "binary/");
-    query(call + "/@raw/data()", true);
-    query(call + "/@content-type/data()", MediaType.APPLICATION_OCTET_STREAM.toString());
-    query(call + "/@modified-date/xs:dateTime(.) > xs:dateTime('1971-01-01T00:00:01')", true);
-    query(call + "/@size/data()", 3);
-    query(call + "/text()", "binary/binary.data");
-
-    query(func.args(NAME, "test"), "");
-    error(func.args("notAvailable"), DB_OPEN2_X);
-  }
-
-  /** Test method. */
-  @Test public void name() {
-    final Function func = _DB_NAME;
-    query(func.args(_DB_OPEN.args(NAME)), NAME);
-    query(func.args(_DB_OPEN.args(NAME) + "/*"), NAME);
-  }
-
-  /** Test method. */
-  @Test public void nodeId() {
-    final Function func = _DB_NODE_ID;
-    query(func.args(" /html"), 1);
-    query(func.args(" / | /html"), "0\n1");
-  }
-
-  /** Test method. */
-  @Test public void nodePre() {
-    final Function func = _DB_NODE_PRE;
-    query(func.args(" /html"), 1);
-    query(func.args(" / | /html"), "0\n1");
-  }
-
-  /** Test method. */
-  @Test public void open() {
-    final Function func = _DB_OPEN;
+  @Test public void get() {
+    final Function func = _DB_GET;
     query("count(" + func.args(NAME) + ")", 1);
     query("count(" + func.args(NAME, "") + ")", 1);
     query("count(" + func.args(NAME, "unknown") + ")", 0);
@@ -638,8 +566,25 @@ public final class DbModuleTest extends QueryPlanTest {
   }
 
   /** Test method. */
-  @Test public void openId() {
-    final Function func = _DB_OPEN_ID;
+  @Test public void getBinary() {
+    final Function func = _DB_GET_BINARY, put = _DB_PUT_BINARY;
+    error(func.args(NAME, "unknown"), WHICHRES_X);
+    query(put.args(NAME, " xs:hexBinary('41')", "path"));
+    query("xs:hexBinary(" + func.args(NAME, "path") + ')', "A");
+    query(_DB_DELETE.args(NAME, "path"));
+
+    query("(0 to 5) !" + put.args(NAME, " .", " 'path' || ."), "");
+    query("(0 to 5) !" + func.args(NAME, " 'path' || ."), "0\n1\n2\n3\n4\n5");
+    query(func.args(NAME) + " => map:keys() => count()", 6);
+
+    query(func.args(NAME, "path0"), 0);
+    query("(0 to 5) !" + _DB_DELETE.args(NAME, " 'path' || ."));
+    error(func.args(NAME, "path0"), WHICHRES_X);
+  }
+
+  /** Test method. */
+  @Test public void getId() {
+    final Function func = _DB_GET_ID;
     query(func.args(NAME, " ()"), "");
     query(func.args(NAME, 0) + "//title/text()", "XML");
     query(func.args(NAME, " (0, 1)") + "//title/text()", "XML");
@@ -648,8 +593,8 @@ public final class DbModuleTest extends QueryPlanTest {
   }
 
   /** Test method. */
-  @Test public void openPre() {
-    final Function func = _DB_OPEN_PRE;
+  @Test public void getPre() {
+    final Function func = _DB_GET_PRE;
     query(func.args(NAME, " ()"), "");
     query(func.args(NAME, 0) + "//title/text()", "XML");
     query(func.args(NAME, " (0, 1)") + "//title/text()", "XML");
@@ -657,6 +602,105 @@ public final class DbModuleTest extends QueryPlanTest {
     error(func.args(NAME, Integer.MAX_VALUE), DB_RANGE_X_X);
   }
 
+  /** Test method. */
+  @Test public void getValue() {
+    final Function func = _DB_GET_VALUE, put = _DB_PUT_VALUE;
+    query("(0 to 5) !" + put.args(NAME, " .", " 'path' || ."), "");
+    query("(0 to 5) !" + func.args(NAME, " 'path' || ."), "0\n1\n2\n3\n4\n5");
+    query(func.args(NAME) + " => map:keys() => count()", 6);
+
+    query(func.args(NAME, "path0"), 0);
+    query("(0 to 5) !" + _DB_DELETE.args(NAME, " 'path' || ."));
+    error(func.args(NAME, "path0"), WHICHRES_X);
+  }
+
+  /** Test method. */
+  @Test public void info() {
+    final Function func = _DB_INFO;
+    query("count(" + func.args(NAME) + "//" +
+        SIZE.replaceAll("[- ]", "").toLowerCase(Locale.ENGLISH) + ')', 1);
+  }
+
+  /** Test method. */
+  @Test public void list() {
+    // add documents
+    final Function func = _DB_LIST;
+    execute(new Add("test/docs", FLDR));
+    contains(func.args(NAME), "test/docs");
+    contains(func.args(NAME, "test/"), "test/docs");
+    contains(func.args(NAME, "test/docs/input.xml"), "input.xml");
+
+    query(_DB_PUT_BINARY.args(NAME, "b", "bin/b"));
+    query(func.args(NAME, "bin/"), "bin/b");
+    query(func.args(NAME, "bin/b"), "bin/b");
+
+    query(_DB_PUT_VALUE.args(NAME, " 1 to 5", "value/value.data"));
+    query(func.args(NAME, "value/"), "value/value.data");
+
+    // create two other database and compare substring
+    execute(new CreateDB(NAME + 1));
+    execute(new CreateDB(NAME + 2));
+    contains(func.args(), NAME + 1 + '\n' + NAME + 2);
+    execute(new DropDB(NAME + 1));
+    execute(new DropDB(NAME + 2));
+  }
+
+  /** Test method. */
+  @Test public void listDetails() {
+    final Function func = _DB_LIST_DETAILS;
+    query(func.args() + "/@resources/string()", 1);
+
+    query(_DB_ADD.args(NAME, " <a/>", "xml/xml.xml"));
+    query(_DB_PUT_BINARY.args(NAME, "bla", "binary/binary.data"));
+    query(_DB_PUT_VALUE.args(NAME, " 1 to 5", "value/value.data"));
+
+    String call = func.args(NAME, "xml/");
+    query(call + "/@type/data()", "xml");
+    query(call + "/@content-type/data()", MediaType.APPLICATION_XML.toString());
+    query(call + "/@modified-date/xs:dateTime(.)");
+    query(call + "/@size/data()", 2);
+    query(call + "/text()", "xml/xml.xml");
+
+    call = func.args(NAME, "binary/");
+    query(call + "/@type/data()", "binary");
+    query(call + "/@content-type/data()", MediaType.APPLICATION_OCTET_STREAM.toString());
+    query(call + "/@modified-date/xs:dateTime(.) > xs:dateTime('1971-01-01T00:00:01')", true);
+    query(call + "/@size/data()", 3);
+    query(call + "/text()", "binary/binary.data");
+
+    call = func.args(NAME, "value/");
+    query(call + "/@type/data()", "value");
+    query(call + "/@content-type/data()", MediaType.APPLICATION_OCTET_STREAM.toString());
+    query(call + "/@modified-date/xs:dateTime(.) > xs:dateTime('1971-01-01T00:00:01')", true);
+    query(call + "/@size/data()", 6);
+    query(call + "/text()", "value/value.data");
+
+    query(func.args(NAME, "test"), "");
+    error(func.args("notAvailable"), DB_OPEN2_X);
+  }
+
+  /** Test method. */
+  @Test public void name() {
+    final Function func = _DB_NAME;
+    query(func.args(_DB_GET.args(NAME)), NAME);
+    query(func.args(_DB_GET.args(NAME) + "/*"), NAME);
+    error(func.args(" <x/> update { }"), DB_NODE_X);
+  }
+
+  /** Test method. */
+  @Test public void nodeId() {
+    final Function func = _DB_NODE_ID;
+    query(func.args(" /html"), 1);
+    query(func.args(" / | /html"), "0\n1");
+  }
+
+  /** Test method. */
+  @Test public void nodePre() {
+    final Function func = _DB_NODE_PRE;
+    query(func.args(" /html"), 1);
+    query(func.args(" / | /html"), "0\n1");
+  }
+
   /** Test method. */
   @Test public void optimize() {
     final Function func = _DB_OPTIMIZE;
@@ -749,15 +793,17 @@ public final class DbModuleTest extends QueryPlanTest {
     query(func.args("ADDRAW"), false);
     query(func.args("runs"), 1);
     query(func.args("bindings"), "");
+    query(func.args("serializer") + "?indent", "no");
+
     error(func.args("XYZ"), DB_OPTION_X);
   }
 
   /** Test method. */
   @Test public void path() {
     final Function func = _DB_PATH;
-    query(func.args(_DB_OPEN.args(NAME)), XML.replaceAll(".*/", ""));
-    query(func.args(_DB_OPEN.args(NAME) + "/*"), XML.replaceAll(".*/", ""));
-    query(func.args(" <x/> update { }"), "");
+    query(func.args(_DB_GET.args(NAME)), XML.replaceAll(".*/", ""));
+    query(func.args(_DB_GET.args(NAME) + "/*"), XML.replaceAll(".*/", ""));
+    error(func.args(" <x/> update { }"), DB_NODE_X);
   }
 
   /** Test method. */
@@ -767,6 +813,78 @@ public final class DbModuleTest extends QueryPlanTest {
     error(func.args(NAME, "xyz"), DB_PROPERTY_X);
   }
 
+  /** Test method. */
+  @Test public void put() {
+    final Function func = _DB_PUT;
+
+    execute(new Add("test", XML));
+
+    query(func.args(NAME, " <R1/>", XML));
+    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R1)", 1);
+    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R2)", 0);
+
+    query(func.args(NAME, " document { <R2/> }", XML));
+    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R1)", 0);
+    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R2)", 1);
+
+    query(func.args(NAME, XML, XML));
+    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R1)", 0);
+    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R2)", 0);
+    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/html)", 1);
+
+    final String addcache = " map { 'addcache': true() }";
+    query(func.args(NAME, " <cache/>", "1.xml", addcache));
+    query("exists(" + _DB_GET.args(NAME, "1.xml") + ")", true);
+    query(func.args(NAME, " <cache/>", "2.xml", addcache));
+    query("exists(" + _DB_GET.args(NAME, "2.xml") + ")", true);
+    query(func.args(NAME, XML, "3.xml", addcache));
+    query("exists(" + _DB_GET.args(NAME, "3.xml") + ")", true);
+
+    // GH-1302: replace same target more than once
+    error("(1 to 2) ! " + func.args(NAME, XML, "3.xml"), UPMULTDOC_X_X);
+    error("(1 to 2) ! " + func.args(NAME, XML, "X.xml"), UPMULTDOC_X_X);
+    error(_DB_ADD.args(NAME, XML, "X.xml") + ',' + func.args(NAME, XML, "X.xml"), UPMULTDOC_X_X);
+    error(func.args(NAME, XML, "X.xml") + ',' + _DB_ADD.args(NAME, XML, "X.xml"), UPMULTDOC_X_X);
+
+    // GH-1302: check replacements of existing and new paths
+    query(func.args(NAME, XML, "3.xml") + ',' + func.args(NAME, XML, "4.xml"));
+    query(func.args(NAME, " <a/>", "3.xml") + ',' + func.args(NAME, " <a/>", "5.xml"));
+
+    // GH-1302: check replacements of new paths
+    query(func.args(NAME, XML, "6.xml") + ',' + func.args(NAME, XML, "7.xml"));
+    query(func.args(NAME, " <a/>", "8.xml") + ',' + func.args(NAME, " <a/>", "9.xml"));
+  }
+
+  /** Test method. */
+  @Test public void putBinary() {
+    final Function func = _DB_PUT_BINARY;
+    query(func.args(NAME, "xs:hexBinary('41')", "binary1"));
+    query(func.args(NAME, "b", "binary2"));
+    query(_DB_GET_BINARY.args(NAME, "binary2"), "b");
+    query(func.args(NAME, 123, "binary3"));
+    query(_DB_GET_BINARY.args(NAME, "binary3"), 123);
+
+    error(func.args(NAME, "bin/x", "x") + ", " + func.args(NAME, "bin//x", "x"), DB_CONFLICT5_X);
+  }
+
+  /** Test method. */
+  @Test public void putValue() {
+    final Function func = _DB_PUT_VALUE;
+    query(func.args(NAME, "a", "value1"));
+    query(func.args(NAME, " 1 to 2", "value2"));
+    query(_DB_GET_VALUE.args(NAME, "value1"), "a");
+    query(_DB_GET_VALUE.args(NAME, "value2"), "1\n2");
+    query(func.args(NAME, 1, "value2"));
+    query(_DB_GET_VALUE.args(NAME, "value2"), 1);
+
+    query(func.args(NAME, " string(attribute a { 'x' })", "value3"));
+    query(_DB_GET_VALUE.args(NAME, "value3"), "x");
+
+    error(func.args(NAME, "x", "value/x") + ", " + func.args(NAME, "x", "value//x"),
+        DB_CONFLICT5_X);
+    error(_DB_PUT_VALUE.args(NAME, "VALUE", ".."), RESINV_X);
+  }
+
   /** Test method. */
   @Test public void rename() {
     final Function func = _DB_RENAME;
@@ -789,71 +907,27 @@ public final class DbModuleTest extends QueryPlanTest {
     query("count(" + COLLECTION.args(NAME + "/x/newtest") + ")", XMLFILES);
 
     // rename binary file
-    query(_DB_STORE.args(NAME, "file1", ""));
+    query(_DB_PUT_BINARY.args(NAME, "", "file1"));
     query(func.args(NAME, "file1", "file2"));
-    query(_DB_RETRIEVE.args(NAME, "file2"));
-    error(_DB_RETRIEVE.args(NAME, "file1"), WHICHRES_X);
+    query(_DB_GET_BINARY.args(NAME, "file2"));
+    error(_DB_GET_BINARY.args(NAME, "file1"), WHICHRES_X);
 
     query(func.args(NAME, "file2", "dir1/file3"));
-    query(_DB_RETRIEVE.args(NAME, "dir1/file3"));
+    query(_DB_GET_BINARY.args(NAME, "dir1/file3"));
     query(func.args(NAME, "dir1", "dir2"));
-    query(_DB_RETRIEVE.args(NAME, "dir2/file3"));
-    error(_DB_RETRIEVE.args(NAME, "dir1"), WHICHRES_X);
+    query(_DB_GET_BINARY.args(NAME, "dir2/file3"));
+    error(_DB_GET_BINARY.args(NAME, "dir1"), WHICHRES_X);
 
-    query(_DB_STORE.args(NAME, "file4", ""));
-    query(_DB_STORE.args(NAME, "dir3/file5", ""));
+    query(_DB_PUT_BINARY.args(NAME, "", "file4"));
+    query(_DB_PUT_BINARY.args(NAME, "", "dir3/file5"));
 
     error(func.args(NAME, "dir2", "file4"), DB_PATH_X);
     error(func.args(NAME, "file4", "dir2"), DB_PATH_X);
 
     // move files in directories
     query(func.args(NAME, "dir2", "dir3"));
-    query(_DB_RETRIEVE.args(NAME, "dir3/file3"));
-    query(_DB_RETRIEVE.args(NAME, "dir3/file5"));
-  }
-
-  /** Test method. */
-  @Test public void replace() {
-    final Function func = _DB_REPLACE;
-
-    execute(new Add("test", XML));
-
-    query(func.args(NAME, XML, " <R1/>"));
-    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R1)", 1);
-    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R2)", 0);
-
-    query(func.args(NAME, XML, " document { <R2/> }"));
-    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R1)", 0);
-    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R2)", 1);
-
-    query(func.args(NAME, XML, XML));
-    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R1)", 0);
-    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/R2)", 0);
-    query("count(" + COLLECTION.args(NAME + '/' + XML) + "/html)", 1);
-
-    final String addcache = " map { 'addcache': true() }";
-    query(func.args(NAME, "1.xml", " <cache/>", addcache));
-    query("exists(" + _DB_OPEN.args(NAME, "1.xml") + ")", true);
-    query(func.args(NAME, "2.xml", " <cache/>", addcache));
-    query("exists(" + _DB_OPEN.args(NAME, "2.xml") + ")", true);
-    query(func.args(NAME, "3.xml", XML, addcache));
-    query("exists(" + _DB_OPEN.args(NAME, "3.xml") + ")", true);
-
-    // GH-1302: replace same target more than once
-    error("(1 to 2) ! " + func.args(NAME, "3.xml", XML), UPMULTDOC_X_X);
-    error("(1 to 2) ! " + func.args(NAME, "X.xml", XML), UPMULTDOC_X_X);
-    error(_DB_ADD.args(NAME, XML, "X.xml") + ',' + func.args(NAME, "X.xml", XML),
-        UPMULTDOC_X_X);
-    error(func.args(NAME, "X.xml", XML) + ',' + _DB_ADD.args(NAME, XML, "X.xml"),
-        UPMULTDOC_X_X);
-
-    // GH-1302: check replacements of existing and new paths
-    query(func.args(NAME, "3.xml", XML) + ',' + func.args(NAME, "4.xml", XML));
-    query(func.args(NAME, "3.xml", " <a/>") + ',' + func.args(NAME, "5.xml", " <a/>"));
-
-    // GH-1302: check replacements of new paths
-    query(func.args(NAME, "6.xml", XML) + ',' + func.args(NAME, "7.xml", XML));
-    query(func.args(NAME, "8.xml", " <a/>") + ',' + func.args(NAME, "9.xml", " <a/>"));
+    query(_DB_GET_BINARY.args(NAME, "dir3/file3"));
+    query(_DB_GET_BINARY.args(NAME, "dir3/file5"));
   }
 
   /** Test method. */
@@ -861,39 +935,21 @@ public final class DbModuleTest extends QueryPlanTest {
     final Function func = _DB_RESTORE;
     execute(new Close());
 
-    // backup and restore file
+    // backup and restore
     query(_DB_CREATE_BACKUP.args(NAME));
     query(func.args(NAME));
     query(func.args(NAME));
 
+    // backup and restore general data
+    query(_DB_CREATE_BACKUP.args(""));
+    query(func.args(""));
+
     // drop backups
     query(_DB_DROP_BACKUP.args(NAME));
     error(func.args(NAME), DB_NOBACKUP_X);
 
     // invalid names
-    error(func.args(" ''"), DB_NAME_X);
-  }
-
-  /** Test method. */
-  @Test public void retrieve() {
-    final Function func = _DB_RETRIEVE;
-    error(func.args(NAME, "binary"), WHICHRES_X);
-    query(_DB_STORE.args(NAME, "binary", " xs:hexBinary('41')"));
-    query("xs:hexBinary(" + func.args(NAME, "binary") + ')', "A");
-    query(_DB_DELETE.args(NAME, "binary"));
-    error(func.args(NAME, "binary"), WHICHRES_X);
-  }
-
-  /** Test method. */
-  @Test public void store() {
-    final Function func = _DB_STORE;
-    query(func.args(NAME, "binary1", "xs:hexBinary('41')"));
-    query(func.args(NAME, "binary2", "b"));
-    query(_DB_RETRIEVE.args(NAME, "binary2"), "b");
-    query(func.args(NAME, "binary3", 123));
-    query(_DB_RETRIEVE.args(NAME, "binary3"), 123);
-
-    error(func.args(NAME, "bin/x", "x") + ", " + func.args(NAME, "bin//x", "x"), DB_CONFLICT5_X);
+    for(final char ch : INVALID) error(func.args(ch), DB_NAME_X);
   }
 
   /** Test method. */
@@ -940,6 +996,15 @@ public final class DbModuleTest extends QueryPlanTest {
     query("data(" + func.args(NAME, "XXX") + ")", "");
   }
 
+  /** Test method. */
+  @Test public void type() {
+    final Function func = _DB_TYPE;
+    query(_DB_ADD.args(NAME, " <a/>", "xml.xml"));
+    query(_DB_PUT_BINARY.args(NAME, "bla", "bla.bin"));
+    query(func.args(NAME, "xml.xml"), "xml");
+    query(func.args(NAME, "bla.bin"), "binary");
+  }
+
   /**
    * Returns a lower-case representation of the specified option.
    * @param option option
