@@ -15,7 +15,7 @@ import org.junit.jupiter.api.*;
 /**
  * This class tests the functions of the File Module.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Rositsa Shadura
  */
 public final class FileModuleTest extends SandboxTest {
@@ -134,6 +134,19 @@ public final class FileModuleTest extends SandboxTest {
     error(func.args(PATH1, PATH3), FILE_NO_DIR_X);
   }
 
+  /** Test method. */
+  @Test public void copy2() {
+    final String query = _FILE_CREATE_DIR.args(PATH1) + ','
+        + _FILE_CREATE_DIR.args(PATH2) + ','
+        + _FILE_CREATE_DIR.args(PATH3) + ','
+        + _FILE_WRITE_TEXT.args(PATH4, "X") + ", "
+        + "for $i in" + _FILE_CHILDREN.args(PATH1) + ' '
+        + "return" + _FILE_COPY.args(" $i", PATH2);
+
+    query(query);
+    query(query);
+  }
+
   /** Test method. */
   @Test public void createDir() {
     final Function func = _FILE_CREATE_DIR;
@@ -415,6 +428,10 @@ public final class FileModuleTest extends SandboxTest {
     query("contains(" + func.args(can1, can2) + ", \"" + can1 + "\")", true);
     query("contains(" + func.args("X", can1 + File.separator) + ", \"" +
         can1 + File.separator + "X\")", true);
+
+    query("not(contains(" + func.args("../", can1) + ", '..'))", true);
+    query("not(contains(" + func.args("../X", can1) + ", '..'))", true);
+
     error(func.args(can1, "b"), FILE_IS_RELATIVE_X);
     error(func.args("X", "b"), FILE_IS_RELATIVE_X);
   }
@@ -497,6 +514,11 @@ public final class FileModuleTest extends SandboxTest {
     query(_FILE_SIZE.args(PATH1), 1);
     query(func.args(PATH1, "\u00fc", "US-ASCII"));
     query(_FILE_READ_TEXT.args(PATH1), "?");
+
+    query(func.args(PATH1, "\u00b0"));
+    query(_FILE_READ_TEXT.args(PATH1), "\u00b0");
+    query(func.args(PATH2, _FILE_READ_TEXT.args(PATH1)));
+    query(_FILE_READ_TEXT.args(PATH2), "\u00b0");
   }
 
   /** Test method. */
