@@ -8,7 +8,7 @@ import org.junit.jupiter.api.*;
 /**
  * Tests for {@link XQArray#put(long, org.basex.query.value.Value)}.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Leo Woerteler
  */
 public final class ArrayPutTest extends ArrayTest {
@@ -17,15 +17,15 @@ public final class ArrayPutTest extends ArrayTest {
    */
   @Test public void setAllTest() {
     final int n = 5000;
-    final ArrayBuilder builder = new ArrayBuilder();
+    final ArrayBuilder ab = new ArrayBuilder();
     for(int i = 0; i < n; i++) {
-      builder.append(Int.get(i));
+      ab.append(Int.get(i));
     }
-    final XQArray array = builder.array();
+    final XQArray array1 = ab.array();
     for(int i = 0; i < n; i++) {
-      final XQArray arr = array.put(i, Int.get(-i));
+      final XQArray array2 = array1.put(i, Int.get(-i));
       for(int j = 0; j < n; j++) {
-        assertEquals(i == j ? -j : j, ((Int) arr.get(j)).itr());
+        assertEquals(i == j ? -j : j, ((Int) array2.get(j)).itr());
       }
     }
   }
