@@ -8,7 +8,7 @@ import java.io.*;
  * This example requires a running database server instance.
  * Documentation: https://docs.basex.org/wiki/Clients
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  */
 public final class CreateExample {
   /**
@@ -28,10 +28,10 @@ public final class CreateExample {
       System.out.println(session.info());
 
       // run query on database
-      System.out.println(session.execute("xquery doc('database')"));
+      System.out.println(session.execute("XQUERY doc('database')"));
 
       // drop database
-      session.execute("drop db database");
+      session.execute("DROP DB database");
     }
   }
 }
