@@ -9,7 +9,7 @@ import net.xqj.basex.*;
  * <a href="http://www.cfoster.net/articles/xqj-tutorial">
  * http://www.cfoster.net/articles/xqj-tutorial</a> from Charles Foster.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  */
 abstract class Main {
   /**
@@ -24,8 +24,9 @@ abstract class Main {
   /**
    * Creates and returns a default connection.
    * @return connection instance
+   * @throws XQException XQException
    */
-  static XQConnection connect() {
+  static XQConnection connect() throws XQException {
     return new BaseXXQDataSource().getConnection("admin", "admin");
   }
 
