@@ -5,9 +5,8 @@ import static org.basex.util.Prop.*;
 import static org.basex.util.Token.*;
 
 import java.io.*;
-import java.lang.reflect.*;
 import java.util.*;
-import java.util.Map.Entry;
+import java.util.Map.*;
 import java.util.regex.*;
 
 import javax.xml.namespace.*;
@@ -18,20 +17,21 @@ import org.basex.io.out.*;
 import org.basex.io.serial.*;
 import org.basex.query.*;
 import org.basex.query.func.*;
-import org.basex.query.func.fn.DeepEqual.Mode;
+import org.basex.query.util.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.type.*;
 import org.basex.tests.bxapi.*;
 import org.basex.tests.bxapi.xdm.*;
 import org.basex.util.*;
-import org.basex.util.options.Options.YesNo;
+import org.basex.util.list.*;
+import org.basex.util.options.Options.*;
 
 /**
  * Driver for the XQuery/XPath/XSLT 3.* Test Suite, located at
  * {@code http://dev.w3.org/2011/QT3-test-suite/}. The driver needs to be
  * executed from the test suite directory.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public final class QT3TS extends Main {
@@ -114,20 +114,17 @@ public final class QT3TS extends Main {
     final IOFile sandbox = new IOFile(TEMPDIR, "tests");
     ctx.soptions.set(StaticOptions.DBPATH, sandbox + "/data");
     parseArgs();
-    init();
 
     final Performance perf = new Performance();
-    ctx.options.set(MainOptions.CHOP, false);
 
     final SerializerOptions sopts = new SerializerOptions();
     sopts.set(SerializerOptions.METHOD, SerialMethod.XML);
-    sopts.set(SerializerOptions.INDENT, YesNo.NO);
     sopts.set(SerializerOptions.OMIT_XML_DECLARATION, YesNo.NO);
     ctx.options.set(MainOptions.SERIALIZER, sopts);
 
     final XdmValue doc = new XQuery("doc('" + file(false, CATALOG) + "')", ctx).value();
     final String version = asString("*:catalog/@version", doc);
-    Util.outln(NL + "QT3 Test Suite " + version);
+    Util.outln(NL + "QT Test Suite " + version);
     Util.outln("Test directory: " + file(false, "."));
     Util.out("Parsing queries");
 
@@ -316,20 +313,22 @@ public final class QT3TS extends Main {
       if(env != null) {
         // bind documents
         for(final HashMap<String, String> src : env.sources) {
-          // add document reference
-          final String file = file(base, src.get(FILE));
-          query.addDocument(src.get(URI), file);
-          final String role = src.get(ROLE);
+          final String file = src.get(FILE), role = src.get(ROLE);
+          if(file ==  null) continue;
+
+          final String path = file(base, file);
+          query.addDocument(src.get(URI), path);
           if(role == null) continue;
 
-          final XdmValue doc = query.document(file);
+          final XdmValue doc = query.document(path);
           if(role.equals(".")) query.context(doc);
-          else query.bind(role, doc);
+          else query.variable(role, doc);
         }
         // bind resources
         for(final HashMap<String, String> src : env.resources) {
-          query.addResource(src.get(URI), file(base, src.get(FILE)),
-              src.get(QT3Constants.ENCODING));
+          final String file = src.get(FILE);
+          if(file == null) continue;
+          query.addResource(src.get(URI), file(base, file), src.get(QT3Constants.ENCODING));
         }
         // bind collections
         query.addCollection(env.collURI, env.collSources.toArray());
@@ -414,7 +413,7 @@ public final class QT3TS extends Main {
       }
       // bind variables
       for(final HashMap<String, String> par : env.params) {
-        query.bind(par.get(NNAME), new XQuery(par.get(SELECT), ctx).value());
+        query.variable(par.get(NNAME), new XQuery(par.get(SELECT), ctx).value());
       }
     }
     return query;
@@ -456,7 +455,7 @@ public final class QT3TS extends Main {
       // skip default-language
       "@type = 'default-language' and @value != 'en' or " +
       // skip non-XQuery tests
-      "@type = 'spec' and not(matches(@value, 'XQ(\\d\\d\\+|31)'))" +
+      "@type = 'spec' and not(matches(@value, 'XQ(\\d\\d\\+|40)'))" +
         ']', ctx).context(test).value().size() == 0;
   }
 
@@ -624,7 +623,7 @@ public final class QT3TS extends Main {
     final String exp = expected.getString();
     try {
       final String query = "declare variable $result external; " + exp;
-      return environment(new XQuery(query, ctx), result.env).bind("$result", result.value).
+      return environment(new XQuery(query, ctx), result.env).variable("$result", result.value).
           value().getBoolean() ? null : exp;
     } catch(final XQueryException ex) {
       // should not occur
@@ -654,7 +653,7 @@ public final class QT3TS extends Main {
     final String exp = expected.getString();
     try {
       final String query = "declare variable $returned external; $returned eq " + exp;
-      return environment(new XQuery(query, ctx), result.env).bind("$returned", result.value).
+      return environment(new XQuery(query, ctx), result.env).variable("$returned", result.value).
           value().getBoolean() ? null : exp;
     } catch(final XQueryException err) {
       // numeric overflow: try simple string comparison
@@ -692,10 +691,10 @@ public final class QT3TS extends Main {
     if(exp.size() != res.size())
       return Util.info("% results (found: %)", exp.size(), res.size());
 
-    for(final String s : exp.toArray(new String[0])) {
+    for(final String s : exp.toArray(String[]::new)) {
       if(!res.contains(s)) return Util.info("% (missing)", s);
     }
-    for(final String s : res.toArray(new String[0])) {
+    for(final String s : res.toArray(String[]::new)) {
       if(!exp.contains(s))
         return Util.info("% (missing in expected result)", s);
     }
@@ -710,14 +709,14 @@ public final class QT3TS extends Main {
    */
   private String assertXML(final QT3Result result, final XdmValue expected) {
     final String file = asString("@file", expected);
-    final boolean norm = asBoolean("@normalize-space=('true','1')", expected);
-    final boolean pref = asBoolean("@ignore-prefixes=('true','1')", expected);
+    final boolean normalizeSpace = asBoolean("@normalize-space=('true','1')", expected);
+    final boolean ignorePrefixes = asBoolean("@ignore-prefixes=('true','1')", expected);
 
     String exp = expected.getString();
     try {
       if(!file.isEmpty()) exp = string(new IOFile(baseDir, file).read());
       exp = normNL(exp);
-      if(norm) exp = string(normalize(token(exp)));
+      if(normalizeSpace) exp = string(normalize(token(exp)));
 
       final XdmValue returned = result.value;
       final String res = normNL(
@@ -729,10 +728,12 @@ public final class QT3TS extends Main {
       if(exp.equals(r)) return null;
 
       // include check for comments, processing instructions and namespaces
-      final StringBuilder flags = new StringBuilder("'").append(Mode.ALLNODES).append('\'');
-      if(!pref) flags.append(",'").append(Mode.NAMESPACES).append('\'');
-      final String query = Function._UTIL_DEEP_EQUAL.args(" <X>" + exp + "</X>",
-          " <X>" + res + "</X>" , " (" + flags.append(")").toString());
+      final StringList options = new StringList();
+      options.add("'" + DeepEqualOptions.NAMESPACE_PREFIXES.name() + "':" + !ignorePrefixes + "()");
+      options.add("'" + DeepEqualOptions.COMMENTS.name() + "':true()");
+      options.add("'" + DeepEqualOptions.PROCESSING_INSTRUCTIONS.name() + "':true()");
+      final String query = Function.DEEP_EQUAL.args(" <X>" + exp + "</X>",
+          " <X>" + res + "</X>", " ()", " map { " + String.join(", ", options) + " }");
       return asBoolean(query, expected) ? null : exp;
     } catch(final IOException ex) {
       return Util.info("% (found: %)", exp, ex);
@@ -753,8 +754,8 @@ public final class QT3TS extends Main {
           + "declare variable $expected external;"
           + "matches($returned, string($expected), '" + flags + "')";
 
-      return environment(new XQuery(query, ctx), result.env).bind("returned", returned).
-          bind("expected", expected).value().getBoolean() ? null : expected.getString();
+      return environment(new XQuery(query, ctx), result.env).variable("returned", returned).
+          variable("expected", expected).value().getBoolean() ? null : expected.getString();
     } catch(final Exception err) {
       return Util.info("% (found: %)", expected.getString(), err);
     }
@@ -797,7 +798,7 @@ public final class QT3TS extends Main {
   private static String serialize(final QT3Result result) throws QueryException, IOException {
     try {
       final ArrayOutput ao = new ArrayOutput();
-      try(Serializer ser = result.query.qp().getSerializer(ao)) {
+      try(Serializer ser = result.query.qp().serializer(ao)) {
         for(final Item item : result.value.internal()) ser.serialize(item);
       }
       return ao.toString();
@@ -862,7 +863,7 @@ public final class QT3TS extends Main {
       final String query = "declare variable $returned external; $returned instance of " + exp;
       final XQuery xquery = environment(new XQuery(query, ctx), result.env);
       final XdmValue returned = result.value;
-      return xquery.bind("returned", returned).value().getBoolean() ? null :
+      return xquery.variable("returned", returned).value().getBoolean() ? null :
         Util.info("Type '%' (found: '%')", exp, returned.getType().toString());
     } catch(final XQueryException ex) {
       // should not occur
@@ -955,42 +956,6 @@ public final class QT3TS extends Main {
     }
   }
 
-  /**
-   * Adds an environment variable required for function tests. Reference:
-   *http://stackoverflow.com/questions/318239/how-do-i-set-environment-variables-from-java
-   */
-  @SuppressWarnings("unchecked")
-  private static void init() {
-    final Map<String, String> ne = new HashMap<>();
-    ne.put("QTTEST", "42");
-    ne.put("QTTEST2", "other");
-    ne.put("QTTESTEMPTY", "");
-    try {
-      final Class<?> pe = Class.forName("java.lang.ProcessEnvironment");
-      final Field f = pe.getDeclaredField("theEnvironment");
-      f.setAccessible(true);
-      ((Map<String, String>) f.get(null)).putAll(ne);
-      final Field f2 = pe.getDeclaredField("theCaseInsensitiveEnvironment");
-      f2.setAccessible(true);
-      ((Map<String, String>) f2.get(null)).putAll(ne);
-    } catch(final NoSuchFieldException ex) {
-      Util.debug(ex);
-      try {
-        for(final Class<?> cl : Collections.class.getDeclaredClasses()) {
-          if("java.util.Collections$UnmodifiableMap".equals(cl.getName())) {
-            final Field f = cl.getDeclaredField("m");
-            f.setAccessible(true);
-            ((Map<String, String>) f.get(System.getenv())).putAll(ne);
-          }
-        }
-      } catch(final Exception ex2) {
-        Util.errln("Test environment variable could not be set:" + ex2);
-      }
-    } catch(final Exception ex1) {
-      Util.errln("Test environment variable could not be set: " + ex1);
-    }
-  }
-
   /**
    * Structure for storing XQuery results.
    */
