@@ -14,19 +14,18 @@ import org.basex.io.*;
 import org.basex.io.out.*;
 import org.basex.io.serial.*;
 import org.basex.query.*;
-import org.basex.query.func.fn.*;
+import org.basex.query.util.*;
 import org.basex.query.value.*;
 import org.basex.query.value.item.*;
 import org.basex.query.value.node.*;
 import org.basex.query.value.seq.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
-import org.basex.util.options.Options.YesNo;
 
 /**
  * XQuery Test Suite wrapper.
  *
- * @author BaseX Team 2005-22, BSD License
+ * @author BaseX Team 2005-23, BSD License
  * @author Christian Gruen
  */
 public abstract class W3CTS extends Main {
@@ -79,8 +78,6 @@ public abstract class W3CTS extends Main {
   private int timer = Integer.MAX_VALUE;
   /** Minimum conformance. */
   private boolean minimum;
-  /** Print compilation steps. */
-  private boolean compile;
   /** test-group to use. */
   private String group;
 
@@ -125,7 +122,6 @@ public abstract class W3CTS extends Main {
 
     final SerializerOptions sopts = new SerializerOptions();
     sopts.set(SerializerOptions.METHOD, SerialMethod.XML);
-    sopts.set(SerializerOptions.INDENT, YesNo.NO);
     context.options.set(MainOptions.SERIALIZER, sopts);
   }
 
@@ -142,16 +138,14 @@ public abstract class W3CTS extends Main {
       System.exit(1);
     }
 
+    final Performance perf = new Performance();
+
     if(!new IOFile(path).isAbsolute()) path = new IOFile(".", path + '/').path();
     queries = path + "Queries/XQuery/";
     expected = path + "ExpectedTestResults/";
     results = path + "ReportingResults/Results/";
     final String report = path + "ReportingResults/";
     final String sources = path + "TestSources/";
-
-    final Performance perf = new Performance();
-    context.options.set(MainOptions.CHOP, false);
-
     data = new DBNode(new IOFile(path + input)).data();
 
     final DBNode root = new DBNode(data, 0);
@@ -267,6 +261,7 @@ public abstract class W3CTS extends Main {
     boolean inspect = false;
     boolean correct = true;
 
+    final DeepEqual deep = new DeepEqual();
     final Value states = states(root);
     final long ss = states.size();
     for(int s = 0; s < ss; s++) {
@@ -285,8 +280,7 @@ public abstract class W3CTS extends Main {
         curr = DBNodeSeq.get(d.resources.docs(), d, true, true);
       }
 
-      context.options.set(MainOptions.QUERYINFO, compile);
-      try(QueryProcessor qp = new QueryProcessor(in, query.path(), context)) {
+      try(QueryProcessor qp = new QueryProcessor(in, query.path(), context, null)) {
         if(curr != null) qp.context(curr);
         context.options.set(MainOptions.QUERYINFO, false);
 
@@ -332,13 +326,6 @@ public abstract class W3CTS extends Main {
           // unexpected error - dump stack trace
         }
 
-        // print compilation steps
-        if(compile) {
-          Util.errln("---------------------------------------------------------");
-          Util.err(qp.info());
-          Util.errln(in);
-        }
-
         final Value expOut = nodes("*:output-file/text()", state);
         final TokenList result = new TokenList();
         for(final Item item : expOut) {
@@ -404,8 +391,7 @@ public abstract class W3CTS extends Main {
             if(xml || frag) {
               try {
                 final Value val = toValue(expect.replaceAll("^<\\?xml.*?\\?>", "").trim(), frag);
-                if(new DeepEqual().equal(value.iter(), val.iter()) ||
-                   new DeepEqual().equal(toValue(actual, frag).iter(), val.iter())) break;
+                if(deep.equal(value, val) || deep.equal(toValue(actual, frag), val)) break;
               } catch(final Throwable ex) {
                 Util.errln('\n' + outname + ':');
                 Util.stack(ex);
@@ -553,7 +539,7 @@ public abstract class W3CTS extends Main {
       }
 
       final Value value = qp.qc.resources.doc(new QueryInput(src, qp.sc), null);
-      qp.bind(string(vars.itemAt(n).string(null)), value);
+      qp.variable(string(vars.itemAt(n).string(null)), value);
     }
     return tb.finish();
   }
@@ -573,7 +559,7 @@ public abstract class W3CTS extends Main {
       final String nm = string(nodes.itemAt(n).string(null));
       final String src = srcs.get(nm);
       final Item item = src == null ? coll(nm, qp) : Str.get(src);
-      qp.bind(string(vars.itemAt(n).string(null)), item);
+      qp.variable(string(vars.itemAt(n).string(null)), item);
     }
   }
 
@@ -586,7 +572,7 @@ public abstract class W3CTS extends Main {
    */
   private Uri coll(final String name, final QueryProcessor qp) throws QueryException {
     qp.qc.resources.addCollection(name, colls.get(name), qp.sc);
-    return Uri.uri(name);
+    return Uri.get(name);
   }
 
   /**
@@ -605,8 +591,8 @@ public abstract class W3CTS extends Main {
     for(int n = 0; n < ns; ++n) {
       final String file = pth + string(nodes.itemAt(n).string(null)) + IO.XQSUFFIX;
       final IO io = new IOFile(queries, file);
-      try(QueryProcessor xq = new QueryProcessor(io.string(), io.path(), context)) {
-        qp.bind(string(vars.itemAt(n).string(null)), xq.value());
+      try(QueryProcessor xq = new QueryProcessor(io.string(), io.path(), context, null)) {
+        qp.variable(string(vars.itemAt(n).string(null)), xq.value());
       }
     }
   }
@@ -732,8 +718,6 @@ public abstract class W3CTS extends Main {
           currTime = true;
         } else if(c == 'C') {
           currTime = true;
-        } else if(c == 'c') {
-          compile = true;
         } else if(c == 'd') {
           Prop.debug = true;
         } else if(c == 'm') {
